(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    295113,       6358]*)
(*NotebookOutlinePosition[    296152,       6392]*)
(*  CellTagsIndexPosition[    296108,       6388]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Signature of a shim placed on a hybrid undulator structure", "Title"],

Cell[TextData[{
  "P. Elleaume (elleaume@esrf.fr)\nNovembre   2000, Version 1.0\nThis \
notebook has been developed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 on a PowerMac. It should execute on other platforms with any version \
of ",
  StyleBox["Mathematica higher than 3. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell["To Read before Starting ", "Section"],

Cell["\<\
- This notebook is intended to show how to  simulate the effect of \
a shim (small flat piece of iron) placed at the surface of an hybrid  \
undulator magnet array. The shim and field integral signatures of the shim \
are computed and plotted. This example is significantly more complex than \
computing the field modification produced by a shim placed on a pure \
permanent magnet undulator. The reason is that the field modification induced \
by the shim takes place through two processes. First, the  magnetization \
induced in the shim change the surrounding field. Second, the magnetization \
in the iron pole of the undulator is changed due to the presence of the shim. \
The modified magnetization of the pole change also the surrounding field. 
- As it can be seen below, the  computation requires solving two cases \
(magnets+poles) and (magnets+poles+shims) and to substract the  field and \
field integrals  computed in each case. The accuracy of the computation \
mostly depends on the segmentation parameters used for the shim and the \
poles. The user is invited to change these parameters to check that the \
result of interest is stable under a further segmentation. The risk is to run \
out of memory and CPU time for too large segmentation. The user is also \
invited to change the shim dimensions and position and experience with the \
signature of the shim. A similar sheet could be used to obtain the siganture \
of a pole or magnet mis-positionning, one would then compare the field and \
field integrals in the cases (magnets+poles in normal position)  and \
(magnets+poles with mis-positionning).
- The dimension and position of the shims used in this notebook are not at \
all optimized to suite a particular project of multipole or spectrum \
shimming. The user interested in using this notebook to develop a shimming \
algorithm must run this notebook in his particular undulator geometry with \
various position and dimension of shims and develop the understanding of the \
field and field integral  modification induced by shims. From such a point, \
he will derive the proper algorithm to perform the shimming. This can be made \
by a sequence of correction of the main errors or by a sophisticated matrix \
invertion. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["How to Use this Notebook", "Section"],

Cell["\<\
It is important to execute the fooling in section in the order in \
which it appears in this notebook. One may modify a parameter of a section \
and re-execute it. THis notebook will not work properly if the section \
\"Initilaization\" is not executed before the section \"Build the Geometry\" \
or if the section \"Build the Geometry\" is not executed before the section \
\"Plot the signature of the shim\" . 
1 - Execute the section \"Initialization\". Mandatory
2 - Edit the parameters and execute the section \"Build the \
Geometry\".Mandatory
3  -Execute the cells in the section \"Display the Geometry\" to check the \
size and position of the shim (in red) at the surface of the block (in blue). \
Not mandatory
4-  Execute the cells in the section \"Plot the signature of the shim\" to \
obtain a  plot of the field and field integral produced by the shim \
.Mandatory\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Radia`;\)\), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(hyb[] := 
        Module[{}, \[IndentingNewLine]magnets = 
            radObjCnt[{}]; \[IndentingNewLine]poles = 
            radObjCnt[{}]; \[IndentingNewLine]\[IndentingNewLine]y = \
\(-per\); \[IndentingNewLine]y = y + per/4; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + per/4; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lpz\)/2}, {lpx, per/2 - ls, 
                lpz}]; \[IndentingNewLine]radObjAddToCnt[
            poles, {m}]; \[IndentingNewLine]y = 
            y + per/4; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                0}]; \[IndentingNewLine]\(radObjAddToCnt[
                magnets, {m}];\)\[IndentingNewLine]\(y = 
                y + per/4;\)\[IndentingNewLine]\(m = 
              radObjRecMag[{0, y, \(-lpz\)/2}, {lpx, per/2 - ls, 
                  lpz}]\); \[IndentingNewLine]radObjAddToCnt[
            poles, {m}]; \[IndentingNewLine]y = 
            y + per/4; \[IndentingNewLine]\(m = 
                radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                    0}];\)\[IndentingNewLine]\(radObjAddToCnt[
                magnets, {m}];\)\[IndentingNewLine]\(y = 
                y + per/4;\)\[IndentingNewLine]\(m = 
              radObjRecMag[{0, y, \(-lpz\)/2}, {lpx, per/2 - ls, 
                  lpz}]\); \[IndentingNewLine]radObjAddToCnt[
            poles, {m}]; \[IndentingNewLine]y = 
            y + per/4; \[IndentingNewLine]\(m = 
                radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                    0}];\)\[IndentingNewLine]radObjAddToCnt[
              magnets, {m}]; \[IndentingNewLine]\[IndentingNewLine]radMatApl[
            magnets, matmag]; \[IndentingNewLine]radObjDivMag[magnets, 
            segmag]; \[IndentingNewLine]radObjDrwAtr[
            magnets, {0, 0.5, 
              1}]; \[IndentingNewLine]\[IndentingNewLine]radMatApl[poles, 
            matpole]; \[IndentingNewLine]radObjDivMag[poles, 
            segpole]; \[IndentingNewLine]radObjDrwAtr[
            poles, {0, 1, 
              0.5}]; \[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  \
___\ Generate\ the\ shim\ ___  ___  ___  ___  ___  ___\ \
*) \[IndentingNewLine]shim = 
            shims[]; \[IndentingNewLine]\[IndentingNewLine]all = 
            radObjCnt[{shim, poles, magnets}]; \[IndentingNewLine]{all, shim, 
            magnets, poles}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(ppm[] := 
        Module[{}, \[IndentingNewLine]magnets = 
            radObjCnt[{}]; \[IndentingNewLine]y = \(-per\)*3/
                4; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                0}]; \[IndentingNewLine]\(radObjAddToCnt[
                magnets, {m}];\)\[IndentingNewLine]\(y = 
              y + ls\); \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 0, 
                br}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 
                0, \(-br\)}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, br, 
                0}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]m = 
            radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, 0, 
                br}]; \[IndentingNewLine]radObjAddToCnt[
            magnets, {m}]; \[IndentingNewLine]y = 
            y + ls; \[IndentingNewLine]\(m = 
                radObjRecMag[{0, y, \(-lz\)/2}, {lx, ls, lz}, {0, \(-br\), 
                    0}];\)\[IndentingNewLine]radObjAddToCnt[
              magnets, {m}]; \[IndentingNewLine]radMatApl[magnets, 
            matmag]; \[IndentingNewLine]\(radObjDivMag[magnets, 
                segmag];\)\[IndentingNewLine]radObjDrwAtr[
              magnets, {0, 0.5, 
                1}]; \[IndentingNewLine] (*___  ___  ___  ___\ Generate\ the\ \
shim\ ___  ___  ___  ___  ___  ___\ *) \[IndentingNewLine]shim = 
            shims[]; \[IndentingNewLine]\[IndentingNewLine]all = 
            radObjCnt[{shim, magnets}]; \[IndentingNewLine]{all, shim, 
            magnets}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(shims[] := 
      Module[{}, \[IndentingNewLine]shim = 
          radObjRecMag[{px, ps, lsz/2 + dz}, {lsx, lss, 
              lsz}]; \[IndentingNewLine]\(radObjDivMag[shim, 
              segshim];\)\[IndentingNewLine]\(radObjDrwAtr[
              shim, {1, 0, 0.5}];\)\[IndentingNewLine]radMatApl[shim, 
            matshim]; shim]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Builg the Geometry ", "Section"],

Cell["\<\
Build a magnet array with a single shim placed at the surface. \
Solve for the magnetization in the shim.  The user is responsible to check \
that the signature of the shim (see below) is unchanged with respec to a \
further subdivision (defined by  seg). \
\>", "Text"],

Cell[BoxData[{
    \(\(radUtiDelAll[];\)\[IndentingNewLine]\[IndentingNewLine] (*___  ___  \
___  ___\ Magnets\ \ \ ___  ___  ___  ___*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(per = 
        35;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ Period\ \ o\
f\ the\ magnetic\ assembly\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 
        50;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(lz = 
        50;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(ls = 
        per*0.35;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ size\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(br = 
        1.2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Magnetization\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(matmag = 
        RadMatNdFeB[br];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Material\ of\ the\ magnets\ *) \), "\[IndentingNewLine]", 
    \(\(segmag = {1, 1, 
          3};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ 
      Segmentation\ of\ the\ magnets\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*___  ___  ___  ___\ Poles\ ___  ___  ___  ___*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(lpx = 
        40;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ Size\ of\ the\ poles\ *) \), "\[IndentingNewLine]", 
    \(\(lpz = 
        40;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ Size\ of\ the\ poles\ *) \), "\[IndentingNewLine]", 
    \(\(matpole = 
        RadMatAFK1[];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Material\ of\ the\ poles\ *) \ \ \), "\[IndentingNewLine]", 
    \(\(segpole = {6, 3, 
          4};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  (*\ Segmentation\ of\ the\ poles\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*___  ___  ___  ___\ Shim\ ___  ___  ___  ___*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(lsx = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(lsz = 
        0.1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(lss = 
        20;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ size\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(px = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ position\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(ps = 
        0;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ position\ of\ the\ shim\ *) \), "\[IndentingNewLine]", 
    \(\(dz = 
        0.01;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ position\ above\ magnet\ array\ *) \), "\[IndentingNewLine]", \

    \(\(segshim = {3, 4, 
          1};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  (*\ Segmentation\ of\ the\ shim\ \ *) \ \), "\[IndentingNewLine]", 
    \(\(matshim = RadMatSteel37[];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Material\ of\ the\ shim\ *) \ \ \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine] (*___  ___  ___  ___\ Generate\ the\ magnet\ array\ \ and\
\ shim\ ___  ___  ___  ___*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\({all, shim, magnets, poles} = hyb[];\)\), "\[IndentingNewLine]", 
    \(\(magnetpole = radObjCnt[{poles, magnets}];\)\)}], "Input",
  CellMargins->{{51, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Display the Geometry ", "Section"],

Cell[BoxData[
    \(\(\( (*\ 
      If\ QuickDraw3D\ is\ installed\ \
*) \)\(\[IndentingNewLine]\)\(radObjDrwQD3D[all];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Only\ with\ Mathematica\ 4.0\ or\ later\ \ *) \[IndentingNewLine]\(<< 
        RealTime3D`;\)\), "\[IndentingNewLine]", 
    \(\(Show[Graphics3D[radObjDrw[all]]];\)\), "\[IndentingNewLine]", 
    \(\(<< Default3D`;\)\)}], "Input"],

Cell[BoxData[
  Graphics3D[{
    Line[{{-25.000008, -28.291662, -50.000008},{
      25.000013, -28.291662, -50.000008},{
      25.000013, -28.291662, 0.000013},{-25.000008, -28.291662, 
        0.000013},{-25.000008, -28.291662, -50.000008}}],
    Line[{{-25.000008, -24.208323, -50.000008},{
      25.000013, -24.208323, -50.000008},{
      25.000013, -24.208323, 0.000013},{-25.000008, -24.208323, 
        0.000013},{-25.000008, -24.208323, -50.000008}}],
    Line[{{-25.000008, -10.791661, -50.000008},{
      25.000013, -10.791661, -50.000008},{
      25.000013, -10.791661, 0.000013},{-25.000008, -10.791661, 
        0.000013},{-25.000008, -10.791661, -50.000008}}],
    Line[{{-25.000008, -6.708322, -50.000008},{
      25.000013, -6.708322, -50.000008},{
      25.000013, -6.708322, 0.000013},{-25.000008, -6.708322, 
        0.000013},{-25.000008, -6.708322, -50.000008}}],
    Line[{{-25.000008, 6.708338, -50.000008},{
      25.000013, 6.708338, -50.000008},{
      25.000013, 6.708338, 0.000013},{-25.000008, 6.708338, 
        0.000013},{-25.000008, 6.708338, -50.000008}}],
    Line[{{-25.000008, 10.791678, -50.000008},{
      25.000013, 10.791678, -50.000008},{
      25.000013, 10.791678, 0.000013},{-25.000008, 10.791678, 
        0.000013},{-25.000008, 10.791678, -50.000008}}],
    Line[{{-25.000008, 24.208338, -50.000008},{
      25.000013, 24.208338, -50.000008},{
      25.000013, 24.208338, 0.000013},{-25.000008, 24.208338, 
        0.000013},{-25.000008, 24.208338, -50.000008}}],
    Line[{{-25.000008, 28.291677, -50.000008},{
      25.000013, 28.291677, -50.000008},{
      25.000013, 28.291677, 0.000013},{-25.000008, 28.291677, 
        0.000013},{-25.000008, 28.291677, -50.000008}}],
    Line[{{-13.333337, -20.125000, -40.000008},{-13.333337, -14.874981, \
-40.000008},{-13.333337, -14.874981, 0.000013},{-13.333337, -20.125000, 
        0.000013},{-13.333337, -20.125000, -40.000008}}],
    Line[{{-6.666667, -20.125000, -40.000008},{-6.666667, -14.874981, \
-40.000008},{-6.666667, -14.874981, 0.000013},{-6.666667, -20.125000, 
        0.000013},{-6.666667, -20.125000, -40.000008}}],
    Line[{{0.000003, -20.125000, -40.000008},{
      0.000003, -14.874981, -40.000008},{0.000003, -14.874981, 0.000013},{
      0.000003, -20.125000, 0.000013},{0.000003, -20.125000, -40.000008}}],
    Line[{{6.666673, -20.125000, -40.000008},{
      6.666673, -14.874981, -40.000008},{6.666673, -14.874981, 0.000013},{
      6.666673, -20.125000, 0.000013},{6.666673, -20.125000, -40.000008}}],
    Line[{{13.333343, -20.125000, -40.000008},{
      13.333343, -14.874981, -40.000008},{13.333343, -14.874981, 0.000013},{
      13.333343, -20.125000, 0.000013},{13.333343, -20.125000, -40.000008}}],
    Line[{{-20.000008, -18.374994, -40.000008},{
      20.000013, -18.374994, -40.000008},{
      20.000013, -18.374994, 0.000013},{-20.000008, -18.374994, 
        0.000013},{-20.000008, -18.374994, -40.000008}}],
    Line[{{-20.000008, -16.624987, -40.000008},{
      20.000013, -16.624987, -40.000008},{
      20.000013, -16.624987, 0.000013},{-20.000008, -16.624987, 
        0.000013},{-20.000008, -16.624987, -40.000008}}],
    Line[{{-20.000008, -20.125000, -30.000002},{
      20.000013, -20.125000, -30.000002},{
      20.000013, -14.874981, -30.000002},{-20.000008, -14.874981, \
-30.000002},{-20.000008, -20.125000, -30.000002}}],
    Line[{{-20.000008, -20.125000, -19.999996},{
      20.000013, -20.125000, -19.999996},{
      20.000013, -14.874981, -19.999996},{-20.000008, -14.874981, \
-19.999996},{-20.000008, -20.125000, -19.999996}}],
    Line[{{-20.000008, -20.125000, -9.999992},{
      20.000013, -20.125000, -9.999992},{
      20.000013, -14.874981, -9.999992},{-20.000008, -14.874981, \
-9.999992},{-20.000008, -20.125000, -9.999992}}],
    Line[{{-13.333337, -2.625001, -40.000008},{-13.333337, 
        2.625019, -40.000008},{-13.333337, 2.625019, 
        0.000013},{-13.333337, -2.625001, 
        0.000013},{-13.333337, -2.625001, -40.000008}}],
    Line[{{-6.666667, -2.625001, -40.000008},{-6.666667, 
        2.625019, -40.000008},{-6.666667, 2.625019, 
        0.000013},{-6.666667, -2.625001, 
        0.000013},{-6.666667, -2.625001, -40.000008}}],
    Line[{{0.000003, -2.625001, -40.000008},{0.000003, 2.625019, -40.000008},{
      0.000003, 2.625019, 0.000013},{0.000003, -2.625001, 0.000013},{
      0.000003, -2.625001, -40.000008}}],
    Line[{{6.666673, -2.625001, -40.000008},{6.666673, 2.625019, -40.000008},{
      6.666673, 2.625019, 0.000013},{6.666673, -2.625001, 0.000013},{
      6.666673, -2.625001, -40.000008}}],
    Line[{{13.333343, -2.625001, -40.000008},{
      13.333343, 2.625019, -40.000008},{13.333343, 2.625019, 0.000013},{
      13.333343, -2.625001, 0.000013},{13.333343, -2.625001, -40.000008}}],
    Line[{{-20.000008, -0.874994, -40.000008},{
      20.000013, -0.874994, -40.000008},{
      20.000013, -0.874994, 0.000013},{-20.000008, -0.874994, 
        0.000013},{-20.000008, -0.874994, -40.000008}}],
    Line[{{-20.000008, 0.875012, -40.000008},{
      20.000013, 0.875012, -40.000008},{
      20.000013, 0.875012, 0.000013},{-20.000008, 0.875012, 
        0.000013},{-20.000008, 0.875012, -40.000008}}],
    Line[{{-20.000008, -2.625001, -30.000002},{
      20.000013, -2.625001, -30.000002},{
      20.000013, 2.625019, -30.000002},{-20.000008, 
        2.625019, -30.000002},{-20.000008, -2.625001, -30.000002}}],
    Line[{{-20.000008, -2.625001, -19.999996},{
      20.000013, -2.625001, -19.999996},{
      20.000013, 2.625019, -19.999996},{-20.000008, 
        2.625019, -19.999996},{-20.000008, -2.625001, -19.999996}}],
    Line[{{-20.000008, -2.625001, -9.999992},{
      20.000013, -2.625001, -9.999992},{
      20.000013, 2.625019, -9.999992},{-20.000008, 
        2.625019, -9.999992},{-20.000008, -2.625001, -9.999992}}],
    Line[{{-13.333337, 14.874999, -40.000008},{-13.333337, 
        20.125019, -40.000008},{-13.333337, 20.125019, 0.000013},{-13.333337, 
        14.874999, 0.000013},{-13.333337, 14.874999, -40.000008}}],
    Line[{{-6.666667, 14.874999, -40.000008},{-6.666667, 
        20.125019, -40.000008},{-6.666667, 20.125019, 0.000013},{-6.666667, 
        14.874999, 0.000013},{-6.666667, 14.874999, -40.000008}}],
    Line[{{0.000003, 14.874999, -40.000008},{
      0.000003, 20.125019, -40.000008},{0.000003, 20.125019, 0.000013},{
      0.000003, 14.874999, 0.000013},{0.000003, 14.874999, -40.000008}}],
    Line[{{6.666673, 14.874999, -40.000008},{
      6.666673, 20.125019, -40.000008},{6.666673, 20.125019, 0.000013},{
      6.666673, 14.874999, 0.000013},{6.666673, 14.874999, -40.000008}}],
    Line[{{13.333343, 14.874999, -40.000008},{
      13.333343, 20.125019, -40.000008},{13.333343, 20.125019, 0.000013},{
      13.333343, 14.874999, 0.000013},{13.333343, 14.874999, -40.000008}}],
    Line[{{-20.000008, 16.625006, -40.000008},{
      20.000013, 16.625006, -40.000008},{
      20.000013, 16.625006, 0.000013},{-20.000008, 16.625006, 
        0.000013},{-20.000008, 16.625006, -40.000008}}],
    Line[{{-20.000008, 18.375013, -40.000008},{
      20.000013, 18.375013, -40.000008},{
      20.000013, 18.375013, 0.000013},{-20.000008, 18.375013, 
        0.000013},{-20.000008, 18.375013, -40.000008}}],
    Line[{{-20.000008, 14.874999, -30.000002},{
      20.000013, 14.874999, -30.000002},{
      20.000013, 20.125019, -30.000002},{-20.000008, 
        20.125019, -30.000002},{-20.000008, 14.874999, -30.000002}}],
    Line[{{-20.000008, 14.874999, -19.999996},{
      20.000013, 14.874999, -19.999996},{
      20.000013, 20.125019, -19.999996},{-20.000008, 
        20.125019, -19.999996},{-20.000008, 14.874999, -19.999996}}],
    Line[{{-20.000008, 14.874999, -9.999992},{
      20.000013, 14.874999, -9.999992},{
      20.000013, 20.125019, -9.999992},{-20.000008, 
        20.125019, -9.999992},{-20.000008, 14.874999, -9.999992}}],
    Line[{{8.333336, -10.000009, 2.000000},{8.333336, 10.000011, 2.000000},{
      8.333336, 10.000011, 2.100020},{8.333336, -10.000009, 2.100020},{
      8.333336, -10.000009, 2.000000}}],
    Line[{{11.666676, -10.000009, 2.000000},{11.666676, 10.000011, 2.000000},{
      11.666676, 10.000011, 2.100020},{11.666676, -10.000009, 2.100020},{
      11.666676, -10.000009, 2.000000}}],
    Line[{{4.999996, -5.000004, 2.000000},{15.000015, -5.000004, 2.000000},{
      15.000015, -5.000004, 2.100020},{4.999996, -5.000004, 2.100020},{
      4.999996, -5.000004, 2.000000}}],
    Line[{{4.999996, 0.000001, 2.000000},{15.000015, 0.000001, 2.000000},{
      15.000015, 0.000001, 2.100020},{4.999996, 0.000001, 2.100020},{
      4.999996, 0.000001, 2.000000}}],
    Line[{{4.999996, 5.000006, 2.000000},{15.000015, 5.000006, 2.000000},{
      15.000015, 5.000006, 2.100020},{4.999996, 5.000006, 2.100020},{
      4.999996, 5.000006, 2.000000}}],
    Polygon[{{-25.000000, -32.375000, -50.000000},{-25.000000, -20.125000, \
-50.000000},{25.000000, -20.125000, -50.000000},{
      25.000000, -32.375000, -50.000000}}],
    Polygon[{{-25.000000, -32.375000, -50.000000},{
      25.000000, -32.375000, -50.000000},{
      25.000000, -32.375000, 0.000000},{-25.000000, -32.375000, 0.000000}}],
    Polygon[{{-25.000000, -32.375000, -50.000000},{-25.000000, -32.375000, 
        0.000000},{-25.000000, -20.125000, 
        0.000000},{-25.000000, -20.125000, -50.000000}}],
    Polygon[{{-25.000000, -32.375000, 0.000000},{
      25.000000, -32.375000, 0.000000},{
      25.000000, -20.125000, 0.000000},{-25.000000, -20.125000, 0.000000}}],
    Polygon[{{-25.000000, -20.125000, -50.000000},{-25.000000, -20.125000, 
        0.000000},{25.000000, -20.125000, 0.000000},{
      25.000000, -20.125000, -50.000000}}],
    Polygon[{{25.000000, -32.375000, -50.000000},{
      25.000000, -20.125000, -50.000000},{25.000000, -20.125000, 0.000000},{
      25.000000, -32.375000, 0.000000}}],
    Polygon[{{-25.000000, -14.875000, -50.000000},{-25.000000, -2.625000, \
-50.000000},{25.000000, -2.625000, -50.000000},{
      25.000000, -14.875000, -50.000000}}],
    Polygon[{{-25.000000, -14.875000, -50.000000},{
      25.000000, -14.875000, -50.000000},{
      25.000000, -14.875000, 0.000000},{-25.000000, -14.875000, 0.000000}}],
    Polygon[{{-25.000000, -14.875000, -50.000000},{-25.000000, -14.875000, 
        0.000000},{-25.000000, -2.625000, 
        0.000000},{-25.000000, -2.625000, -50.000000}}],
    Polygon[{{-25.000000, -14.875000, 0.000000},{
      25.000000, -14.875000, 0.000000},{
      25.000000, -2.625000, 0.000000},{-25.000000, -2.625000, 0.000000}}],
    Polygon[{{-25.000000, -2.625000, -50.000000},{-25.000000, -2.625000, 
        0.000000},{25.000000, -2.625000, 0.000000},{
      25.000000, -2.625000, -50.000000}}],
    Polygon[{{25.000000, -14.875000, -50.000000},{
      25.000000, -2.625000, -50.000000},{25.000000, -2.625000, 0.000000},{
      25.000000, -14.875000, 0.000000}}],
    Polygon[{{-25.000000, 2.625000, -50.000000},{-25.000000, 
        14.875000, -50.000000},{25.000000, 14.875000, -50.000000},{
      25.000000, 2.625000, -50.000000}}],
    Polygon[{{-25.000000, 2.625000, -50.000000},{
      25.000000, 2.625000, -50.000000},{
      25.000000, 2.625000, 0.000000},{-25.000000, 2.625000, 0.000000}}],
    Polygon[{{-25.000000, 2.625000, -50.000000},{-25.000000, 2.625000, 
        0.000000},{-25.000000, 14.875000, 0.000000},{-25.000000, 
        14.875000, -50.000000}}],
    Polygon[{{-25.000000, 2.625000, 0.000000},{
      25.000000, 2.625000, 0.000000},{
      25.000000, 14.875000, 0.000000},{-25.000000, 14.875000, 0.000000}}],
    Polygon[{{-25.000000, 14.875000, -50.000000},{-25.000000, 14.875000, 
        0.000000},{25.000000, 14.875000, 0.000000},{
      25.000000, 14.875000, -50.000000}}],
    Polygon[{{25.000000, 2.625000, -50.000000},{
      25.000000, 14.875000, -50.000000},{25.000000, 14.875000, 0.000000},{
      25.000000, 2.625000, 0.000000}}],
    Polygon[{{-25.000000, 20.125000, -50.000000},{-25.000000, 
        32.375000, -50.000000},{25.000000, 32.375000, -50.000000},{
      25.000000, 20.125000, -50.000000}}],
    Polygon[{{-25.000000, 20.125000, -50.000000},{
      25.000000, 20.125000, -50.000000},{
      25.000000, 20.125000, 0.000000},{-25.000000, 20.125000, 0.000000}}],
    Polygon[{{-25.000000, 20.125000, -50.000000},{-25.000000, 20.125000, 
        0.000000},{-25.000000, 32.375000, 0.000000},{-25.000000, 
        32.375000, -50.000000}}],
    Polygon[{{-25.000000, 20.125000, 0.000000},{
      25.000000, 20.125000, 0.000000},{
      25.000000, 32.375000, 0.000000},{-25.000000, 32.375000, 0.000000}}],
    Polygon[{{-25.000000, 32.375000, -50.000000},{-25.000000, 32.375000, 
        0.000000},{25.000000, 32.375000, 0.000000},{
      25.000000, 32.375000, -50.000000}}],
    Polygon[{{25.000000, 20.125000, -50.000000},{
      25.000000, 32.375000, -50.000000},{25.000000, 32.375000, 0.000000},{
      25.000000, 20.125000, 0.000000}}],
    Polygon[{{-20.000000, -20.125000, -40.000000},{-20.000000, -14.875000, \
-40.000000},{20.000000, -14.875000, -40.000000},{
      20.000000, -20.125000, -40.000000}}],
    Polygon[{{-20.000000, -20.125000, -40.000000},{
      20.000000, -20.125000, -40.000000},{
      20.000000, -20.125000, 0.000000},{-20.000000, -20.125000, 0.000000}}],
    Polygon[{{-20.000000, -20.125000, -40.000000},{-20.000000, -20.125000, 
        0.000000},{-20.000000, -14.875000, 
        0.000000},{-20.000000, -14.875000, -40.000000}}],
    Polygon[{{-20.000000, -20.125000, 0.000000},{
      20.000000, -20.125000, 0.000000},{
      20.000000, -14.875000, 0.000000},{-20.000000, -14.875000, 0.000000}}],
    Polygon[{{-20.000000, -14.875000, -40.000000},{-20.000000, -14.875000, 
        0.000000},{20.000000, -14.875000, 0.000000},{
      20.000000, -14.875000, -40.000000}}],
    Polygon[{{20.000000, -20.125000, -40.000000},{
      20.000000, -14.875000, -40.000000},{20.000000, -14.875000, 0.000000},{
      20.000000, -20.125000, 0.000000}}],
    Polygon[{{-20.000000, -2.625000, -40.000000},{-20.000000, 
        2.625000, -40.000000},{20.000000, 2.625000, -40.000000},{
      20.000000, -2.625000, -40.000000}}],
    Polygon[{{-20.000000, -2.625000, -40.000000},{
      20.000000, -2.625000, -40.000000},{
      20.000000, -2.625000, 0.000000},{-20.000000, -2.625000, 0.000000}}],
    Polygon[{{-20.000000, -2.625000, -40.000000},{-20.000000, -2.625000, 
        0.000000},{-20.000000, 2.625000, 0.000000},{-20.000000, 
        2.625000, -40.000000}}],
    Polygon[{{-20.000000, -2.625000, 0.000000},{
      20.000000, -2.625000, 0.000000},{
      20.000000, 2.625000, 0.000000},{-20.000000, 2.625000, 0.000000}}],
    Polygon[{{-20.000000, 2.625000, -40.000000},{-20.000000, 2.625000, 
        0.000000},{20.000000, 2.625000, 0.000000},{
      20.000000, 2.625000, -40.000000}}],
    Polygon[{{20.000000, -2.625000, -40.000000},{
      20.000000, 2.625000, -40.000000},{20.000000, 2.625000, 0.000000},{
      20.000000, -2.625000, 0.000000}}],
    Polygon[{{-20.000000, 14.875000, -40.000000},{-20.000000, 
        20.125000, -40.000000},{20.000000, 20.125000, -40.000000},{
      20.000000, 14.875000, -40.000000}}],
    Polygon[{{-20.000000, 14.875000, -40.000000},{
      20.000000, 14.875000, -40.000000},{
      20.000000, 14.875000, 0.000000},{-20.000000, 14.875000, 0.000000}}],
    Polygon[{{-20.000000, 14.875000, -40.000000},{-20.000000, 14.875000, 
        0.000000},{-20.000000, 20.125000, 0.000000},{-20.000000, 
        20.125000, -40.000000}}],
    Polygon[{{-20.000000, 14.875000, 0.000000},{
      20.000000, 14.875000, 0.000000},{
      20.000000, 20.125000, 0.000000},{-20.000000, 20.125000, 0.000000}}],
    Polygon[{{-20.000000, 20.125000, -40.000000},{-20.000000, 20.125000, 
        0.000000},{20.000000, 20.125000, 0.000000},{
      20.000000, 20.125000, -40.000000}}],
    Polygon[{{20.000000, 14.875000, -40.000000},{
      20.000000, 20.125000, -40.000000},{20.000000, 20.125000, 0.000000},{
      20.000000, 14.875000, 0.000000}}],
    Polygon[{{5.000000, -10.000000, 2.000000},{
      5.000000, 10.000000, 2.000000},{15.000000, 10.000000, 2.000000},{
      15.000000, -10.000000, 2.000000}}],
    Polygon[{{5.000000, -10.000000, 2.000000},{
      15.000000, -10.000000, 2.000000},{15.000000, -10.000000, 2.100000},{
      5.000000, -10.000000, 2.100000}}],
    Polygon[{{5.000000, -10.000000, 2.000000},{
      5.000000, -10.000000, 2.100000},{5.000000, 10.000000, 2.100000},{
      5.000000, 10.000000, 2.000000}}],
    Polygon[{{5.000000, -10.000000, 2.100000},{
      15.000000, -10.000000, 2.100000},{15.000000, 10.000000, 2.100000},{
      5.000000, 10.000000, 2.100000}}],
    Polygon[{{5.000000, 10.000000, 2.000000},{5.000000, 10.000000, 2.100000},{
      15.000000, 10.000000, 2.100000},{15.000000, 10.000000, 2.000000}}],
    Polygon[{{15.000000, -10.000000, 2.000000},{
      15.000000, 10.000000, 2.000000},{15.000000, 10.000000, 2.100000},{
      15.000000, -10.000000, 2.100000}}]},
    ViewPoint -> {1.965964, -2.660310, 1.087539}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool2000008d0oooo002?0?ooo`80000000<0oooo000000000000
S03oool008d0oooo0P0000030?ooo`040000003oool00000000008X0oooo002;0?ooo`8000001@3o
ool01@000000oooo0?ooo`3oool0000008T0oooo00280?ooo`<000001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo08H0oooo00260?ooo`8000002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo08D0oooo00240?ooo`800000303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08@0oooo00220?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`80
0000Q03oool007l0oooo0`00000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
P@3oool007d0oooo0P00000C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P03o
ool007/0oooo0P00000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0O`3oool0
07P0oooo0`00000G0?ooo`030000003oool0oooo00X0oooo0P00001o0?ooo`00MP3oool2000001T0
oooo0P00000>0?ooo`030000003oool0oooo07`0oooo001d0?ooo`8000006@3oool20000000303<c
<`000000000000h0oooo00<000000?ooo`3oool0N`3oool00780oooo0P00000I0?ooo`8000000`0c
<c<010000000a:Tc00000000000=0?ooo`030000003oool0oooo07X0oooo001_0?ooo`<00000603o
ool3000000D0<c<c00D000000<BY<`34ZC<0a:Tc0000000=0?ooo`030000003oool0oooo07T0oooo
001]0?ooo`8000006@3oool2000000P0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000oooo0?oo
o`0;0?ooo`800000N@3oool006/0oooo0P00000H0?ooo`<000002P0c<c<00`000000a:Tc0<BY<`03
0<BY<`8000003@3oool00`000000oooo0?ooo`1f0?ooo`00J@3oool2000001P0oooo0P00000=03<c
<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1e0?oo
o`00IP3oool3000001P0oooo0P00000?03<c<`0300000034ZC<0a:Tc00H0a:Tc00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1d0?ooo`00I03oool2000001P0oooo0`00000A03<c<`030000
0034ZC<0a:Tc00L0a:Tc00<000000?ooo`3oool02`3oool2000007@0oooo001R0?ooo`800000603o
ool2000001@0<c<c00<000000<BY<`34ZC<02034ZC<2000000d0oooo00<000000?ooo`3oool0L@3o
ool00600oooo0P00000G0?ooo`<000005P0c<c<00`000000a:Tc0<BY<`090<BY<`8000003@3oool0
0`000000oooo0?ooo`1`0?ooo`00G@3oool3000001L0oooo0P00000I03<c<`0300000034ZC<0a:Tc
00T0a:Tc00<000000<BY<`0000003@3oool00`000000oooo0?ooo`1_0?ooo`00F`3oool2000001P0
oooo0P00000K03<c<`0300000034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00P00000<0?ooo`03
0000003oool0oooo06h0oooo001I0?ooo`8000005`3oool3000001d0<c<c00<000000<BY<`34ZC<0
2@34ZC<00`000000a:Tc0<BY<`020<BY<`030000003oool0oooo00X0oooo0P00001^0?ooo`00EP3o
ool3000001L0oooo0P00000P03<c<`0300000034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00`34
ZC<00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06/0oooo001D0?ooo`800000603oool2
00000280<c<c00<000000<BY<`34ZC<02@34ZC<00`000000a:Tc0<BY<`030<BY<`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0JP3oool00580oooo0P00000G0?ooo`<00000900c<c<00`00
0000a:Tc0<BY<`090<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1Y0?ooo`00D03oool2000001L0oooo0P00000W03<c<`0300000034ZC<0a:Tc00T0
a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000oooo0?ooo`0>0?ooo`800000J@3oool004d0oooo
0`00000F0?ooo`<00000:@0c<c<00`000000a:Tc0<BY<`090<BY<`0300000034ZC<0a:Tc00<0a:Tc
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1V0?ooo`00B`3oool2000001L0oooo0P00
000/03<c<`0300000034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo06D0oooo00190?ooo`8000005`3oool2000002h0<c<c00<00000
0<BY<`34ZC<02@34ZC<00`000000a:Tc0<BY<`030<BY<`030000003oool0oooo00<0oooo0P00000=
0?ooo`030000003oool0oooo06@0oooo00170?ooo`8000005P3oool300000300<c<c00<000000<BY
<`34ZC<02@34ZC<00`000000a:Tc0<BY<`030<BY<`040000003oool0oooo0?ooo`80000000<0<c<c
0000000000003@3oool00`000000oooo0?ooo`1S0?ooo`00A03oool3000001H0oooo0P00000c03<c
<`0300000034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00`34ZC<4000000<0<c<c00@000000<BY
<`0000000000303oool2000006<0oooo00120?ooo`8000005P3oool3000003D0<c<c00<000000<BY
<`34ZC<03`34ZC<00`000000<c<c03<c<`0403<c<`0500000034ZC<0a:Tc0<BY<`0000003@3oool0
0`000000oooo0?ooo`1P0?ooo`00@03oool2000001H0oooo0P00000h03<c<`0300000034ZC<0a:Tc
00l0a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`020<BY<`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0G`3oool003h0oooo0P00000F0?ooo`800000>P0c<c<00`000000
a:Tc0<BY<`0?0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo05h0oooo000k0?ooo`<000005@3oool3000003`0<c<c
00<000000<BY<`34ZC<03`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00@0a:Tc
0P00000<0?ooo`800000GP3oool003T0oooo0P00000F0?ooo`800000?`0c<c<00`000000a:Tc0<BY
<`0?0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<01@34ZC<2000000d0oooo00<0
00000?ooo`3oool0F`3oool003L0oooo0P00000F0?ooo`800000@@0c<c<00`000000a:Tc0<BY<`0?
0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<01`34ZC<2000000`0oooo00<00000
0?ooo`3oool0FP3oool003@0oooo0`00000E0?ooo`<00000@`0c<c<00`000000a:Tc0<BY<`0?0<BY
<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo05T0oooo000b0?ooo`8000005P3oool2000004H0<c<c00<000000<BY<`34
ZC<03`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc0P00000=0?ooo`03
0000003oool0oooo05P0oooo000`0?ooo`8000005@3oool3000004P0<c<c00<000000<BY<`34ZC<0
3`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc00@000000<BY<`000000
0000303oool2000005P0oooo000^0?ooo`8000005@3oool2000004/0<c<c00<000000<BY<`34ZC<0
3`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc00D000000<BY<`34ZC<0
a:Tc0000000=0?ooo`030000003oool0oooo05D0oooo000/0?ooo`8000005@3oool2000004d0<c<c
00<000000<BY<`34ZC<03`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc
00<000000<BY<`34ZC<00P34ZC<00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05@0oooo
000/0?ooo`<000004@3oool3000004l0<c<c00<000000<BY<`34ZC<03`34ZC<00`000000<c<c03<c
<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo05<0oooo000/0?ooo`030000003oool0oooo008000003@3oool2
00000580<c<c00<000000<BY<`34ZC<03`34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0
a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000oooo0?ooo`0=0?ooo`800000D`3oool0
02`0oooo00<000000?ooo`3oool00P3oool2000000P0oooo0`00001D03<c<`0300000034ZC<0a:Tc
00l0a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`0=0<BY<`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0D03oool002`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo03<c<`0c<c<0E00c<c<00`000000a:Tc0<BY<`0?0<BY<`03
0000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<03@34ZC<00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo04l0oooo000/0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool00000
0000001I03<c<`0300000034ZC<0a:Tc00l0a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc
0<BY<`0=0<BY<`030000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo04h0oooo
000[0?ooo`030000003oool0oooo00L0oooo0P00001K03<c<`0300000034ZC<0a:Tc00l0a:Tc00<0
000003<c<`0c<c<0100c<c<2000000@0a:Tc00<000000<BY<`34ZC<01`34ZC<00`000000oooo0000
00020000000403<c<`0000000000000000`0oooo00<000000?ooo`3oool0C@3oool002/0oooo00<0
00000?ooo`3oool01`3oool00`000000<c<c03<c<`1J03<c<`0300000034ZC<0a:Tc00l0a:Tc00<0
000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00L0a:Tc0P00
000403<c<`0400000034ZC<0a:Tc000000`0oooo0P00001=0?ooo`00:`3oool00`000000oooo0?oo
o`070?ooo`030000000c<c<0<c<c05X0<c<c00<000000<BY<`34ZC<03`34ZC<00`000000<c<c03<c
<`0503<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01`34ZC<00`000000<c<c03<c
<`0303<c<`0400000034ZC<0a:Tc0<BY<`800000303oool00`000000oooo0?ooo`1:0?ooo`00:`3o
ool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05X0<c<c00<000000<BY<`34ZC<03`34
ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<00`34
ZC<01@000000a:Tc0<BY<`34ZC<0000000D0<c<c00<000000<BY<`34ZC<00P34ZC<2000000`0oooo
00<000000?ooo`3oool0B@3oool002/0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c
<`1J03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY
<`080<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc0<BY<`040<BY<`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0B03oool002/0oooo00<000000?ooo`3oool01`3o
ool00`000000<c<c03<c<`1J03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c<`0c<c<0100c
<c<00`000000a:Tc0<BY<`080<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc
0<BY<`050<BY<`030000003oool0oooo00X0oooo0P0000180?ooo`00:`3oool00`000000oooo0?oo
o`070?ooo`030000000c<c<0<c<c05X0<c<c00<000000<BY<`34ZC<04034ZC<00`000000<c<c03<c
<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc00D000000<BY<`34ZC<0a:Tc0000000503<c<`030000
0034ZC<0a:Tc00H0a:Tc0P00000<0?ooo`030000003oool0oooo04D0oooo000[0?ooo`030000003o
ool0oooo00H0oooo00<0000003<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY<`0@0<BY<`030000000c
<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<01@000000a:Tc0<BY<`34ZC<0000000D0<c<c
00<000000<BY<`34ZC<02034ZC<00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04@0oooo
000[0?ooo`030000003oool0oooo00H0oooo00<0000003<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY
<`0@0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY
<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<02@34ZC<00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04<0oooo000[0?ooo`030000003oool0oooo00H0oooo00<00000
03<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY<`0@0<BY<`030000000c<c<0<c<c00@0<c<c00<00000
0<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c0080<c<c00<00000
0<BY<`34ZC<02P34ZC<2000000/0oooo00<000000?ooo`3oool0@P3oool002/0oooo00<000000?oo
o`3oool01P3oool00`000000<c<c03<c<`1K03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c
<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c
<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0;0<BY<`030000003oool0oooo00T0oooo0P0000120?oo
o`00:`3oool00`000000oooo0?ooo`060?ooo`030000000c<c<0<c<c05/0<c<c00<000000<BY<`34
ZC<04034ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34
ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00/0a:Tc00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0o0?ooo`00:P3oool00`000000oooo0?ooo`070?ooo`030000
000c<c<0<c<c05/0<c<c00<000000<BY<`34ZC<04034ZC<00`000000<c<c03<c<`0403<c<`030000
0034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`030000
0034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01P34ZC<00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03h0oooo000Z0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0F`0c
<c<00`000000a:Tc0<BY<`0@0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034
ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<00P34
ZC<00`000000a:Tc0<BY<`060<BY<`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?@3o
ool002X0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1K03<c<`0300000034ZC<0
a:Tc0100a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0
a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0
a:Tc00H0a:Tc00<000000?ooo`3oool03P3oool2000003d0oooo000Z0?ooo`030000003oool0oooo
00L0oooo00<0000003<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY<`0@0<BY<`030000000c<c<0<c<c
00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c
00<0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY<`0500000034ZC<0a:Tc
0<BY<`000000103oool2000000`0oooo00<000000?ooo`3oool0>P3oool002X0oooo00<000000?oo
o`3oool01`3oool00`000000<c<c03<c<`1K03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c
<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c
<`0c<c<00`0c<c<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc0080a:Tc00H000000<BY
<`34ZC<0a:Tc0000003oool30000000303<c<`000000000000`0oooo00<000000?ooo`3oool0>@3o
ool002X0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1K03<c<`0300000034ZC<0
a:Tc0100a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0
a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`070<BY<`0400000034ZC<0
a:Tc0<BY<`800000100c<c<010000000a:Tc00000000000;0?ooo`030000003oool0oooo03P0oooo
000Z0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY
<`0@0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY
<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<01`34ZC<01@000000a:Tc0<BY
<`34ZC<0000000D0<c<c00<000000<BY<`34ZC<00P00000;0?ooo`030000003oool0oooo03L0oooo
000Z0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0F`0c<c<00`000000a:Tc0<BY
<`0@0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY
<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000a:Tc0<BY
<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<00P34ZC<00`000000oooo0?oo
o`090?ooo`800000=`3oool002X0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1K
03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`08
0<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`07
0<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00P0c<c<00`000000a:Tc0<BY<`03
0<BY<`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=03oool002X0oooo00<000000?oo
o`3oool01P3oool00`000000<c<c03<c<`1L03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c
<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c
<`0c<c<00`0c<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c
<`0c<c<00P0c<c<00`000000a:Tc0<BY<`040<BY<`8000002P3oool2000003D0oooo000Z0?ooo`03
0000003oool0oooo00H0oooo00<0000003<c<`0c<c<0G00c<c<00`000000a:Tc0<BY<`0@0<BY<`03
0000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`03
0000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`03
0000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<01@34ZC<00`000000a:Tc0?ooo`050?ooo`<0
000000<0oooo0000003oool0=03oool002T0oooo00<000000?ooo`3oool01`3oool00`000000<c<c
03<c<`1L03<c<`0300000034ZC<0a:Tc0100a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc
0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc
0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00P0c<c<00`000000a:Tc
0<BY<`060<BY<`8000000P3oool3000000@0oooo00<000000?ooo`3oool0<`3oool002T0oooo00<0
00000?ooo`3oool01`3oool00`000000<c<c03<c<`1L03<c<`0300000034ZC<0a:Tc0100a:Tc00<0
000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0
000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c<c<0<c<c00<0<c<c00<0
00000<BY<`34ZC<01`34ZC<2000000L0oooo00<000000?ooo`3oool0<`3oool002T0oooo00<00000
0?ooo`3oool01`3oool00`000000<c<c03<c<`1L03<c<`0300000034ZC<0a:Tc0100a:Tc00<00000
03<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<00000
03<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c<c<0<c<c00<0<c<c00<00000
0<BY<`34ZC<02034ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo000Y0?oo
o`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G00c<c<00`000000a:Tc0<BY<`040<BY
<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`0=0<BY
<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<03034ZC<00`000000<c<c03<c<`0303<c
<`0500000034ZC<0a:Tc0<BY<`0000001P34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0
oooo03<0oooo000Y0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G00c<c<00`00
0000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<0100c<c<00`00
0000a:Tc0<BY<`0=0<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<03034ZC<00`00
0000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000001P34ZC<00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo03<0oooo000Y0?ooo`030000003oool0oooo00L0oooo00<0000003<c
<`0c<c<0G00c<c<00`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c
<`0c<c<0100c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00L0a:Tc00<0000003<c
<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c<c<0<c<c00<0<c<c00D000000<BY
<`34ZC<0a:Tc000000060<BY<`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<P3oool0
02T0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1L03<c<`0300000034ZC<0a:Tc
00@0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c
00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`070<BY<`030000000c<c<0<c<c
00<0<c<c00<000000<BY<`34ZC<03034ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc
0<BY<`0000000`34ZC<010000000a:Tc0<BY<`0000080?ooo`030000003oool0oooo0380oooo000Y
0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G00c<c<00`000000a:Tc0<BY<`04
0<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000<c<c03<c<`04
03<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<01`34ZC<00`000000<c<c03<c<`03
03<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<01P34ZC<00`000000<c<c03<c<`03
03<c<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<010000000a:Tc0<BY<`0000080?ooo`030000
003oool0oooo0380oooo000Y0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G00c
<c<00`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34
ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34
ZC<01@000000a:Tc0<BY<`34ZC<0000000D0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc
0<BY<`060<BY<`030000000c<c<0<c<c00<0<c<c00D000000<BY<`34ZC<0a:Tc000000030<BY<`04
00000034ZC<0a:Tc000000P0oooo00<000000?ooo`3oool0<P3oool002T0oooo00<000000?ooo`3o
ool01`3oool00`000000<c<c03<c<`1L03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34
ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34
ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`0500000034ZC<0a:Tc0<BY<`0000001P0c<c<00`00
0000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00H0a:Tc00<0000003<c<`0c<c<00`0c<c<01@00
0000a:Tc0<BY<`34ZC<0000000<0a:Tc00D000000<BY<`34ZC<0a:Tc000000070?ooo`030000003o
ool0oooo0380oooo000Y0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G00c<c<0
0`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<0
0`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<0
1@000000a:Tc0<BY<`34ZC<0000000H0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY
<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<01@000000a:Tc0<BY<`34ZC<0000000L0
a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`00:@3oool00`000000oooo
0?ooo`070?ooo`030000000c<c<0<c<c05`0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc
0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc
0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00D000000<BY<`34ZC<0a:Tc0000000603<c<`03
00000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<00000
00D0<c<c00<000000<BY<`34ZC<02@34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0380oooo000X0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G@0c<c<00`000000
a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000
<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<01@000000
a:Tc0<BY<`34ZC<0000000H0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY
<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc0<BY<`090<BY<`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0<P3oool002P0oooo00<000000?ooo`3oool01`3oool00`00
0000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<00`34ZC<00`00
0000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`00
0000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`00
0000a:Tc0<BY<`070<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc0<BY<`09
0<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<P3oool002P0oooo00<000000?oo
o`3oool01`3oool00`000000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY
<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY
<`34ZC<02@34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY
<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY
<`34ZC<02@34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo0380oooo000X0?ooo`03
0000003oool0oooo00L0oooo00<0000003<c<`0c<c<0G@0c<c<00`000000a:Tc0<BY<`040<BY<`03
00000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000<c<c03<c<`0403<c<`80
00002P34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34
ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY<`34
ZC<02@34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo0380oooo000X0?ooo`030000
003oool0oooo00L0oooo00<0000003<c<`0c<c<0G@0c<c<00`000000a:Tc0<BY<`040<BY<`030000
0034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000<c<c03<c<`0503<c<`030000
0034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`030000
0034ZC<0a:Tc00L0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0203<c<`030000
0034ZC<0a:Tc00T0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`00:03o
ool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05d0<c<c00<000000<BY<`34ZC<01034
ZC<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00<0000003<c<`0c<c<01@0c
<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c
<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00P0c
<c<00`000000a:Tc0<BY<`090<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<P3o
ool002P0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1M03<c<`0300000034ZC<0
a:Tc00@0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`030000000c<c<0
<c<c00D0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0
<c<c00<0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0
<c<c0080<c<c0P0000030<BY<`0300000034ZC<0a:Tc00@0a:Tc00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0a0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c
05d0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc
00<0a:Tc00<0000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc
0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc
0080a:Tc00<0000003<c<`0c<c<00`0c<c<01@000000a:Tc0<BY<`34ZC<0000000H0a:Tc00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0a0?ooo`00:03oool00`000000oooo0?ooo`070?oo
o`030000000c<c<0<c<c05d0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`030<BY
<`0300000034ZC<0a:Tc00<0a:Tc00<0000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`080<BY
<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0<0<BY
<`030000000c<c<0<c<c00<0<c<c00D000000<BY<`34ZC<0a:Tc000000060<BY<`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0<@3oool002P0oooo00<000000?ooo`3oool01`3oool00`00
0000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<00`34ZC<00`00
0000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<02034ZC<00`00
0000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<03034ZC<00`00
0000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<01@000000a:Tc0<BY<`34
ZC<0000000L0oooo00<000000?ooo`3oool0<@3oool002P0oooo00<000000?ooo`3oool01`3oool0
0`000000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<00`34ZC<0
0`000000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<02034ZC<0
0`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<03034ZC<0
0`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<01@000000a:Tc0<BY
<`34ZC<0000000L0oooo00<000000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool0203o
ool00`000000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<00`34
ZC<00`000000a:Tc0<BY<`030<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<02034
ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<03034
ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<01@000000a:Tc
0<BY<`34ZC<0000000L0oooo00<000000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool0
203oool00`000000<c<c03<c<`1M03<c<`0300000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<0
2@34ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<0
0P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00`0a:Tc00<0000003<c<`0c<c<0
0`0c<c<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00D000000<BY<`34ZC<0a:Tc000000070?oo
o`030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c
<c<0GP0c<c<00`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c
<c<01@0c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c
<c<00`0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00H0a:Tc00<0000003<c<`0c
<c<00`0c<c<01@000000a:Tc0<BY<`34ZC<0000000L0a:Tc00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05h0
<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`090<BY<`030000000c<c<0<c<c00D0
<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0
<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`060<BY<`030000000c<c<0<c<c00<0
<c<c00D000000<BY<`34ZC<0a:Tc000000070<BY<`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0<@3oool002L0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1N03<c<`03
00000034ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<02@34ZC<00`000000<c<c03<c<`0503<c<`03
00000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`03
00000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<01P34ZC<00`000000<c<c03<c<`0303<c<`03
00000034ZC<0a:Tc00T0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0a0?ooo`00
9`3oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05h0<c<c00<000000<BY<`34ZC<0
1034ZC<00`000000a:Tc0<BY<`090<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<0
2034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<0
0`34ZC<00`000000a:Tc0<BY<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000
a:Tc0<BY<`090<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool002L0oooo
00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1N03<c<`0300000034ZC<0a:Tc00@0a:Tc
00<000000<BY<`34ZC<02@34ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00P0a:Tc
00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00<0a:Tc
00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000D0<c<c00<000000<BY<`34
ZC<02@34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340oooo000W0?ooo`030000
003oool0oooo00L0oooo00<0000003<c<`0c<c<0GP0c<c<00`000000a:Tc0<BY<`040<BY<`030000
0034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`080<BY<`030000
0034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`030<BY<`030000
0034ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc0000000503<c<`0300000034ZC<0a:Tc00T0
a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo
0?ooo`070?ooo`030000000c<c<0<c<c05h0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc
0<BY<`090<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<03@34ZC<00`000000<c<c
03<c<`0403<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc
0<BY<`34ZC<0000000D0<c<c00<000000<BY<`34ZC<02@34ZC<00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0300oooo000W0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0
GP0c<c<00`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<0
1@0c<c<00`000000a:Tc0<BY<`0=0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<0
1`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<0
0P34ZC<00`000000a:Tc0<BY<`040<BY<`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
<03oool002L0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c<`1N03<c<`0300000034
ZC<0a:Tc00@0a:Tc00<000000<BY<`34ZC<02@34ZC<00`000000<c<c03<c<`0503<c<`0300000034
ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<01`34ZC<00`000000<c<c03<c<`0403<c<`0300000034
ZC<0a:Tc00L0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0203<c<`0300000034
ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01034ZC<00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0300oooo000V0?ooo`030000003oool0oooo00P0oooo00<0000003<c<`0c<c<0GP0c<c<0
0`000000a:Tc0<BY<`040<BY<`0300000034ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<01@0c<c<0
0`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00L0a:Tc00<0000003<c<`0c<c<0100c<c<0
0`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00P0c<c<0
0`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0`0?ooo`009P3oool00`000000oooo0?ooo`080?ooo`030000000c<c<0<c<c
05h0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`090<BY<`030000000c<c<0<c<c
00D0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`070<BY<`030000000c<c<0<c<c
00@0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c
0080<c<c00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`009P3oool00`000000oooo0?ooo`080?oo
o`030000000c<c<0<c<c05h0<c<c00<000000<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`090<BY
<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY
<`0500000034ZC<0a:Tc0<BY<`0000001P0c<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0
a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00D0
00000<BY<`34ZC<0a:Tc000000070?ooo`030000003oool0oooo0300oooo000V0?ooo`030000003o
ool0oooo00P0oooo00<0000003<c<`0c<c<0GP0c<c<00`000000a:Tc0<BY<`040<BY<`0300000034
ZC<0a:Tc00T0a:Tc00<0000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034
ZC<0a:Tc00<0a:Tc00D000000<BY<`34ZC<0a:Tc0000000603<c<`0300000034ZC<0a:Tc00L0a:Tc
00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`00
00000`34ZC<01@000000a:Tc0<BY<`34ZC<0000000L0oooo00<000000?ooo`3oool0<03oool002H0
oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`1N03<c<`0300000034ZC<0a:Tc00@0
a:Tc00<000000<BY<`34ZC<02@34ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00<0
a:Tc00<000000<BY<`34ZC<00`34ZC<01@000000a:Tc0<BY<`34ZC<0000000H0<c<c00<000000<BY
<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00D000000<BY
<`34ZC<0a:Tc000000030<BY<`0500000034ZC<0a:Tc0<BY<`0000001`3oool00`000000oooo0?oo
o`0`0?ooo`009P3oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05l0<c<c00<00000
0<BY<`34ZC<01034ZC<00`000000a:Tc0<BY<`0:0<BY<`030000000c<c<0<c<c00@0<c<c00<00000
0<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`0500000034ZC<0a:Tc0<BY<`0000001P0c
<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c
<c<01@000000a:Tc0<BY<`34ZC<0000000L0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0`0?ooo`009P3oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05l0<c<c00<0
00000<BY<`34ZC<04@34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0a:Tc00<0
00000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<0
00000<BY<`34ZC<03034ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`000000
1`34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo000V0?ooo`030000003o
ool0oooo00L0oooo00<0000003<c<`0c<c<0G`0c<c<00`000000a:Tc0<BY<`0A0<BY<`030000000c
<c<0<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`0300000034
ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c
<c<0<c<c00<0<c<c00D000000<BY<`34ZC<0a:Tc000000070<BY<`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0<03oool002H0oooo00<000000?ooo`3oool01`3oool00`000000<c<c03<c
<`1O03<c<`0300000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY
<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c
<`0303<c<`0300000034ZC<0a:Tc00`0a:Tc00<0000003<c<`0c<c<00`0c<c<01@000000a:Tc0<BY
<`34ZC<0000000L0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`009P3o
ool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c05l0<c<c00<000000<BY<`34ZC<04@34
ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34
ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<00`34
ZC<00`000000a:Tc0<BY<`060<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<02@34
ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo000V0?ooo`030000003oool0
oooo00L0oooo00<0000003<c<`0c<c<0G`0c<c<00`000000a:Tc0<BY<`0A0<BY<`030000000c<c<0
<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0
a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0
a:Tc00H0a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`090<BY<`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0;`3oool002H0oooo00<000000?ooo`3oool01`3oool00`00
0000<c<c03<c<`1O03<c<`0300000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c<c<0100c<c<00`00
0000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`00
0000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<01P34ZC<00`00
0000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00T0a:Tc00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0_0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000000c<c<0<c<c05l0
<c<c00<000000<BY<`34ZC<04@34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00<0
a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0
<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`0500000034ZC<0a:Tc0<BY
<`0000001@0c<c<00`000000a:Tc0<BY<`090<BY<`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;`3oool002D0oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`1O03<c<`03
00000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`030<BY<`03
00000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`03
00000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<00000
00D0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`050<BY<`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;`3oool002D0oooo00<000000?ooo`3oool0203oool00`000000
<c<c03<c<`1O03<c<`0300000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c<c<0100c<c<00`000000
a:Tc0<BY<`090<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000
a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc0000000503<c
<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01@34ZC<00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02l0oooo000U0?ooo`030000003oool0oooo00P0oooo00<0000003<c<`0c
<c<0G`0c<c<00`000000a:Tc0<BY<`0A0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34
ZC<02@34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34
ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c
<c<00P0c<c<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0_0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000
000c<c<0<c<c05l0<c<c00<000000<BY<`34ZC<04@34ZC<00`000000<c<c03<c<`0403<c<`030000
0034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`030000
0034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY<`030000
000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000<0
a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`009@3oool00`000000oooo
0?ooo`080?ooo`030000000c<c<0<c<c05l0<c<c00<000000<BY<`34ZC<04@34ZC<00`000000<c<c
03<c<`0403<c<`0300000034ZC<0a:Tc00T0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c
03<c<`0303<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c
03<c<`0203<c<`0300000034ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc000000030<BY<`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool002D0oooo00<000000?ooo`3oool0
1`3oool00`000000<c<c03<c<`1P03<c<`0300000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c<c<0
100c<c<00`000000a:Tc0<BY<`090<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<0
0`0c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<0
0P0c<c<00`000000a:Tc0<BY<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo000U0?ooo`030000003oool0oooo00L0oooo
00<0000003<c<`0c<c<0H00c<c<00`000000a:Tc0<BY<`0A0<BY<`030000000c<c<0<c<c00@0<c<c
0P00000:0<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc
0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00`0c<c<01@000000a:Tc
0<BY<`34ZC<0000000<0a:Tc00D000000<BY<`34ZC<0a:Tc000000070?ooo`030000003oool0oooo
02l0oooo000U0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0H00c<c<00`000000
a:Tc0<BY<`0A0<BY<`030000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<02034ZC<00`000000
a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000
a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00D000000<BY<`34ZC<0a:Tc000000070<BY
<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool002D0oooo00<000000?ooo`3o
ool01`3oool00`000000<c<c03<c<`1P03<c<`0300000034ZC<0a:Tc0140a:Tc00<0000003<c<`0c
<c<01@0c<c<00`000000a:Tc0<BY<`080<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c
<c<0100c<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c
<c<00`0c<c<01@000000a:Tc0<BY<`34ZC<0000000L0a:Tc00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0_0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`030000000c<c<0<c<c0600
<c<c00<000000<BY<`34ZC<04@34ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00P0
a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00L0
a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY
<`0000001`34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo000T0?ooo`03
0000003oool0oooo00P0oooo00<0000003<c<`0c<c<0H00c<c<00`000000a:Tc0<BY<`0A0<BY<`03
0000000c<c<0<c<c00D0<c<c00<000000<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`03
0000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<01`34ZC<00`000000a:Tc0<BY<`020<BY<`03
0000000c<c<0<c<c00<0<c<c00D000000<BY<`34ZC<0a:Tc000000070<BY<`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0;P3oool002@0oooo00<000000?ooo`3oool0203oool00`000000
<c<c03<c<`1O03<c<`<000004P34ZC<00`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00P0
a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00`0
a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`090<BY<`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;P3oool002@0oooo00<000000?ooo`3oool0203oool00`000000<c<c
03<c<`1K03<c<`@0000000<0bJ[90000000000000P00000@0<BY<`030000000c<c<0<c<c00D0<c<c
00<000000<BY<`34ZC<03@34ZC<00`000000<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00`0a:Tc
00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0:0<BY<`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0;P3oool002@0oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c
<`1G03<c<`@000001@39Z/T00`000000bJ[90<VZb@03000000h0a:Tc00<0000003<c<`0c<c<01@0c
<c<00`000000a:Tc0<BY<`0=0<BY<`030000000c<c<0<c<c00@0<c<c00<000000<BY<`34ZC<03034
ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00X0a:Tc00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0^0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000000c<c<0
<c<c05@0<c<c0`0000090<VZb@0300000039Z/T0bJ[90080bJ[90`00000<0<BY<`030000000c<c<0
<c<c00D0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`070<BY<`030000000c<c<0
<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`060<BY<`030000000c<c<0
<c<c00<0<c<c00<000000<BY<`34ZC<02P34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02h0oooo000T0?ooo`030000003oool0oooo00P0oooo00<0000003<c<`0c<c<0D00c<c<40000
00`0bJ[900<000000<VZb@39Z/T00`39Z/T4000000X0a:Tc00<0000003<c<`0c<c<01@0c<c<00`00
0000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00L0a:Tc00<0000003<c<`0c<c<0100c<c<00`00
0000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00H0a:Tc00<0000003<c<`0c<c<00`0c<c<00`00
0000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0^0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000000c<c<0<c<c04d0
<c<c0`00000@0<VZb@0300000039Z/T0000000<000000`39Z/T3000000P0a:Tc00<0000003<c<`0c
<c<01@0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00L0a:Tc00<0000003<c<`0c
<c<0100c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00H0a:Tc00<0000003<c<`0c
<c<00`0c<c<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0^0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000
000c<c<0<c<c04T0<c<c1000000B0<VZb@<000002@39Z/T3000000H0a:Tc00<0000003<c<`0c<c<0
1@0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00D000000<BY<`34ZC<0
a:Tc0000000603<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<01@000000
a:Tc0<BY<`34ZC<0000000D0<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`050<BY
<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool002@0oooo00<000000?ooo`3o
ool0203oool00`000000<c<c03<c<`1503<c<`@000004P39Z/T300000080bJ[900<000000<VZb@39
Z/T02P39Z/T3000000@0a:Tc00<0000003<c<`0c<c<01@0c<c<00`000000a:Tc0<BY<`030<BY<`03
00000034ZC<0a:Tc00<0a:Tc00D000000<BY<`34ZC<0a:Tc0000000603<c<`0300000034ZC<0a:Tc
00<0a:Tc00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000D0<c<c00<00000
0<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0^0?ooo`00903oool00`000000oooo0?ooo`070?ooo`030000000c<c<0
<c<c04<0<c<c0`00000B0<VZb@<000001@39Z/T3000000P0bJ[90P0000030<VZb@<000000P34ZC<0
0`000000<c<c03<c<`0503<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<0
1@000000a:Tc0<BY<`34ZC<0000000H0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY
<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc0<BY<`020<BY<`050000
0034ZC<0a:Tc0<BY<`0000000`34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo02h0
oooo000T0?ooo`030000003oool0oooo00L0oooo00<0000003<c<`0c<c<0?`0c<c<400000140bJ[9
100000040<VZb@@000000`39Z/T200000080bJ[90P0000090<VZb@@000001`0c<c<00`000000a:Tc
0<BY<`030<BY<`0300000034ZC<0a:Tc00<0a:Tc00D000000<BY<`34ZC<0a:Tc0000000603<c<`03
00000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY<`03
0000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<00000
00<0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`00903oool00`000000
oooo0?ooo`070?ooo`030000000c<c<0<c<c03`0<c<c0`00000B0<VZb@<000001039Z/T4000000L0
bJ[91000000=0<VZb@8000001`0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00<0
a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00<0
a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c0080
<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`050<BY<`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0;P3oool002<0oooo00<000000?ooo`3oool0203oool00`000000<c<c
03<c<`0h03<c<`@000004@39Z/T3000000D0bJ[90`0000070<VZb@8000001P39Z/T2000000L0bJ[9
1000000903<c<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc
0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc
0<BY<`020<BY<`0300000034ZC<0a:Tc0080a:Tc00<0000003<c<`0c<c<00P0c<c<00`000000a:Tc
0<BY<`020<BY<`0300000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0]0?ooo`008`3oool00`000000oooo0?ooo`080?ooo`030000000c<c<0<c<c03@0<c<c1000
000A0<VZb@<000001@39Z/T4000000L0bJ[900<000000<VZb@39Z/T02P39Z/T2000000030<VZb@00
00000000008000000P34ZC<00`000000<c<c03<c<`0803<c<`0300000034ZC<0a:Tc00<0a:Tc00<0
00000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<0
00000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`0300000034ZC<0a:Tc0080a:Tc00<0
000003<c<`0c<c<00P0c<c<2000000<0a:Tc00<000000<BY<`34ZC<01@34ZC<00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02d0oooo000S0?ooo`030000003oool0oooo00P0oooo00<00000
03<c<`0c<c<0<@0c<c<300000180bJ[90`0000040<VZb@@000001`39Z/T00`000000bJ[90<VZb@0=
0<VZb@D000001@34ZC<00`000000<c<c03<c<`0803<c<`0300000034ZC<0a:Tc00<0a:Tc00<00000
0<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00<00000
0<BY<`34ZC<02034ZC<00`000000a:Tc0<BY<`020<BY<`030000000c<c<0<c<c00<0<c<c00D00000
0<BY<`34ZC<0a:Tc000000070<BY<`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3o
ool002<0oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`0]03<c<`@000004@39Z/T3
000000D0bJ[90`0000070<VZb@8000003P39Z/T500000080bJ[9100000030<BY<`030000000c<c<0
<c<c00L0<c<c0P0000050<BY<`0300000034ZC<0a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<0
0`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<0
0`000000<c<c03<c<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000002034ZC<00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02d0oooo000S0?ooo`030000003oool0oooo00P0oooo00<00000
03<c<`0c<c<0:P0c<c<300000140bJ[90`0000050<VZb@@000001P39Z/T2000000h0bJ[91@000006
0<VZb@H0000000<0a:Tc0000000c<c<0100c<c<400000080bJ[90P0000030<BY<`0300000034ZC<0
a:Tc00<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0
a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c<`0303<c<`0500000034ZC<0
a:Tc0<BY<`0000002034ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo000S
0?ooo`030000003oool0oooo00P0oooo00<0000003<c<`0c<c<09P0c<c<400000100bJ[90`000006
0<VZb@<000001P39Z/T2000000l0bJ[9100000060<VZb@@000001039Z/T40000000303<c<`000000
0000008000002039Z/T2000000030<BY<`000000a:Tc00@0a:Tc00<000000<BY<`34ZC<00P34ZC<0
0`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00P0a:Tc00<000000<BY<`34ZC<00P34ZC<0
0`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc00X0a:Tc00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0]0?ooo`008`3oool00`000000oooo0?ooo`080?ooo`030000000c<c<0<c<c
0280<c<c1000000A0<VZb@<000001@39Z/T4000000H0bJ[900<000000<VZb@39Z/T03@39Z/T40000
00H0bJ[9100000040<VZb@<000000`39Z/T4000000d0bJ[90P0000050<BY<`0300000034ZC<0a:Tc
0080a:Tc00<0000003<c<`0c<c<0100c<c<00`000000a:Tc0<BY<`070<BY<`0300000034ZC<0a:Tc
0080a:Tc00<0000003<c<`0c<c<00`0c<c<00`000000a:Tc0<BY<`0:0<BY<`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;@3oool002<0oooo00<000000?ooo`3oool0203oool00`000000
<c<c03<c<`0O03<c<`<000004@39Z/T3000000D0bJ[9100000060<VZb@0300000039Z/T0bJ[900d0
bJ[9100000040<VZb@0300000039Z/T0000000<000001039Z/T3000000<0bJ[9100000040<VZb@80
00002P39Z/T00`000000bJ[90<VZb@02000000<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000
<c<c03<c<`0403<c<`0300000034ZC<0a:Tc00L0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000
<c<c03<c<`0303<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01@34ZC<00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo000S0?ooo`030000003oool0oooo00P0oooo
00<0000003<c<`0c<c<06`0c<c<400000100bJ[90`0000060<VZb@<000001P39Z/T00`000000bJ[9
0<VZb@0=0<VZb@D000001@39Z/T5000000<0bJ[90`0000030<VZb@@000002P39Z/T2000000@0bJ[9
00<000000<VZb@39Z/T01P39Z/T2000000030<BY<`000000a:Tc00<0a:Tc00<0000003<c<`0c<c<0
100c<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<0
0P34ZC<00`000000a:Tc0<BY<`050<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
;@3oool002<0oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`0H03<c<`<000004039
Z/T4000000D0bJ[9100000050<VZb@0300000039Z/T0bJ[900d0bJ[91@0000050<VZb@@000001039
Z/T3000000<0bJ[91000000@0<VZb@8000003@39Z/T2000000@0a:Tc00<0000003<c<`0c<c<0100c
<c<00`000000a:Tc0<BY<`0<0<BY<`030000000c<c<0<c<c00<0<c<c00<000000<BY<`34ZC<00P34
ZC<00`000000a:Tc0<BY<`050<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3o
ool002<0oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`0D03<c<`@000004039Z/T3
000000D0bJ[9100000050<VZb@8000003P39Z/T5000000D0bJ[9100000040<VZb@<000000`39Z/T4
00000100bJ[900<000000<VZb@39Z/T00`39Z/T2000000d0bJ[90P0000020<BY<`030000000c<c<0
<c<c00@0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc0<BY<`060<BY<`030000000c<c<0
<c<c00<0<c<c00<000000<BY<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0]0?ooo`008P3oool00`000000oooo0?ooo`08
0?ooo`030000000c<c<0<c<c0140<c<c1000000@0<VZb@<000001P39Z/T3000000H0bJ[900<00000
0<VZb@39Z/T03039Z/T5000000D0bJ[9100000040<VZb@<000000`39Z/T400000100bJ[900<00000
0<VZb@39Z/T02@39Z/T2000000d0bJ[90`00000603<c<`0300000034ZC<0a:Tc00<0a:Tc00<00000
0<BY<`34ZC<01P34ZC<00`000000<c<c03<c<`0303<c<`0300000034ZC<0a:Tc0080a:Tc00D00000
0<BY<`34ZC<0a:Tc000000030<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3o
ool00280oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c<`0>03<c<`<000004039Z/T3
000000H0bJ[9100000050<VZb@0300000039Z/T0bJ[900d0bJ[9100000050<VZb@@000001039Z/T3
000000<0bJ[91000000@0<VZb@0300000039Z/T0bJ[900l0bJ[90P00000;0<VZb@<000001P0c<c<0
0`000000a:Tc0<BY<`030<BY<`0300000034ZC<0a:Tc00H0a:Tc00<0000003<c<`0c<c<00`0c<c<0
0`000000a:Tc0<BY<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000000`34ZC<00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02d0oooo000R0?ooo`030000003oool0oooo00P0oooo00<00000
03<c<`0c<c<02P0c<c<400000100bJ[90`0000050<VZb@@000001@39Z/T00`000000bJ[90<VZb@0=
0<VZb@D000001039Z/T4000000@0bJ[90`0000030<VZb@@000004039Z/T00`000000bJ[90<VZb@0>
0<VZb@0300000039Z/T0bJ[900@0bJ[90P0000050<VZb@@000002@0c<c<00`000000a:Tc0<BY<`03
0<BY<`0300000034ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc0000000503<c<`0300000034
ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc000000030<BY<`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0;03oool00280oooo00<000000?ooo`3oool0203oool00`000000<c<c03<c
<`0703<c<`<000004039Z/T3000000H0bJ[90`0000050<VZb@0300000039Z/T0bJ[900d0bJ[91@00
00030<VZb@D000001039Z/T3000000<0bJ[91000000@0<VZb@0300000039Z/T0bJ[900h0bJ[900<0
00000<VZb@39Z/T02P39Z/T5000000<0a:Tc2P0c<c<00`000000a:Tc0<BY<`030<BY<`0300000034
ZC<0a:Tc0080a:Tc00D000000<BY<`34ZC<0a:Tc0000000503<c<`0300000034ZC<0a:Tc0080a:Tc
00<000000<BY<`34ZC<01@34ZC<00`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo
000R0?ooo`030000003oool0oooo00P0oooo00<0000003<c<`0c<c<00`0c<c<4000000l0bJ[90`00
00060<VZb@@000001039Z/T00`000000bJ[90<VZb@0=0<VZb@D000001039Z/T4000000040<VZb@00
0000bJ[90<VZb@<000000`39Z/T4000000l0bJ[90P00000@0<VZb@0300000039Z/T0bJ[900/0bJ[9
1`0000040<BY<`030000000c<c<0<c<c00L0<c<c00<000000<BY<`34ZC<00`34ZC<00`000000a:Tc
0<BY<`020<BY<`0500000034ZC<0a:Tc0<BY<`0000001@0c<c<00`000000a:Tc0<BY<`020<BY<`03
00000034ZC<0a:Tc00D0a:Tc00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`00
8P3oool00`000000oooo0?ooo`080?ooo`030000000c<c<0000000<000003`39Z/T3000000H0bJ[9
100000050<VZb@0300000039Z/T0bJ[900`0bJ[91@0000050<VZb@<000001039Z/T400000080bJ[9
1000000?0<VZb@8000004039Z/T00`000000bJ[90<VZb@0;0<VZb@D000001039Z/T400000080a:Tc
00<0000003<c<`0c<c<01@0c<c<4000000@0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc
0<BY<`020<BY<`030000000c<c<0<c<c0080<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc
0<BY<`060<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00280oooo00<0
00000?ooo`3oool0203oool200000100bJ[90`0000060<VZb@<000001@39Z/T00`000000bJ[90<VZ
b@0<0<VZb@D000001@39Z/T3000000@0bJ[90`0000030<VZb@@000003`39Z/T200000100bJ[900<0
00000<VZb@0000000`0000070<VZb@H000001@39Z/T2000000<0bJ[91@00000303<c<`@000000`39
Z/T300000080a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`020<BY<`030000000c
<c<0<c<c0080<c<c00<000000<BY<`34ZC<00P34ZC<00`000000a:Tc0<BY<`060<BY<`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;03oool00280oooo00<000000?ooo`3oool02P3oool2
000000X0bJ[90`0000060<VZb@@000001039Z/T00`000000bJ[90<VZb@0=0<VZb@@000001@39Z/T3
000000D0bJ[90P0000030<VZb@@000003`39Z/T2000000l0bJ[90P0000000`39Z/T0000000000003
000000<0bJ[90P0000000`39Z/T0000000000004000000D0bJ[90P0000050<VZb@0400000039Z/T0
bJ[90<VZb@H000002@39Z/T4000000@0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c
<`0203<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01P34ZC<00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02`0oooo000R0?ooo`030000003oool0oooo00`0oooo0`000003
0<VZb@<000001P39Z/T4000000@0bJ[900<000000<VZb@39Z/T03@39Z/T5000000@0bJ[90`000005
0<VZb@8000000`39Z/T4000000l0bJ[90`00000>0<VZb@80000000<0bJ[90000000000000`000009
0<VZb@<000000P39Z/T00`000000bJ[90<VZb@02000000D0bJ[900@000000<VZb@39Z/T0bJ[91P00
00020<VZb@8000002`39Z/T3000000<0a:Tc00<000000<BY<`34ZC<00P34ZC<00`000000<c<c03<c
<`0303<c<`0500000034ZC<0a:Tc0<BY<`0000002034ZC<00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02`0oooo000R0?ooo`030000003oool0oooo00l0oooo0`0000060<VZb@<000001039
Z/T00`000000bJ[90<VZb@0=0<VZb@D000001039Z/T3000000D0bJ[90P0000030<VZb@@000003`39
Z/T3000000h0bJ[90P0000000`39Z/T0000000000003000000l0bJ[90`0000020<VZb@0300000039
Z/T0bJ[9008000000`39Z/T5000000T0bJ[90P0000040<VZb@@000000`39Z/T3000000030<BY<`00
0000a:Tc00<0a:Tc00<0000003<c<`0c<c<00`0c<c<01@000000a:Tc0<BY<`34ZC<0000000P0a:Tc
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`008P3oool00`000000oooo0?oo
o`0B0?ooo`H000004`39Z/T5000000@0bJ[90`0000050<VZb@8000000`39Z/T4000000l0bJ[90`00
000>0<VZb@80000000<0bJ[90000000000000`00000:0<VZb@0300000039Z/T0bJ[900L0bJ[91@00
00000`39Z/T000000<VZb@05000000l0bJ[9100000090<VZb@<000001034ZC<00`000000<c<c03<c
<`0303<c<`0300000034ZC<0a:Tc00X0a:Tc00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0/0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`H000004039Z/T5000000@0bJ[90`000004
0<VZb@<000000`39Z/T4000000l0bJ[90`00000>0<VZb@0300000039Z/T0bJ[90080bJ[90`000005
0<VZb@0300000039Z/T0bJ[900P0bJ[900@000000<VZb@39Z/T0bJ[90`0000040<VZb@H000003P39
Z/T4000000<0bJ[90P0000080<VZb@0300000039Z/T0bJ[900<000000P34ZC<00`000000<c<c03<c
<`0303<c<`0300000034ZC<0a:Tc0080a:Tc00<000000<BY<`34ZC<01@34ZC<00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02`0oooo000Q0?ooo`030000003oool0oooo00h0oooo10000006
0?ooo`<000002@39Z/T5000000@0bJ[90`0000050<VZb@8000000`39Z/T4000000l0bJ[90`00000=
0<VZb@8000002P39Z/T2000000H0bJ[90P0000070<VZb@<000002P39Z/T3000000/0bJ[910000009
0<VZb@80000000<0bJ[90000000000002039Z/T4000000D0<c<c00<000000<BY<`34ZC<00P34ZC<0
0`000000a:Tc0<BY<`050<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool0
0240oooo00<000000?ooo`3oool02P3oool4000000d0oooo0P0000030<VZb@@000000`3oool00`00
0000<c<c00000002000000D0bJ[90P0000030<VZb@@000003`39Z/T3000000d0bJ[90P00000<0<VZ
b@H000001`39Z/T5000000D0bJ[900<000000<VZb@39Z/T02039Z/T3000000@0bJ[91000000=0<VZ
b@0300000039Z/T0bJ[9008000002P39Z/T3000000D0<c<c00<000000<BY<`34ZC<00P34ZC<00`00
0000a:Tc0<BY<`050<BY<`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00240
oooo00<000000?ooo`3oool01`3oool3000001<0oooo0`0000070?ooo`030000000c<c<0<c<c0080
<c<c0`0000030<VZb@@000003`39Z/T3000000d0bJ[90P00000<0<VZb@D0000000@0bJ[900000039
Z/T0bJ[9100000000`39Z/T0000000000002000000030<VZb@000000000000P0bJ[90P0000040<VZ
b@8000001039Z/T3000000d0bJ[90P0000080<VZb@8000000`39Z/T5000000P0<c<c00<000000<BY
<`34ZC<00P34ZC<01@000000a:Tc0<BY<`34ZC<0000000<0a:Tc00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0/0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`@00000803oool00`00
0000<c<c03<c<`0303<c<`D000003`39Z/T3000000d0bJ[90P00000;0<VZb@H000001039Z/T20000
00040<VZb@000000bJ[90<VZb@@000001P39Z/T2000000L0bJ[90`00000:0<VZb@8000002039Z/T0
0`000000bJ[90<VZb@0<0<VZb@@000000`34ZC<:03<c<`0300000034ZC<0a:Tc0080a:Tc00D00000
0<BY<`34ZC<0a:Tc000000030<BY<`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3o
ool00240oooo00<000000?ooo`0000000`00000T0?ooo`030000000c<c<0000000<000004039Z/T3
000000d0bJ[90P00000;0<VZb@D000001@39Z/T2000000D0bJ[90`0000020<VZb@@000001`39Z/T0
0`000000bJ[900000002000000D0bJ[900<000000<VZb@39Z/T02039Z/T2000000030<VZb@000000
000000d0bJ[91@0000020<VZb@<000000P34ZC<803<c<`@000000`34ZC<01@000000a:Tc0<BY<`34
ZC<0000000<0a:Tc00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`008@3oool2
000002P0oooo0P00000?0<VZb@@000003039Z/T3000000/0bJ[91@0000040<VZb@<000001039Z/T3
000000<0bJ[9100000040<VZb@<0000000<0bJ[90000000000000P0000000`39Z/T0000000000008
0<VZb@0300000039Z/T0bJ[900<0bJ[90P0000030<VZb@8000002@39Z/T5000000<0bJ[90P000004
0<VZb@<000000`0c<c<5000000<0bJ[90`0000000`34ZC<000000<BY<`070<BY<`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:`3oool002<0oooo0`00000W0?ooo`<000002039Z/T40000
00`0bJ[90`00000;0<VZb@D000001039Z/T2000000D0bJ[90P0000030<VZb@D000002@39Z/T40000
00L0bJ[900<000000<VZb@39Z/T01@39Z/T3000000T0bJ[90P0000020<VZb@D000001039Z/T00`00
0000bJ[90<VZb@030<VZb@8000000`39Z/T5000000X0bJ[90`0000080<BY<`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0:`3oool002H0oooo0`00000W0?ooo`8000000P39Z/T4000000`0
bJ[90`00000:0<VZb@D000001@39Z/T2000000D0bJ[90P0000030<VZb@D000003@39Z/T6000000L0
bJ[900<000000<VZb@0000000P0000040<VZb@8000002039Z/T3000000@0bJ[90P0000050<VZb@04
00000039Z/T0bJ[90<VZb@H000000`39Z/T2000000/0bJ[90`0000060<BY<`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0:`3oool002T0oooo0`00000V0?ooo`<000002`39Z/T3000000X0
bJ[91@0000040<VZb@<000001039Z/T3000000<0bJ[91000000>0<VZb@<000001`39Z/T300000003
0<VZb@00000000000080000000<0bJ[90000000000001`39Z/T2000000030<VZb@000000000000<0
00000P39Z/T2000000D0bJ[90P0000030<VZb@D000002P39Z/T2000000/0bJ[90`0000040<BY<`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool002`0oooo0`00000V0?ooo`<00000
1039Z/T3000000X0bJ[91@0000040<VZb@8000000`39Z/T010000000bJ[90000000000030<VZb@D0
00003@39Z/T3000000d0bJ[9100000070<VZb@0400000039Z/T0bJ[90<VZb@H000000P39Z/T00`00
0000bJ[90<VZb@030<VZb@8000000`39Z/T5000000h0bJ[900<000000<VZb@39Z/T00P00000:0<VZ
b@@000000P34ZC<00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo000_0?ooo`<0
00009P3oool3000000X0bJ[91@0000040<VZb@8000001@39Z/T200000080bJ[91P00000=0<VZb@<0
00003@39Z/T00`000000bJ[90<VZb@050<VZb@8000001039Z/T5000000<0bJ[90P0000040<VZb@80
00000`39Z/T6000000d0bJ[900<000000<VZb@39Z/T01`39Z/T2000000<0bJ[9100000040<VZb@@0
00001`3oool00`000000oooo0?ooo`0[0?ooo`00<P3oool3000002D0oooo0`0000040<VZb@@00000
00@0oooo0000000c<c<0<c<c0`0000040<VZb@<000000`39Z/T4000000d0bJ[90`00000=0<VZb@80
00003039Z/T5000000<0bJ[90P0000050<VZb@8000000`39Z/T5000000d0bJ[900<000000<VZb@39
Z/T03039Z/T4000000X0bJ[90`0000070?ooo`030000003oool0oooo02/0oooo000e0?ooo`<00000
9@3oool4000000D0oooo00<0000003<c<`0c<c<00P0c<c<4000000<0bJ[91000000=0<VZb@<00000
3@39Z/T00`000000bJ[90<VZb@0:0<VZb@D000001039Z/T00`000000bJ[90<VZb@030<VZb@800000
0`39Z/T5000000d0bJ[90P00000=0<VZb@@000001@39Z/T2000000<0bJ[91@00000:0?ooo`030000
003oool0oooo02/0oooo000h0?ooo`<00000:`3oool00`000000<c<c03<c<`0403<c<`D000003039
Z/T3000000d0bJ[90P00000;0<VZb@D000001039Z/T400000080bJ[90P0000030<VZb@H000003039
Z/T2000000d0bJ[91000000:0<VZb@D000003`3oool00`000000oooo0?ooo`0[0?ooo`00>`3oool3
000002P0oooo00<0000003<c<`0c<c<01000000=0<VZb@<000003@39Z/T00`000000bJ[90<VZb@09
0<VZb@D000001039Z/T2000000D0bJ[90P0000000`39Z/T000000<VZb@05000000`0bJ[90P00000>
0<VZb@<000002P39Z/T5000000@0oooo0P00000>0?ooo`030000003oool0oooo02/0oooo000n0?oo
o`<000009@3oool3000000`0bJ[90`00000=0<VZb@8000002`39Z/T4000000D0bJ[900<000000<VZ
b@39Z/T00`39Z/T2000000<0bJ[91@00000<0<VZb@<000003@39Z/T2000000/0bJ[91@00000;0?oo
o`800000303oool00`000000oooo0?ooo`0[0?ooo`00@@3oool3000002@0oooo0`0000060<VZb@80
00003P39Z/T00`000000bJ[90<VZb@090<VZb@D000001039Z/T2000000<0bJ[90`0000030<VZb@D0
00003@39Z/T2000000d0bJ[90P00000:0<VZb@H000004P3oool2000000/0oooo00<000000?ooo`3o
ool0:P3oool004@0oooo0`00000T0?ooo`@000003@39Z/T2000000X0bJ[91@0000040<VZb@800000
1039Z/T3000000<0bJ[91@00000<0<VZb@8000003@39Z/T2000000X0bJ[91@00000J0?ooo`800000
2@3oool00`000000oooo0?ooo`0Z0?ooo`00A`3oool3000002@0oooo0P0000070<VZb@8000002P39
Z/T5000000D0bJ[90P0000040<VZb@8000000`39Z/T5000000`0bJ[90P00000=0<VZb@8000002P39
Z/T500000240oooo0P0000070?ooo`030000003oool0oooo02X0oooo001:0?ooo`<000008`3oool5
000000X0bJ[9100000050<VZb@8000001039Z/T2000000<0bJ[91@00000<0<VZb@<000003039Z/T2
000000X0bJ[91@00000X0?ooo`8000001@3oool00`000000oooo0?ooo`0Z0?ooo`00C@3oool30000
02<0oooo0`0000040<VZb@D000000`0c<c<3000000@0bJ[90`0000030<VZb@D000002`39Z/T30000
00`0bJ[90P00000:0<VZb@D00000;`3oool2000000<0oooo00<000000?ooo`3oool0:P3oool00500
oooo0`00000S0?ooo`@00000103oool00`000000<c<c03<c<`0303<c<`<000000`39Z/T5000000/0
bJ[90`00000<0<VZb@8000002P39Z/T5000003H0oooo0P0000000`3oool000000?ooo`0[0?ooo`00
D`3oool3000002P0oooo00<0000003<c<`0c<c<01@0c<c<4000000/0bJ[91000000;0<VZb@800000
2P39Z/T5000003`0oooo0`00000/0?ooo`00EP3oool4000002@0oooo00<0000003<c<`0c<c<01@00
000:0<VZb@@000002`39Z/T2000000X0bJ[91@00000l0?ooo`D00000;`3oool005X0oooo0`00000Q
0?ooo`<000002P39Z/T4000000/0bJ[900<000000<VZb@39Z/T02@39Z/T5000003/0oooo1P00000d
0?ooo`00G@3oool300000200oooo0`0000030<VZb@D000002P39Z/T00`000000bJ[90<VZb@080<VZ
b@H00000>`3oool5000003X0oooo001P0?ooo`<00000803oool4000000T0bJ[900<000000<VZb@39
Z/T02039Z/T5000003`0oooo1@00000o0?ooo`00H`3oool300000200oooo100000000`39Z/T00000
0<VZb@090<VZb@D00000>`3oool6000004@0oooo001V0?ooo`<000008@3oool3000000@0bJ[91@00
000k0?ooo`D00000BP3oool006T0oooo0`00000Q0?ooo`@00000>`3oool5000004l0oooo001/0?oo
o`<000007`3oool00`000000oooo0?ooo`0e0?ooo`H00000E03oool006l0oooo0`00000L0?ooo`03
0000003oool0oooo0300oooo1@00001J0?ooo`00LP3oool3000001T0oooo00<000000?ooo`3oool0
:`3oool5000005l0oooo001e0?ooo`<000005P3oool00`000000oooo0?ooo`0U0?ooo`H00000I03o
ool007P0oooo0`00000C0?ooo`030000003oool0oooo0200oooo1@00001Z0?ooo`00N`3oool30000
0100oooo00<000000?ooo`3oool06`3oool5000006l0oooo001n0?ooo`<000003@3oool00`000000
oooo0?ooo`0E0?ooo`H00000M03oool00840oooo0`00000:0?ooo`030000003oool0oooo0100oooo
1@00001j0?ooo`00Q03oool3000000L0oooo00<000000?ooo`3oool02`3oool5000007l0oooo0027
0?ooo`<00000103oool00`000000oooo0?ooo`050?ooo`H00000Q03oool008X0oooo0`000000103o
ool000000?ooo`3oool5000008X0oooo002=0?ooo`@00000S`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics3D[radObjDrw[all]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.10126 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0625683 1.19052 1.11022e-16 1.19052 [
[ 0 0 0 0 ]
[ 1 1.10126 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07154 .22539 m
0 .7437 L
s
0 .7437 m
.45735 1.10126 L
s
.45735 1.10126 m
.46572 .63254 L
s
.46572 .63254 m
.07154 .22539 L
s
.62133 0 m
.94403 .48064 L
s
.94403 .48064 m
1 .97006 L
s
1 .97006 m
.63662 .53741 L
s
.63662 .53741 m
.62133 0 L
s
.07154 .22539 m
0 .7437 L
s
0 .7437 m
.63662 .53741 L
s
.63662 .53741 m
.62133 0 L
s
.62133 0 m
.07154 .22539 L
s
.46572 .63254 m
.94403 .48064 L
s
.94403 .48064 m
1 .97006 L
s
1 .97006 m
.45735 1.10126 L
s
.45735 1.10126 m
.46572 .63254 L
s
0 0 m
1 0 L
1 1.10126 L
0 1.10126 L
closepath
clip
newpath
.001 w
.97748 .95094 m .92657 .4855 L .46837 .63107 L p 0 .183 .563 r
F P
0 g
s
.46837 .63107 m .4607 1.0778 L .97748 .95094 L p 0 .183 .563 r
F P
0 g
s
.4607 1.0778 m .46837 .63107 L .40725 .56781 L p 0 .343 .514 r
F P
0 g
s
.40725 .56781 m .46837 .63107 L .92657 .4855 L p 0 .366 .897 r
F P
0 g
s
.40725 .56781 m .39175 1.02294 L .4607 1.0778 L p 0 .343 .514 r
F P
0 g
s
.86567 .90102 m .83361 .51425 L .44931 .63638 L p 0 .352 .276 r
F P
0 g
s
.44931 .63638 m .441 1.01027 L .86567 .90102 L p 0 .352 .276 r
F P
0 g
s
.441 1.01027 m .44931 .63638 L .44931 .63638 L p 0 .687 .252 r
F P
0 g
s
.40725 .56781 m .45024 .59436 L .44429 .63798 L 0 .176 .552 r
F
.39175 1.02294 m .40443 .65065 L p .44429 .63798 L F P
0 g
s
.40443 .65065 m .40725 .56781 L p .44429 .63798 L 0 .176 .552 r
F P
0 g
s
.44931 .63638 m .83361 .51425 L p .83361 .51425 L 0 .74 .453 r
F P
0 g
s
.44931 .63638 m .44931 .63638 L p .83361 .51425 L 0 .74 .453 r
F P
0 g
s
.441 1.01027 m .441 1.01027 L .44931 .63638 L 0 .687 .252 r
F
.83361 .51425 m .86567 .90102 L p .86567 .90102 L 0 .678 .188 r
F P
0 g
s
.44931 .63638 m .86177 .85403 L .441 1.01027 L 0 .176 .552 r
F
.441 1.01027 m .39175 1.02294 L p .45024 .59436 L F P
0 g
s
.42166 .60813 m .41042 .98512 L .441 1.01027 L p 0 .687 .252 r
F P
0 g
s
.86567 .90102 m .441 1.01027 L .441 1.01027 L p 0 .773 .474 r
F P
0 g
s
.86567 .90102 m .86567 .90102 L .441 1.01027 L 0 .773 .474 r
F
.86567 .90102 m .441 1.01027 L p .441 1.01027 L 0 .176 .552 r
F P
0 g
s
.86177 .85403 m .86567 .90102 L .441 1.01027 L 0 .176 .552 r
F
.86567 .90102 m .86567 .90102 L .441 1.01027 L F
.44931 .63638 m .42166 .60813 L p .441 1.01027 L 0 .687 .252 r
F P
0 g
s
.41042 .98512 m .84018 .87223 L .86567 .90102 L p 0 .773 .474 r
F P
0 g
s
.441 1.01027 m .41042 .98512 L p .86567 .90102 L 0 .773 .474 r
F P
0 g
s
.83361 .51425 m .83361 .51425 L p .86567 .90102 L 0 .678 .188 r
F P
0 g
s
.49485 .62191 m .86129 .84823 L .44931 .63638 L 0 .176 .552 r
F
.86129 .84823 m .92292 .88629 L .86177 .85403 L F
.86129 .84823 m .86177 .85403 L .44931 .63638 L F
.45024 .59436 m .49485 .62191 L .44931 .63638 L F
.92657 .4855 m .87671 .4123 L .40725 .56781 L p 0 .366 .897 r
F P
0 g
s
.40725 .56781 m .87671 .4123 L .92292 .88629 L p 0 .176 .552 r
F P
0 g
s
.83361 .51425 m .81012 .48232 L .42166 .60813 L p 0 .74 .453 r
F P
0 g
s
.42166 .60813 m .44931 .63638 L p .83361 .51425 L 0 .74 .453 r
F P
0 g
s
.86567 .90102 m .84018 .87223 L .81012 .48232 L p 0 .678 .188 r
F P
0 g
s
.81012 .48232 m .83361 .51425 L p .86567 .90102 L 0 .678 .188 r
F P
0 g
s
.92292 .88629 m .86567 .90102 L p .86177 .85403 L 0 .176 .552 r
F P
0 g
s
.42166 .60813 m .81012 .48232 L .84018 .87223 L p 0 .345 .274 r
F P
0 g
s
.8982 .85699 m .85426 .37935 L .37983 .53942 L p 0 .173 .547 r
F P
0 g
s
.84018 .87223 m .41042 .98512 L .42166 .60813 L p 0 .345 .274 r
F P
0 g
s
.37983 .53942 m .36064 .9982 L .8982 .85699 L p 0 .173 .547 r
F P
0 g
s
.36064 .9982 m .37983 .53942 L .31275 .46999 L p 0 .343 .514 r
F P
0 g
s
.31275 .46999 m .37983 .53942 L .85426 .37935 L p 0 .366 .897 r
F P
0 g
s
.87671 .4123 m .92657 .4855 L .97748 .95094 L p 0 .337 .351 r
F P
0 g
s
.31275 .46999 m .28409 .93729 L .36064 .9982 L p 0 .343 .514 r
F P
0 g
s
.7772 .80108 m .75241 .40385 L .35393 .53891 L p 0 .328 .267 r
F P
0 g
s
.83706 .78454 m .8982 .85699 L p .34292 .9296 L 0 .387 .947 r
F P
0 g
s
.28409 .93729 m .33514 .92319 L .34292 .9296 L 0 .387 .947 r
F
.83706 .78454 m .83706 .78454 L p .7772 .80108 L F P
0 g
s
.35393 .53891 m .75241 .40385 L p .75241 .40385 L 0 .74 .453 r
F P
0 g
s
.31275 .46999 m .35603 .49596 L .34874 .54067 L 0 .164 .535 r
F
.30756 .55463 m .31275 .46999 L p .34874 .54067 L F P
0 g
s
.35393 .53891 m .35393 .53891 L p .75241 .40385 L 0 .74 .453 r
F P
0 g
s
.33514 .92319 m .35393 .53891 L .35393 .53891 L p 0 .687 .252 r
F P
0 g
s
.33514 .92319 m .33514 .92319 L .35393 .53891 L 0 .687 .252 r
F
.33514 .92319 m .7772 .80108 L .34292 .9296 L 0 .387 .947 r
F
.7772 .80108 m .77793 .8019 L .34292 .9296 L F
.8982 .85699 m .36064 .9982 L .28409 .93729 L p F P
0 g
s
.64569 .89135 m .64566 .89028 L .60403 .84902 L p .97 0 .218 r
F P
0 g
s
.35393 .53891 m .33514 .92319 L p .60342 .81518 L 0 .328 .267 r
F P
0 g
s
.33514 .92319 m .33514 .92319 L p .60342 .81518 L 0 .328 .267 r
F P
0 g
s
.7581 .86126 m .75804 .86017 L .64566 .89028 L p .554 0 .271 r
F P
0 g
s
.60342 .81518 m .60342 .81518 L .71618 .76979 L 0 .328 .267 r
F
.33514 .92319 m .60342 .81518 L .60342 .81518 L F
.60121 .69207 m .60342 .81518 L .71618 .76979 L F
.71587 .76309 m .71618 .76979 L .72254 .76722 L F
.60121 .69207 m .71618 .76979 L .71587 .76309 L F
.72254 .76722 m .71618 .76979 L .7772 .80108 L F
.33514 .92319 m .60403 .84891 L p .60342 .81518 L F P
0 g
s
.35393 .53891 m .60342 .81518 L .60121 .69207 L 0 .328 .267 r
F
.28409 .93729 m .30756 .55463 L p .34874 .54067 L 0 .164 .535 r
F P
0 g
s
.33514 .92319 m .28409 .93729 L p .34874 .54067 L 0 .164 .535 r
F P
0 g
s
.35603 .49596 m .35393 .53891 L .34874 .54067 L 0 .164 .535 r
F
.35393 .53891 m .33514 .92319 L .34874 .54067 L F
.28409 .93729 m .33514 .92319 L .28409 .93729 L 0 .387 .947 r
F
.35603 .49596 m .60032 .64251 L .33514 .92319 L 0 .164 .535 r
F
.85426 .37935 m .79913 .29842 L .31275 .46999 L p 0 .366 .897 r
F P
0 g
s
.79913 .29842 m .83706 .78454 L p .7738 .74659 L 0 .164 .535 r
F P
0 g
s
.31275 .46999 m .74697 .31682 L p .7738 .74659 L 0 .164 .535 r
F P
0 g
s
.75241 .40385 m .7772 .80108 L p .7772 .80108 L 0 .678 .188 r
F P
0 g
s
.75241 .40385 m .75241 .40385 L p .7772 .80108 L 0 .678 .188 r
F P
0 g
s
.74697 .31682 m .79913 .29842 L p .7738 .74659 L 0 .164 .535 r
F P
0 g
s
.72862 .40961 m .72633 .3684 L .32343 .50774 L p 0 .74 .453 r
F P
0 g
s
.72633 .3684 m .73111 .40901 L p .75241 .40385 L 0 .74 .453 r
F P
0 g
s
.60032 .64251 m .7738 .74659 L .60342 .81518 L 0 .164 .535 r
F
.71618 .76979 m .60342 .81518 L .71843 .81731 L 0 .328 .267 r
F
.60403 .84891 m .71843 .81731 L p .60342 .81518 L F P
0 g
s
.71843 .81731 m .7772 .80108 L p .71618 .76979 L 0 .328 .267 r
F P
0 g
s
.71843 .81731 m .60403 .84891 L p .71671 .781 L 0 .164 .535 r
F P
0 g
s
.7738 .74659 m .60403 .84891 L .60342 .81518 L 0 .164 .535 r
F
.33514 .92319 m .7772 .80108 L .33514 .92319 L 0 .387 .947 r
F
.33514 .92319 m .7772 .80108 L p .7772 .80108 L F P
0 g
s
.60403 .84891 m .33514 .92319 L p .60342 .81518 L 0 .164 .535 r
F P
0 g
s
.60032 .64251 m .60342 .81518 L .33514 .92319 L 0 .164 .535 r
F
.7772 .80108 m .71843 .81731 L p .7738 .74659 L F P
0 g
s
.7738 .74659 m .71843 .81731 L .71671 .781 L 0 .164 .535 r
F
.30106 .89516 m .335 .92308 L p .335 .92308 L 0 .687 .252 r
F P
0 g
s
.32343 .50774 m .30106 .89516 L p .335 .92308 L 0 .687 .252 r
F P
0 g
s
.30106 .89516 m .30106 .89516 L p .335 .92308 L 0 .687 .252 r
F P
0 g
s
.20864 .36222 m .16396 .84172 L .24946 .90974 L p 0 .343 .514 r
F P
0 g
s
.24946 .90974 m .16396 .84172 L p .22563 .83311 L 0 .387 .947 r
F P
0 g
s
.32343 .50774 m .35393 .53891 L p .75241 .40385 L 0 .74 .453 r
F P
0 g
s
.35393 .53891 m .32343 .50774 L p .33514 .92319 L 0 .687 .252 r
F P
0 g
s
.30106 .89516 m .32343 .50774 L p .57151 .66004 L 0 .32 .264 r
F P
0 g
s
.57151 .66004 m .68682 .73083 L .57314 .8183 L 0 .32 .264 r
F
.68902 .78557 m .57314 .8183 L p .68682 .73083 L F P
0 g
s
.74858 .76874 m .68902 .78557 L p .68682 .73083 L 0 .32 .264 r
F P
0 g
s
.57314 .8183 m .30106 .89516 L p .57151 .66004 L 0 .32 .264 r
F P
0 g
s
.32343 .50774 m .72633 .3684 L .74858 .76874 L p 0 .32 .264 r
F P
0 g
s
.25514 .82899 m .54982 .78784 L p .28259 .43877 L 0 .16 .528 r
F P
0 g
s
.25325 .85583 m .24946 .90974 L p .30106 .89516 L 0 .16 .528 r
F P
0 g
s
.57314 .8183 m .68902 .78557 L p .57177 .68553 L 0 .16 .528 r
F P
0 g
s
.28259 .43877 m .57314 .8183 L .57177 .68553 L 0 .16 .528 r
F
.7772 .80108 m .75622 .77738 L p .72633 .3684 L 0 .678 .188 r
F P
0 g
s
.75622 .77738 m .74858 .76874 L .74858 .76874 L p 0 .678 .188 r
F P
0 g
s
.74858 .76874 m .72633 .3684 L p .75622 .77738 L 0 .678 .188 r
F P
0 g
s
.83706 .78454 m .7772 .80108 L p .7738 .74659 L 0 .164 .535 r
F P
0 g
s
.72633 .3684 m .75241 .40385 L p .7772 .80108 L 0 .678 .188 r
F P
0 g
s
.68902 .78557 m .80926 .7516 L p .68469 .67761 L 0 .16 .528 r
F P
0 g
s
.68833 .76849 m .74175 .76103 L .68868 .77718 L 0 .387 .947 r
F
.28259 .43877 m .68902 .78557 L .68469 .67761 L 0 .16 .528 r
F
.68833 .76849 m .68868 .77718 L .30106 .89516 L 0 .387 .947 r
F
.24946 .90974 m .28259 .43877 L .20864 .36222 L p 0 .343 .514 r
F P
0 g
s
.22563 .83311 m .68833 .76849 L .30106 .89516 L 0 .387 .947 r
F
.80926 .7516 m .74858 .76874 L p .74175 .76103 L F P
0 g
s
.74858 .76874 m .30106 .89516 L p .74175 .76103 L 0 .387 .947 r
F P
0 g
s
.30106 .89516 m .74858 .76874 L .7772 .80108 L p 0 .773 .474 r
F P
0 g
s
.7772 .80108 m .71835 .81733 L p .71473 .81342 L 0 .773 .474 r
F P
0 g
s
.71835 .81733 m .33514 .92319 L p .71473 .81342 L 0 .773 .474 r
F P
0 g
s
.33514 .92319 m .30106 .89516 L p .71473 .81342 L 0 .773 .474 r
F P
0 g
s
.80926 .7516 m .77424 .2619 L .28259 .43877 L p 0 .16 .528 r
F P
0 g
s
.20864 .36222 m .28259 .43877 L .77424 .2619 L p 0 .366 .897 r
F P
0 g
s
.77424 .2619 m .71298 .17196 L .20864 .36222 L p 0 .366 .897 r
F P
0 g
s
.67759 .68855 m .66207 .28103 L .24853 .43119 L p 0 .299 .256 r
F P
0 g
s
.74028 .66985 m .80926 .7516 L p .22563 .83311 L 0 .387 .947 r
F P
0 g
s
.16396 .84172 m .2169 .82593 L .22563 .83311 L 0 .387 .947 r
F
.74028 .66985 m .74028 .66985 L p .67759 .68855 L F P
0 g
s
.24853 .43119 m .66207 .28103 L p .66207 .28103 L 0 .74 .453 r
F P
0 g
s
.20864 .36222 m .25204 .38734 L .24316 .43314 L 0 .149 .513 r
F
.20059 .4486 m .20864 .36222 L p .24316 .43314 L F P
0 g
s
.24853 .43119 m .24853 .43119 L p .66207 .28103 L 0 .74 .453 r
F P
0 g
s
.24039 .53281 m .24853 .43119 L .24853 .43119 L p 0 .687 .252 r
F P
0 g
s
.24853 .43119 m .2169 .82593 L p .62171 .65503 L 0 .299 .256 r
F P
0 g
s
.2169 .82593 m .2169 .82593 L p .62171 .65503 L 0 .299 .256 r
F P
0 g
s
.2169 .82593 m .67759 .68855 L p .62171 .65503 L 0 .299 .256 r
F P
0 g
s
.16396 .84172 m .20059 .4486 L p .24316 .43314 L 0 .149 .513 r
F P
0 g
s
.2169 .82593 m .16396 .84172 L p .25204 .38734 L 0 .149 .513 r
F P
0 g
s
.21471 .39663 m .17869 .7945 L .21685 .82589 L p 0 .687 .252 r
F P
0 g
s
.16396 .84172 m .2169 .82593 L .16396 .84172 L 0 .387 .947 r
F
.25204 .38734 m .67545 .63234 L .2169 .82593 L 0 .149 .513 r
F
.67759 .68855 m .2169 .82593 L p .67545 .63234 L F P
0 g
s
.71298 .17196 m .74028 .66985 L p .67545 .63234 L 0 .149 .513 r
F P
0 g
s
.20864 .36222 m .6587 .19244 L p .66207 .28103 L 0 .149 .513 r
F P
0 g
s
.20864 .36222 m .66207 .28103 L .29725 .4135 L 0 .149 .513 r
F
.66207 .28103 m .63296 .24145 L .21471 .39663 L p 0 .74 .453 r
F P
0 g
s
.29725 .4135 m .66207 .28103 L .67545 .63234 L 0 .149 .513 r
F
.66207 .28103 m .67759 .68855 L p .67759 .68855 L 0 .678 .188 r
F P
0 g
s
.66207 .28103 m .66207 .28103 L p .67759 .68855 L 0 .678 .188 r
F P
0 g
s
.6587 .19244 m .71298 .17196 L p .67545 .63234 L 0 .149 .513 r
F P
0 g
s
.63754 .28737 m .63779 .28985 L .66207 .28103 L 0 .74 .453 r
F
.21471 .39663 m .63779 .28985 L .63754 .28737 L F
.21471 .39663 m .24853 .43119 L p .63779 .28985 L F P
0 g
s
.67759 .68855 m .64521 .65197 L .63296 .24145 L p 0 .678 .188 r
F P
0 g
s
.2169 .82593 m .67759 .68855 L .2169 .82593 L 0 .387 .947 r
F
.2169 .82593 m .2169 .82593 L .16396 .84172 L F
.74028 .66985 m .67759 .68855 L p .67545 .63234 L 0 .149 .513 r
F P
0 g
s
.63296 .24145 m .66207 .28103 L p .67759 .68855 L 0 .678 .188 r
F P
0 g
s
.2169 .82593 m .24039 .53281 L p .21471 .39663 L 0 .687 .252 r
F P
0 g
s
.24853 .43119 m .21471 .39663 L p .24039 .53281 L 0 .687 .252 r
F P
0 g
s
.2169 .82593 m .67759 .68855 L p .67759 .68855 L 0 .387 .947 r
F P
0 g
s
.67759 .68855 m .74028 .66985 L p .67759 .68855 L 0 .387 .947 r
F P
0 g
s
.2169 .82593 m .67759 .68855 L .22563 .83311 L 0 .387 .947 r
F
.67759 .68855 m .74028 .66985 L .67841 .68948 L F
.67759 .68855 m .67841 .68948 L .22563 .83311 L F
.75804 .86017 m .64588 .73912 L .52786 .77355 L p .634 0 .474 r
F P
0 g
s
.64591 .74024 m .64588 .73912 L p .68904 .78609 L .975 0 .199 r
F P
0 g
s
.68904 .78609 m .71847 .81812 L .68906 .78655 L .975 0 .199 r
F
.68904 .78609 m .68906 .78655 L .64591 .74024 L F
.52786 .77355 m .52786 .77466 L .57315 .81951 L p .97 0 .218 r
F P
0 g
s
.57315 .81951 m .60405 .85011 L p .57315 .81906 L .97 0 .218 r
F P
0 g
s
.52786 .77355 m .57315 .81951 L .57315 .81906 L .97 0 .218 r
F
.30106 .89516 m .24946 .90974 L p .22563 .83311 L 0 .387 .947 r
F P
0 g
s
.57315 .81882 m .60405 .85011 L .60404 .84971 L .97 0 .218 r
F
.52786 .77355 m .57315 .81906 L .57315 .81882 L F
.57315 .81906 m .60405 .85011 L .57315 .81882 L F
.68904 .78609 m .71843 .81742 L .71847 .81812 L .975 0 .199 r
F
.64588 .73912 m .68902 .78568 L p .68904 .78609 L F P
0 g
s
.68902 .78568 m .71843 .81742 L p .68904 .78609 L .975 0 .199 r
F P
0 g
s
.33514 .92319 m .33514 .92319 L .28409 .93729 L 0 .387 .947 r
F
.60405 .85011 m .64569 .89135 L p .60404 .84971 L .97 0 .218 r
F P
0 g
s
.71847 .81812 m .71843 .81742 L .71847 .81812 L .975 0 .199 r
F
.71843 .81742 m .71843 .81742 L p .71847 .81812 L F P
0 g
s
.75729 .86037 m .75804 .86017 L p .75661 .85963 L .634 0 .474 r
F P
0 g
s
.52786 .77355 m .75729 .86037 L .75661 .85963 L .634 0 .474 r
F
.52786 .77355 m .64566 .89028 L .75729 .86037 L p F P
0 g
s
.7581 .86126 m .71849 .81852 L p .71847 .81812 L .975 0 .199 r
F P
0 g
s
.71849 .81852 m .64591 .74024 L p .71847 .81812 L .975 0 .199 r
F P
0 g
s
.75804 .86017 m .7581 .86126 L p .71847 .81812 L .975 0 .199 r
F P
0 g
s
.71843 .81742 m .75804 .86017 L p .71847 .81812 L .975 0 .199 r
F P
0 g
s
.60403 .84902 m .52786 .77355 L p .60404 .84971 L .97 0 .218 r
F P
0 g
s
.60404 .84971 m .64569 .89135 L .60403 .84902 L .97 0 .218 r
F
.7772 .80108 m .83706 .78454 L p .7772 .80108 L 0 .387 .947 r
F P
0 g
s
.7772 .80108 m .83706 .78454 L .77793 .8019 L 0 .387 .947 r
F
0 0 0 r
.54695 .86468 m
.54696 .86922 L
s
.97748 .95094 m .92292 .88629 L .87671 .4123 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.95911 .78298 m
.95911 .78298 L
s
.95911 .78298 m
.95911 .78298 L
s
.9422 .62834 m
.9422 .62834 L
s
.9422 .62834 m
.9422 .62834 L
s
.9062 .71475 m
.9062 .71475 L
s
.9422 .62834 m
.9422 .62834 L
s
.97748 .95094 m .4607 1.0778 L .39175 1.02294 L p 0 .387 .947 r
F P
0 g
s
0 0 0 r
.3239 .91395 m
.3239 .91395 L
s
.3239 .91395 m
.3239 .91395 L
s
.3239 .91395 m
.3239 .91395 L
s
.3239 .91395 m
.3239 .91395 L
s
.31255 .90461 m
.31255 .90461 L
s
.31255 .90461 m
.31255 .90461 L
s
.31255 .90461 m
.31255 .90461 L
s
.79913 .29842 m .85426 .37935 L .8982 .85699 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.89085 .55731 m
.9422 .62834 L
s
.89085 .55731 m
.89085 .55731 L
s
.9062 .71475 m
.9062 .71475 L
s
.89085 .55731 m
.89085 .55731 L
s
.89085 .55731 m
.89085 .55731 L
s
.87119 .56338 m
.89085 .55731 L
s
.47562 .88439 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.84877 .88194 m
.84877 .88194 L
s
.84877 .88194 m
.84877 .88194 L
s
.84785 .87022 m
.84877 .88194 L
s
.37128 .87533 m
.37128 .87533 L
s
.37128 .87533 m
.37128 .87533 L
s
.37128 .87533 m
.37128 .87533 L
s
.37128 .87533 m
.37128 .87533 L
s
.21471 .39663 m .63296 .24145 L .64521 .65197 L p 0 .288 .252 r
F P
0 g
s
.7088 .63254 m .68525 .13126 L .1753 .32772 L p 0 .144 .505 r
F P
0 g
s
.64521 .65197 m .17869 .7945 L .21471 .39663 L p 0 .288 .252 r
F P
0 g
s
.1753 .32772 m .12516 .81086 L .7088 .63254 L p 0 .144 .505 r
F P
0 g
s
.12516 .81086 m .1753 .32772 L .09336 .24289 L p 0 .343 .514 r
F P
0 g
s
.09336 .24289 m .1753 .32772 L .68525 .13126 L p 0 .366 .897 r
F P
0 g
s
0 0 0 r
.44316 .85502 m
.44316 .85502 L
s
.44316 .85502 m
.44316 .85502 L
s
.44316 .85502 m
.44316 .85502 L
s
.44316 .85502 m
.44316 .85502 L
s
.39175 1.02294 m .92292 .88629 L .97748 .95094 L p 0 .387 .947 r
F P
0 g
s
0 0 0 r
.85538 .86824 m
.85727 .89153 L
s
.85727 .89153 m
.85727 .89153 L
s
.85727 .89153 m
.85727 .89153 L
s
.85727 .89153 m
.85727 .89153 L
s
.7644 .89214 m
.7644 .89214 L
s
.7644 .89214 m
.7644 .89214 L
s
.7644 .89214 m
.7644 .89214 L
s
.7644 .89214 m
.7644 .89214 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.43091 1.00198 m
.43091 1.00198 L
s
.43091 1.00198 m
.43091 1.00198 L
s
.43091 1.00198 m
.43091 1.00198 L
s
.42072 .99359 m
.42072 .99359 L
s
.42072 .99359 m
.42072 .99359 L
s
.42072 .99359 m
.42072 .99359 L
s
.42072 .99359 m
.42072 .99359 L
s
.50791 .99306 m
.50791 .99306 L
s
.57631 .97546 m
.57631 .97546 L
s
.47808 .96735 m
.47808 .96735 L
s
.47808 .96735 m
.47808 .96735 L
s
.47808 .96735 m
.47808 .96735 L
s
.47808 .96735 m
.47808 .96735 L
s
.64623 .95748 m
.64623 .95748 L
s
.79085 .92027 m
.79085 .92027 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.61799 .9306 L
s
.71772 .93908 m
.71772 .93908 L
s
.54725 .94918 m
.54725 .94918 L
s
.54725 .94918 m
.54725 .94918 L
s
.54725 .94918 m
.54725 .94918 L
s
.54725 .94918 m
.54725 .94918 L
s
.47912 .88929 m
.4792 .8834 L
s
.9062 .71475 m
.9062 .71475 L
s
.9062 .71475 m
.95911 .78298 L
s
.95911 .78298 m
.95911 .78298 L
s
.8982 .85699 m .83706 .78454 L .79913 .29842 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.88228 .6839 m
.88228 .6839 L
s
.88228 .6839 m
.88228 .6839 L
s
.88228 .6839 m
.88228 .6839 L
s
.86768 .52527 m
.86768 .52527 L
s
.86768 .52527 m
.86768 .52527 L
s
.88565 .72059 m
.9062 .71475 L
s
.81068 .44642 m
.81068 .44642 L
s
.51676 .83423 m
.51676 .83423 L
s
.51676 .83423 m
.51676 .83423 L
s
.51676 .83423 m
.51676 .83423 L
s
.51676 .83423 m
.51676 .83423 L
s
.51676 .83423 m
.51676 .83423 L
s
.82327 .60782 m
.82327 .60782 L
s
.85727 .89153 m
.85727 .89153 L
s
.85727 .89153 m
.85727 .89153 L
s
.85727 .89153 m
.85727 .89153 L
s
.43091 1.00198 m
.85727 .89153 L
s
.43091 1.00198 m
.43091 1.00198 L
s
.81068 .44642 m
.81068 .44642 L
s
.81068 .44642 m
.86768 .52527 L
s
.86768 .52527 m
.86768 .52527 L
s
.86768 .52527 m
.86768 .52527 L
s
.84877 .88194 m
.84877 .88194 L
s
.84877 .88194 m
.84877 .88194 L
s
.84877 .88194 m
.84877 .88194 L
s
.42072 .99359 m
.68141 .92559 L
s
.42072 .99359 m
.42072 .99359 L
s
.47808 .96735 m
.47808 .96735 L
s
.47808 .96735 m
.47808 .96735 L
s
.47808 .96735 m
.50791 .99306 L
s
.50791 .99306 m
.50791 .99306 L
s
.50791 .99306 m
.50791 .99306 L
s
.71298 .17196 m .77424 .2619 L .80926 .7516 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.82327 .60782 m
.82327 .60782 L
s
.81068 .44642 m
.81068 .44642 L
s
.78797 .45389 m
.81068 .44642 L
s
.54725 .94918 m
.54725 .94918 L
s
.54725 .94918 m
.54725 .94918 L
s
.54725 .94918 m
.57631 .97546 L
s
.57631 .97546 m
.57631 .97546 L
s
.57631 .97546 m
.57631 .97546 L
s
.76777 .79043 m
.76777 .79043 L
s
.76777 .79043 m
.76777 .79043 L
s
.76777 .79043 m
.76777 .79043 L
s
.76777 .79043 m
.76777 .79043 L
s
.76617 .76378 m
.76777 .79043 L
s
.09336 .24289 m .02907 .73441 L .12516 .81086 L p 0 .343 .514 r
F P
0 g
s
.63035 .53958 m .02907 .73441 L .09336 .24289 L p 0 .131 .485 r
F P
0 g
s
0 0 0 r
.58998 .66884 m
.59067 .71447 L
s
.68525 .13126 m .61675 .03072 L .09336 .24289 L p 0 .366 .897 r
F P
0 g
s
.09336 .24289 m .61675 .03072 L .63035 .53958 L p 0 .131 .485 r
F P
0 g
s
0 0 0 r
.75823 .77965 m
.75823 .77965 L
s
.75823 .77965 m
.75823 .77965 L
s
.07383 .39217 m
.07383 .39217 L
s
.07383 .39217 m
.07383 .39217 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.61799 .9306 L
s
.61799 .9306 m
.64623 .95748 L
s
.64623 .95748 m
.64623 .95748 L
s
.64623 .95748 m
.64623 .95748 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.69036 .91159 L
s
.69036 .91159 m
.71772 .93908 L
s
.71772 .93908 m
.71772 .93908 L
s
.71772 .93908 m
.71772 .93908 L
s
.82327 .60782 m
.82327 .60782 L
s
.82327 .60782 m
.88228 .6839 L
s
.88228 .6839 m
.88228 .6839 L
s
.88228 .6839 m
.88228 .6839 L
s
.80926 .7516 m .74028 .66985 L .71298 .17196 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.79651 .57332 m
.79652 .57332 L
s
.79652 .57332 m
.79652 .57332 L
s
.78489 .41075 m
.78489 .41075 L
s
.78489 .41075 m
.78489 .41075 L
s
.7995 .61505 m
.82327 .60782 L
s
.72124 .32271 m
.72124 .32271 L
s
.7644 .89214 m
.7644 .89214 L
s
.7644 .89214 m
.7644 .89214 L
s
.7644 .89214 m
.79085 .92027 L
s
.79085 .92027 m
.79085 .92027 L
s
.79085 .92027 m
.79085 .92027 L
s
.7303 .48794 m
.7303 .48794 L
s
.76777 .79043 m
.76777 .79043 L
s
.76777 .79043 m
.76777 .79043 L
s
.3239 .91395 m
.3239 .91395 L
s
.72124 .32271 m
.72124 .32271 L
s
.72124 .32271 m
.78489 .41075 L
s
.78489 .41075 m
.78489 .41075 L
s
.78489 .41075 m
.78489 .41075 L
s
.75823 .77965 m
.75823 .77965 L
s
.31255 .90461 m
.31255 .90461 L
s
.37128 .87533 m
.37128 .87533 L
s
.37128 .87533 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.40457 .90401 m
.40457 .90401 L
s
.07383 .39217 m
.07383 .39217 L
s
.07383 .39217 m
.07383 .39217 L
s
.61675 .03072 m .68525 .13126 L .7088 .63254 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.69468 .33209 m
.72124 .32271 L
s
.05249 .55533 m
.05249 .55533 L
s
.05249 .55533 m
.05249 .55533 L
s
.64566 .89028 m .64569 .89135 L .7581 .86126 L p .554 0 .271 r
F P
0 g
s
.7581 .86126 m .64569 .89135 L .52786 .77466 L p .634 0 .474 r
F P
0 g
s
0 0 0 r
.68141 .92559 m
.84877 .88194 L
s
.54835 .8643 m
.54835 .8643 L
s
.54835 .8643 m
.54835 .8643 L
s
.54835 .8643 m
.54835 .8643 L
s
.44316 .85502 m
.44316 .85502 L
s
.44316 .85502 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.47562 .88439 m
.47562 .88439 L
s
.68273 .88144 m
.68273 .88144 L
s
.68273 .88144 m
.68273 .88144 L
s
.68273 .88144 m
.68273 .88144 L
s
.18844 .68682 m
.18844 .68682 L
s
.72019 .87141 m
.72019 .87141 L
s
.72019 .87141 m
.72019 .87141 L
s
.72019 .87141 m
.72019 .87141 L
s
.51676 .83423 m
.51676 .83423 L
s
.54835 .8643 m
.54835 .8643 L
s
.54835 .8643 m
.54835 .8643 L
s
.54835 .8643 m
.54835 .8643 L
s
.54835 .8643 m
.54835 .8643 L
s
.61768 .86361 m
.61768 .86361 L
s
.61768 .86361 m
.61768 .86361 L
s
.61768 .86361 m
.61768 .86361 L
s
.52786 .77466 m .64591 .74024 L .7581 .86126 L p .634 0 .474 r
F P
0 g
s
0 0 0 r
.61768 .86361 m
.73146 .83251 L
s
.73146 .83251 m
.73146 .83251 L
s
.7314 .83142 m
.7314 .83142 L
s
.7314 .83142 m
.7314 .83142 L
s
.51676 .83423 m
.54835 .8643 L
s
.67988 .82918 m
.72019 .87141 L
s
.67988 .82918 m
.67988 .82918 L
s
.64174 .83971 m
.68273 .88144 L
s
.64174 .83971 m
.64174 .83971 L
s
.75746 .76624 m
.75823 .77965 L
s
.3239 .91395 m
.59292 .83909 L
s
.31255 .90461 m
.58262 .82889 L
s
.18844 .68682 m
.18844 .68682 L
s
.7303 .48794 m
.7303 .48794 L
s
.7303 .48794 m
.79652 .57332 L
s
.79652 .57332 m
.79652 .57332 L
s
.79652 .57332 m
.79652 .57332 L
s
.58874 .83495 m
.58874 .83495 L
s
.58874 .83495 m
.58874 .83495 L
s
.58874 .83495 m
.58874 .83495 L
s
.73146 .83251 m
.73146 .83251 L
s
.7314 .83142 m
.73146 .83251 L
s
.7314 .83142 m
.7314 .83142 L
s
.67759 .68855 m .2169 .82593 L .17869 .7945 L p 0 .773 .474 r
F P
0 g
s
0 0 0 r
.20432 .81558 m
.20432 .81558 L
s
.20432 .81558 m
.20432 .81558 L
s
.20432 .81558 m
.20432 .81558 L
s
.7088 .63254 m .63035 .53958 L .61675 .03072 L p 0 .337 .351 r
F P
0 g
s
0 0 0 r
.70018 .44909 m
.70018 .44909 L
s
.70018 .44909 m
.70018 .44909 L
s
.69236 .28276 m
.69236 .28276 L
s
.69236 .28276 m
.69236 .28276 L
s
.70243 .49705 m
.7303 .48794 L
s
.07383 .39217 m
.62085 .18383 L
s
.62085 .18383 m
.62085 .18383 L
s
.62535 .35261 m
.62535 .35261 L
s
.10506 .53673 m
.62535 .35261 L
s
.05249 .55533 m
.10506 .53673 L
s
.05249 .55533 m
.05249 .55533 L
s
.20432 .81558 m
.20432 .81558 L
s
.62085 .18383 m
.62085 .18383 L
s
.62085 .18383 m
.69236 .28276 L
s
.69236 .28276 m
.69236 .28276 L
s
.69236 .28276 m
.69236 .28276 L
s
.7088 .63254 m .12516 .81086 L .02907 .73441 L p 0 .387 .947 r
F P
0 g
s
0 0 0 r
.19158 .8051 m
.19158 .8051 L
s
.19158 .8051 m
.19158 .8051 L
s
.19158 .8051 m
.19158 .8051 L
s
.19158 .8051 m
.19158 .8051 L
s
.289 .80443 m
.289 .80443 L
s
.289 .80443 m
.289 .80443 L
s
.289 .80443 m
.289 .80443 L
s
.289 .80443 m
.289 .80443 L
s
.25682 .70028 m
.25975 .65966 L
s
.64996 .79783 m
.67988 .82918 L
s
.64996 .79783 m
.64996 .79783 L
s
.61132 .80874 m
.64174 .83971 L
s
.61132 .80874 m
.61132 .80874 L
s
.58874 .83495 m
.70391 .8028 L
s
.70391 .8028 m
.70391 .8028 L
s
.70386 .80169 m
.70386 .80169 L
s
.70386 .80169 m
.70386 .80169 L
s
.69886 .7963 m
.69894 .79628 L
s
.69894 .79628 m
.75823 .77965 L
s
.70866 .80688 m
.70874 .80686 L
s
.70874 .80686 m
.76777 .79043 L
s
.19158 .8051 m
.19158 .8051 L
s
.289 .80443 m
.289 .80443 L
s
.289 .80443 m
.289 .80443 L
s
.289 .80443 m
.289 .80443 L
s
.55881 .80531 m
.55881 .80531 L
s
.55881 .80531 m
.55881 .80531 L
s
.55881 .80531 m
.55881 .80531 L
s
.70391 .8028 m
.70391 .8028 L
s
.70386 .80169 m
.70391 .8028 L
s
.70386 .80169 m
.70386 .80169 L
s
.17869 .7945 m .64521 .65197 L .67759 .68855 L p 0 .773 .474 r
F P
0 g
s
0 0 0 r
.67541 .77206 m
.67541 .77206 L
s
.67537 .77094 m
.67537 .77094 L
s
.67537 .77094 m
.67537 .77094 L
s
.25162 .77222 m
.289 .80443 L
s
.25162 .77222 m
.25162 .77222 L
s
.25162 .77222 m
.25162 .77222 L
s
.40465 .67812 m
.40688 .61199 L
s
.51625 .73666 m
.51625 .73666 L
s
.51625 .73666 m
.51625 .73666 L
s
.51625 .73666 m
.51625 .73666 L
s
.51625 .73666 m
.51625 .73666 L
s
.32958 .68937 m
.33242 .63611 L
s
.32637 .74938 m
.32637 .74938 L
s
.32637 .74938 m
.32637 .74938 L
s
.4386 .75982 m
.4386 .75982 L
s
.4386 .75982 m
.4386 .75982 L
s
.4386 .75982 m
.4386 .75982 L
s
.4386 .75982 m
.4386 .75982 L
s
.25162 .77222 m
.25162 .77222 L
s
.25162 .77222 m
.25162 .77222 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.32637 .74938 m
.32637 .74938 L
s
.32637 .74938 m
.32637 .74938 L
s
.32637 .74938 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.36288 .7824 m
.36288 .7824 L
s
.64591 .74024 m .52786 .77466 L .52786 .77355 L p .532 0 .26 r
F P
0 g
s
.52786 .77355 m .64588 .73912 L .64591 .74024 L p .532 0 .26 r
F P
0 g
s
0 0 0 r
.55881 .80531 m
.67541 .77206 L
s
.56671 .76221 m
.56671 .76221 L
s
.56671 .76221 m
.56671 .76221 L
s
.56672 .76333 m
.61132 .80874 L
s
.56672 .76333 m
.56672 .76333 L
s
.60605 .75074 m
.60605 .75074 L
s
.60605 .75074 m
.60605 .75074 L
s
.60607 .75186 m
.64996 .79783 L
s
.60607 .75186 m
.60607 .75186 L
s
.67541 .77206 m
.67541 .77206 L
s
.67537 .77094 m
.67541 .77206 L
s
.67537 .77094 m
.67537 .77094 L
s
.56672 .76333 m
.56672 .76333 L
s
.56671 .76221 m
.56672 .76333 L
s
.56671 .76221 m
.56671 .76221 L
s
.4386 .75982 m
.4386 .75982 L
s
.4386 .75982 m
.4386 .75982 L
s
.4386 .75982 m
.4386 .75982 L
s
.60607 .75186 m
.60607 .75186 L
s
.60605 .75074 m
.60607 .75186 L
s
.60605 .75074 m
.60605 .75074 L
s
.51625 .73666 m
.51625 .73666 L
s
.51625 .73666 m
.51625 .73666 L
s
.51625 .73666 m
.51625 .73666 L
s
.02907 .73441 m .63035 .53958 L .7088 .63254 L p 0 .387 .947 r
F P
0 g
s
0 0 0 r
.48168 .70193 m
.51625 .73666 L
s
.48168 .70193 m
.48168 .70193 L
s
.48168 .70193 m
.48168 .70193 L
s
.40304 .72596 m
.4386 .75982 L
s
.40304 .72596 m
.40304 .72596 L
s
.40304 .72596 m
.40304 .72596 L
s
.20432 .81558 m
.48519 .73114 L
s
.48519 .73114 m
.60518 .69507 L
s
.60518 .69507 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.40304 .72596 m
.40304 .72596 L
s
.40304 .72596 m
.40304 .72596 L
s
.59589 .71291 m
.59589 .71291 L
s
.59589 .71291 m
.59589 .71291 L
s
.59589 .71291 m
.59589 .71291 L
s
.59589 .71291 m
.59589 .71291 L
s
.48168 .70193 m
.48168 .70193 L
s
.48168 .70193 m
.48168 .70193 L
s
.65614 .66432 m
.65614 .66432 L
s
.65564 .64878 m
.65614 .66432 L
s
.65614 .66432 m
.65614 .66432 L
s
.66584 .64567 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.66694 .67651 m
.66694 .67651 L
s
.56238 .67728 m
.56238 .67728 L
s
.56238 .67728 m
.56238 .67728 L
s
.65614 .66432 m
.65614 .66432 L
s
.5941 .68312 m
.65614 .66432 L
s
.47358 .71964 m
.5941 .68312 L
s
.19158 .8051 m
.47358 .71964 L
s
.62535 .35261 m
.62535 .35261 L
s
.62535 .35261 m
.70018 .44909 L
s
.70018 .44909 m
.70018 .44909 L
s
.70018 .44909 m
.70018 .44909 L
s
.56238 .67728 m
.56238 .67728 L
s
.56238 .67728 m
.56238 .67728 L
s
.56238 .67728 m
.59589 .71291 L
s
.59589 .71291 m
.59589 .71291 L
s
.59589 .71291 m
.59589 .71291 L
s
0 g
.25 Mabswid
.62133 0 m
.94403 .48064 L
s
.94403 .48064 m
1 .97006 L
s
1 .97006 m
.63662 .53741 L
s
.63662 .53741 m
.62133 0 L
s
.07154 .22539 m
0 .7437 L
s
0 .7437 m
.63662 .53741 L
s
.63662 .53741 m
.62133 0 L
s
.62133 0 m
.07154 .22539 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 317.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001?B000`400?l00000o`00003o/@3oool2
000006d0oooo002^0?ooo`<0000000<0oooo0000003oool0K03oool00:`0oooo0P0000040?ooo`80
0000K03oool00:T0oooo0`0000060?ooo`030000003oool0000006/0oooo002W0?ooo`8000002@3o
ool00`000000oooo0000001[0?ooo`00Y@3oool2000000/0oooo00@000000?ooo`3oool00000JP3o
ool00:80oooo0`00000=0?ooo`050000003oool0oooo0?ooo`000000J@3oool00:00oooo0P00000@
0?ooo`050000003oool0oooo0?ooo`000000J@3oool009d0oooo0`00000B0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0IP3oool009/0oooo0P00000C0?ooo`<000001@3oool00`00
0000oooo0?ooo`1U0?ooo`00V03oool300000180oooo0`0000000`008G`00000000000050?ooo`03
0000003oool0oooo06D0oooo002F0?ooo`8000004`3oool2000000@0025l0P0000060?ooo`030000
003oool0oooo06@0oooo002D0?ooo`8000004P3oool3000000H0025l0`0000060?ooo`030000003o
ool0oooo06<0oooo002A0?ooo`<000004P3oool2000000T0025l0`0000060?ooo`030000003oool0
oooo06<0oooo002?0?ooo`8000004P3oool3000000/0025l0P0000000`00EUT000000?ooo`050?oo
o`030000003oool0oooo0680oooo002<0?ooo`<000004P3oool2000000h0025l0P000002001FF@03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0H@3oool008X0oooo0P00000B0?ooo`<00000
40008G`20000008005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Q0?ooo`00Q`3o
ool300000180oooo0P00000C000QO08000000`00EUT00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0600oooo00250?ooo`8000004P3oool3000001D0025l0P000004001FF@030000003oool0
oooo00@0oooo00<000000?ooo`3oool0G`3oool008<0oooo0P00000B0?ooo`80000060008G`20000
00@005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1O0?ooo`00P03oool300000180
oooo0P00000J000QO00300000000EUT0000000@005II00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1N0?ooo`00OP3oool200000180oooo0`00000L000QO00300000000EUT0000000D005II
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1M0?ooo`00N`3oool300000180oooo0P00
000O000QO00300000000EUT0000000D005II00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1M0?ooo`00N@3oool200000180oooo0`00000Q000QO00300000000EUT0000000H005II00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1L0?ooo`00MP3oool300000180oooo0P00000T000Q
O00300000000EUT0000000L005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1K0?oo
o`00M03oool200000180oooo0`00000V000QO00300000000EUT0000000L005II00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1K0?ooo`00LP3oool200000180oooo0P00000Y000QO0030000
0000EUT0000000P005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1J0?ooo`00K`3o
ool300000140oooo0`00000[000QO00300000000EUT0000000P005II00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1I0?ooo`00K@3oool200000180oooo0P00000^000QO00300000000EUT0
000000T005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1I0?ooo`00JP3oool30000
0140oooo0`00000`000QO00300000000EUT0000000X005II00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1H0?ooo`00J03oool200000180oooo0P00000c000QO00300000000EUT0000000X0
05II00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`00I@3oool300000140oooo
0`00000e000QO00300000000EUT0000000/005II00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1G0?ooo`00H`3oool200000180oooo0P00000h000QO00300000000EUT0000000`005II00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?ooo`00H@3oool200000140oooo0`00000j
000QO00300000000EUT0000000`005II00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1E
0?ooo`00GP3oool300000140oooo0P00000n000QO08000003@00EUT00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05D0oooo001L0?ooo`8000004@3oool300000400025l0P00000>001FF@03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0E03oool005T0oooo0`00000A0?ooo`800000
@`008G`2000000h005II00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`00E`3o
ool200000140oooo0`000015000QO08000003`00EUT00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo05<0oooo001D0?ooo`<000004@3oool2000004P0025l0P00000@001FF@030000003oool0
oooo00@0oooo00<000000?ooo`3oool0DP3oool00580oooo0P00000A0?ooo`<00000BP008G`20000
010005II00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`00D03oool200000140
oooo0P00001=000QO08000004000EUT00`000000oooo0?ooo`050?ooo`030000003oool0oooo0540
oooo001=0?ooo`<000004@3oool2000004l0025l0P00000@001FF@030000003oool0oooo00H0oooo
00<000000?ooo`3oool0D03oool004/0oooo0P00000A0?ooo`<00000D@008G`20000010005II00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1?0?ooo`00B03oool300000140oooo0P00001D
000QO08000004000EUT00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00160?oo
o`8000004@3oool3000005H0025l0P00000@001FF@030000003oool0oooo00P0oooo00<000000?oo
o`3oool0CP3oool004<0oooo0`00000A0?ooo`800000F@008G`20000010005II00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1=0?ooo`00@@3oool200000140oooo0`00001K000QO0800000
4000EUT00`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0oooo000o0?ooo`8000004@3o
ool2000005h0025l0P00000@001FF@030000003oool0oooo00X0oooo00<000000?ooo`3oool0C03o
ool003`0oooo0`00000@0?ooo`<00000H0008G`20000010005II00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1;0?ooo`00>P3oool200000140oooo0P00001S000QO08000004@00EUT00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo000g0?ooo`<00000403oool3000006D0
025l0P00000A001FF@030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo04X0
oooo000e0?ooo`8000004@3oool2000006P0025l0P00000A001FF@030000003oool0oooo00<00000
00<002J30000003oool01P3oool00`000000oooo0?ooo`190?ooo`00<P3oool300000100oooo0`00
001Z000QO08000004@00EUT3000000@002J30P0000060?ooo`030000003oool0oooo04T0oooo000`
0?ooo`8000004@3oool2000006`0025l0`00000A001FF@03000000009X<002J300@002J300<00000
001FF@0000001P3oool00`000000oooo0?ooo`180?ooo`00;P3oool200000100oooo0`00001[000Q
O0<0000000<0025l0000000000004@00EUT00`00000002J3000VP`04000VP`0300000000EUT00000
00L0oooo00<000000?ooo`3oool0A`3oool002/0oooo0`00000@0?ooo`800000J`008G`3000000@0
025l0P00000A001FF@03000000009X<002J300@002J300@00000001FF@00EUT000001P3oool00`00
0000oooo0?ooo`170?ooo`00:@3oool200000100oooo0`00001[000QO08000001`008G`300000100
05II00<00000000VP`009X<010009X<01@00000005II001FF@00EUT0000000H0oooo00<000000?oo
o`3oool0AP3oool002H0oooo0`00000@0?ooo`800000J`008G`3000000T0025l0`00000@001FF@03
000000009X<002J300@002J300<00000001FF@00EUT00P00EUT00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04D0oooo000T0?ooo`800000403oool3000006/0025l0P00000<000QO0800000
00<005II00000000EUT03P00EUT00`00000002J3000VP`04000VP`0300000000EUT005II008005II
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`150?ooo`008@3oool300000100oooo0P00
001[000QO0<000003P008G`01@00000005II00000000EUT0000000h005II00<00000000VP`009X<0
10009X<00`00000005II001FF@03001FF@030000003oool0oooo00@0oooo00<000000?ooo`3oool0
A03oool001l0oooo0P00000A0?ooo`800000JP008G`300000140025l00D00000001FF@00000005II
0000000>001FF@03000000009X<002J300D002J300<00000001FF@00EUT00`00EUT00`000000oooo
0?ooo`040?ooo`030000003oool0oooo04<0oooo000M0?ooo`800000403oool3000006X0025l0P00
000D000QO00300000000EUT00000008005II00<00000001FF@00EUT02`00EUT00`00000002J3000V
P`05000VP`0300000000EUT005II00<005II00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`130?ooo`006P3oool300000100oooo0P00001Z000QO0<000005P008G`00`00000005II00000003
001FF@0300000000EUT005II00X005II00<00000000VP`009X<01@009X<00`00000005II001FF@04
001FF@030000003oool0oooo00@0oooo00<000000?ooo`3oool0@P3oool001P0oooo0P00000@0?oo
o`<00000JP008G`2000001T0025l00<00000001FF@0000001000EUT00`00000005II001FF@09001F
F@03000000009X<002J300D002J300<00000001FF@00EUT01@00EUT00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0440oooo000E0?ooo`<00000403oool2000006X0025l0`00000K000QO003
00000000EUT0000000@005II00<00000001FF@00EUT02@00EUT00`00000002J3000VP`05000VP`03
00000000EUT005II00D005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`110?ooo`00
503oool00`000000oooo0?ooo`0>0?ooo`<00000J@008G`3000001h0025l00<00000001FF@000000
1@00EUT00`00000005II001FF@08001FF@03000000009X<002J300D002J300<00000001FF@00EUT0
1P00EUT00`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo000D0?ooo`030000003o
ool0oooo00`0oooo0P00001Z000QO08000008@008G`00`00000005II00000006001FF@0300000000
EUT005II00L005II00<00000000VP`009X<01@009X<00`00000005II001FF@07001FF@030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?`3oool001@0oooo0P00000:0?ooo`<00000J@008G`3
000002<0025l00<00000001FF@0000001P00EUT00`00000005II001FF@07001FF@03000000009X<0
02J300D002J300<00000001FF@00EUT01`00EUT00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03l0oooo000D0?ooo`030000003oool0000000L0oooo0P00001Y000QO0<000009P008G`00`00
000005II00000007001FF@0300000000EUT005II00H005II00<00000000VP`009X<01@009X<00`00
000005II001FF@08001FF@030000003oool0oooo00@0oooo00<000000?ooo`3oool0?P3oool001@0
oooo00@000000?ooo`3oool000000`3oool3000006T0025l0P00000Y000QO00300000000EUT00000
00P005II00<00000001FF@00EUT01@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II
00T005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`004`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000006T0025l0`00000[000QO00300000000EUT0000000P0
05II00<00000001FF@00EUT01P00EUT00`00000002J3000VP`04000VP`0300000000EUT005II00X0
05II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`004`3oool00`000000oooo
0?ooo`030?ooo`800000I`008G`2000002h0025l00<00000001FF@0000002@00EUT00`00000005II
001FF@05001FF@03000000009X<002J300@002J300<00000001FF@00EUT02P00EUT00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03`0oooo000C0?ooo`030000003oool0oooo00@0oooo00<0
0000000QO0008G`0HP008G`300000300025l00<00000001FF@0000002P00EUT00`00000005II001F
F@04001FF@03000000009X<002J300@002J300<00000001FF@00EUT02`00EUT00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03/0oooo000C0?ooo`030000003oool0oooo00@0oooo00<00000
000QO0008G`0G`008G`3000003<0025l00<00000001FF@0000002P00EUT00`00000005II001FF@04
001FF@03000000009X<002J300@002J300<00000001FF@00EUT03000EUT00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03/0oooo000C0?ooo`030000003oool0oooo00@0oooo00<00000000Q
O0008G`0G@008G`2000003H0025l00<00000001FF@0000002`00EUT00`00000005II001FF@03001F
F@03000000009X<002J300@002J300<00000001FF@00EUT03000EUT00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03X0oooo000C0?ooo`030000003oool0oooo00<0oooo00<00000000QO000
8G`0F`008G`3000003P0025l00<00000001FF@0000003000EUT00`00000005II001FF@02001FF@03
000000009X<002J300@002J300<00000001FF@00EUT03@00EUT00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo000C0?ooo`030000003oool0oooo00<0oooo00<00000000QO0008G`0
F@008G`2000003/0025l00<00000001FF@0000003@00EUT01@00000005II001FF@00EUT0000000H0
02J300<00000001FF@00EUT03P00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0
oooo000B0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0EP008G`3000003d0025l
00<00000001FF@0000003@00EUT01@00000005II001FF@00EUT0000000H002J300<00000001FF@00
EUT03P00EUT00`000000oooo0?ooo`040?ooo`030000003oool0oooo03P0oooo000B0?ooo`030000
003oool0oooo00@0oooo00<00000000QO0008G`0D`008G`300000400025l00<00000001FF@000000
3P00EUT01000000005II001FF@000007000VP`0300000000EUT005II00d005II00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0g0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`030000
00008G`0025l0540025l0P000013000QO00300000000EUT0000000l005II00<00000001FF@000000
1`009X<00`00000005II001FF@0=001FF@030000003oool0oooo00D0oooo00<000000?ooo`3oool0
=`3oool00180oooo00<000000?ooo`3oool0103oool00`000000025l000QO01>000QO0<00000A@00
8G`00`00000005II0000000?001FF@0300000000EUT0000000L002J300<00000001FF@00EUT03@00
EUT00`000000oooo0?ooo`060?ooo`030000003oool0oooo03H0oooo000B0?ooo`030000003oool0
oooo00@0oooo00<00000000QO0008G`0B`008G`3000004P0025l00<00000001FF@0000004000EUT3
000000H002J300<00000001FF@00EUT03@00EUT00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03D0oooo000B0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0B@008G`20000
04/0025l00<00000001FF@0000004@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II
00d005II00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`004P3oool00`000000
oooo0?ooo`030?ooo`03000000008G`0025l04L0025l0`00001>000QO08000004@00EUT00`000000
02J3000VP`05000VP`0300000000EUT005II00d005II00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0d0?ooo`004P3oool00`000000oooo0?ooo`030?ooo`03000000008G`0025l04D0025l
0P00001A000QO08000004@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00h005II
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0c0?ooo`004@3oool00`000000oooo0?oo
o`040?ooo`03000000008G`0025l0480025l0`00001C000QO08000004@00EUT00`00000002J3000V
P`05000VP`0300000000EUT005II00h005II00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0c0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l03l0025l0`00001F
000QO08000004@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00h005II00<00000
0?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0<P3oool00140oooo00<000000?oo
o`3oool0103oool00`000000025l000QO00m000QO0800000F@008G`20000014005II00<00000000V
P`009X<01@009X<00`00000005II001FF@0>001FF@030000003oool000000080000000<002V80000
003oool01@3oool00`000000oooo0?ooo`0a0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`03
000000008G`0025l03X0025l0`00001K000QO08000004@00EUT00`00000002J3000VP`05000VP`03
00000000EUT005II00h005II0P000004000YR08000001@3oool00`000000oooo0?ooo`0a0?ooo`00
4@3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l03L0025l0`00001N000QO0800000
4@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00h005II00<00000000YR000:HP0
0`00:HP00`00000005II000000050?ooo`030000003oool0oooo0300oooo000A0?ooo`030000003o
ool0oooo00@0oooo00<00000000QO0008G`0=@008G`200000640025l0P00000B001FF@0300000000
9X<002J300@002J300<00000001FF@00EUT03P00EUT00`00000002V8000YR003000YR00300000000
EUT0000000H0oooo00<000000?ooo`3oool0;`3oool00140oooo00<000000?ooo`3oool00`3oool0
0`000000025l000QO00c000QO0<00000H`008G`20000018005II00<00000000VP`009X<010009X<0
0`00000005II001FF@0>001FF@0300000000:HP002V800<002V800@00000001FF@00EUT000001@3o
ool00`000000oooo0?ooo`0_0?ooo`00403oool00`000000oooo0?ooo`040?ooo`03000000008G`0
025l0340025l0P00001V000QO08000004P00EUT00`00000002J3000VP`04000VP`0300000000EUT0
05II00h005II00<00000000YR000:HP00`00:HP01@00000005II001FF@00EUT0000000D0oooo00<0
00000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0103oool00`000000025l000QO00^
000QO0<00000J0008G`20000018005II00<00000000VP`009X<00`009X<3000000l005II00<00000
000YR000:HP01000:HP01@00000005II001FF@00EUT0000000D0oooo00<000000?ooo`3oool0;@3o
ool00100oooo00<000000?ooo`3oool0103oool00`000000025l000QO00[000QO0<00000J`008G`2
0000018005II00<00000000VP`009X<00`0000000`009X<00000001FF@0?001FF@0300000000:HP0
02V800@002V800D00000001FF@00EUT005II000000050?ooo`030000003oool0oooo02d0oooo000@
0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0:@008G`2000006h0025l0P00000B
001FF@<0000010009X<2000000l005II00<00000000YR000:HP01000:HP00`00000005II001FF@02
001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00100oooo00<000000?oo
o`3oool0103oool00`000000025l000QO00V000QO0<00000L0008G`20000018005II00<00000000V
P`009X<01@009X<2000000h005II00<00000000YR000:HP01000:HP00`00000005II001FF@03001F
F@030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00100oooo00<000000?ooo`3o
ool0103oool00`000000025l000QO00T000QO0800000L`008G`20000018005II00<00000000VP`00
9X<01@009X<00`00000005II0000000=001FF@0300000000:HP002V800@002V800<00000001FF@00
EUT00`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo000@0?ooo`030000
003oool0oooo00<0oooo00<00000000QO0008G`08P008G`3000007D0025l00<00000001FF@000000
4@00EUT00`00000002J3000VP`05000VP`0300000000EUT0000000h005II00<00000000YR000:HP0
0`00:HP00`00000005II001FF@04001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:P3oool00100oooo00<000000?ooo`3oool00`3oool00`000000025l000QO00O000QO0<00000N000
8G`00`00000005II0000000A001FF@03000000009X<002J300D002J300@00000001FF@00EUT00000
3@00EUT00`00000002V8000YR003000YR00300000000EUT005II00D005II00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0Y0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`0300000000
8G`0025l01d0025l0P00001k000QO00300000000EUT00000014005II00<00000000VP`009X<01@00
9X<01@00000005II001FF@00EUT0000000`005II00<00000000YR000:HP00`00:HP00`00000005II
001FF@05001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool000l0oooo00<0
00000?ooo`3oool0103oool00`000000025l000QO00J000QO0<00000O@008G`00`00000005II0000
000A001FF@03000000009X<002J300D002J300<00000001FF@00EUT00P00EUT00`00000005II001F
F@09001FF@0300000000:HP002V800<002V800<00000001FF@00EUT01P00EUT00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02P0oooo000?0?ooo`030000003oool0oooo00@0oooo00<00000
000QO0008G`05`008G`3000007l0025l0P0000000`00EUT00000001FF@0@001FF@03000000009X<0
02J300D002J300<00000001FF@00EUT00P00EUT00`00000005II001FF@09001FF@0300000000:HP0
02V800<002V800<00000001FF@00EUT01`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02L0oooo000?0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`05@008G`20000
07l0025l0`00000010008G`00000001FF@00000A001FF@03000000009X<002J300D002J300<00000
001FF@00EUT00`00EUT00`00000005II001FF@08001FF@0300000000:HP002V800<002V800<00000
001FF@00EUT01`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo000?0?oo
o`030000003oool0oooo00@0oooo00<00000000QO0008G`04P008G`3000007h0025l0`000004000Q
O0<000004@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00@005II00<00000001F
F@00EUT01`00EUT00`00000002V8000YR003000YR00300000000EUT005II00P005II00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`03
000000008G`0025l0100025l0P00001n000QO0<000001`008G`00`00000005II0000000A001FF@03
000000009X<002J300D002J300<00000001FF@00EUT01@00EUT00`00000005II001FF@06001FF@03
00000000:HP002V800<002V800<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02D0oooo000?0?ooo`030000003oool0oooo00<0oooo00<00000000QO0008G`0
3P008G`3000007d0025l0`00000:000QO00400000000EUT000000000010005II00<00000000VP`00
9X<01@009X<00`00000005II001FF@06001FF@0300000000EUT005II00D005II00<00000000YR000
:HP01000:HP00`00000005II001FF@09001FF@030000003oool0oooo0080oooo00<000000?ooo`3o
ool09@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000025l000QO00;000QO0<00000
O@008G`3000000d0025l00D00000001FF@00000005II0000000?001FF@03000000009X<002J300D0
02J300<00000001FF@00EUT01P00EUT00`00000005II001FF@05001FF@0300000000:HP002V800@0
02V800<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0
oooo000>0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`02@008G`2000007d0025l
0`00000@000QO00500000000EUT00000001FF@0000003`00EUT00`00000002J3000VP`05000VP`03
00000000EUT005II00L005II00<00000001FF@00EUT01000EUT00`00000002V8000YR004000YR003
00000000EUT005II00X005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`00
3P3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l00H0025l0`00001m000QO0800000
4`008G`00`00000005II00000002001FF@0300000000EUT005II00`005II00<00000000VP`009X<0
1@009X<00`00000005II001FF@08001FF@0300000000EUT005II00<005II00<00000000YR000:HP0
1000:HP00`00000005II001FF@0;001FF@030000003oool0oooo0080oooo00<000000?ooo`3oool0
8`3oool000h0oooo00<000000?ooo`3oool0103oool00`000000025l000QO004000QO0800000O@00
8G`3000001D0025l00<00000001FF@0000000`00EUT00`00000005II001FF@0;001FF@0300000000
9X<002J300D002J300<00000001FF@00EUT02@00EUT00`00000005II001FF@02001FF@0300000000
:HP002V800@002V800<00000001FF@00EUT02`00EUT00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0280oooo000>0?ooo`030000003oool0oooo00@0oooo00@00000000QO0008G`0025l0`00
001l000QO0<0000060008G`00`00000005II00000004001FF@0300000000EUT005II00/005II00<0
0000000VP`009X<010009X<00`00000005II001FF@09001FF@0300000000EUT005II008005II00<0
0000000YR000:HP01000:HP00`00000005II001FF@0;001FF@030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool000h0oooo00<000000?ooo`3oool0103oool4000007`0025l0`00000K
000QO00300000000EUT0000000@005II00<00000001FF@00EUT02`00EUT00`00000002J3000VP`04
000VP`0300000000EUT005II00X005II00<00000001FF@00EUT00P00EUT00`00000002V8000YR003
000YR00300000000EUT005II00/005II00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q
0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l07X0025l0`00000N000Q
O00300000000EUT0000000D005II00<00000001FF@00EUT02P00EUT00`00000002J3000VP`04000V
P`0300000000EUT005II00/005II00D00000001FF@00EUT005II00000005000YR00300000000EUT0
05II00/005II00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`003@3oool00`00
0000oooo0?ooo`040?ooo`03000000008G`0025l07P0025l0`00000Q000QO00300000000EUT00000
00H005II00<00000001FF@00EUT02@00EUT00`00000002J3000VP`05000VP`0300000000EUT005II
00/005II00@00000001FF@00EUT000001@00:HP00`00000005II001FF@0;001FF@030000003oool0
oooo00H0oooo00<000000?ooo`3oool07`3oool000d0oooo00<000000?ooo`3oool0103oool00`00
0000025l000QO01e000QO0<0000090008G`00`00000005II00000007001FF@0300000000EUT005II
00P005II00<00000000VP`009X<01@009X<00`00000005II001FF@0;001FF@0400000000EUT005II
000000D002V800<00000001FF@00EUT02`00EUT00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01l0oooo000=0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0LP008G`30000
02L0025l00<00000001FF@0000002000EUT00`00000005II001FF@07001FF@03000000009X<002J3
00D002J300<00000001FF@00EUT03000EUT00`00000005II00000005000YR00300000000EUT005II
00`005II00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`003@3oool00`000000
oooo0?ooo`040?ooo`03000000008G`0025l0700025l0P00000Z000QO00300000000EUT0000000P0
05II00<00000001FF@00EUT01`00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00d0
05II0P000005000YR00300000000EUT005II00`005II00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0M0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l06d0025l
0`00000/000QO00300000000EUT0000000T005II00<00000001FF@00EUT01P00EUT00`00000002J3
000VP`05000VP`0300000000EUT005II00h005II00<00000000YR000:HP00`00:HP00`00000005II
001FF@0<001FF@030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool000d0oooo00<0
00000?ooo`3oool0103oool00`000000025l000QO01Z000QO0<00000;`008G`00`00000005II0000
000:001FF@0300000000EUT005II00D005II00<00000000VP`009X<01@009X<00`00000005II001F
F@0>001FF@0300000000:HP002V800@002V800<00000001FF@00EUT02`00EUT00`000000oooo0?oo
o`03000000D0oooo00<000000?ooo`3oool0703oool000d0oooo00<000000?ooo`3oool0103oool0
0`000000025l000QO01W000QO0<00000<P008G`00`00000005II0000000;001FF@0300000000EUT0
05II00@005II00<00000000VP`009X<01@009X<00`00000005II001FF@0>001FF@0300000000:HP0
02V800@002V800<00000001FF@00EUT02`00EUT30000008002f=00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0K0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l
06@0025l0`00000e000QO00300000000EUT0000000/005II00<00000001FF@00EUT01000EUT00`00
000002J3000VP`05000VP`0300000000EUT005II00h005II00<00000000YR000:HP01000:HP00`00
000005II001FF@0;001FF@0300000000;Hd002f=008002f=0P0000050?ooo`030000003oool0oooo
01/0oooo000<0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0HP008G`3000003P0
025l00<00000001FF@0000003000EUT00`00000005II001FF@03001FF@03000000009X<002J300D0
02J300<00000001FF@00EUT03P00EUT00`00000002V8000YR004000YR00300000000EUT005II00/0
05II00<00000000]S@00;Hd00P00;Hd00`00000005II000000050?ooo`030000003oool0oooo01X0
oooo000<0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0G`008G`3000003/0025l
00<00000001FF@0000003@00EUT00`00000005II001FF@02001FF@03000000009X<002J300D002J3
00<00000001FF@00EUT03P00EUT00`00000002V8000YR004000YR00300000000EUT005II00/005II
00<00000000]S@00;Hd00P00;Hd00`00000005II000000060?ooo`030000003oool0oooo01T0oooo
000<0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0G@008G`2000003h0025l00<0
0000001FF@0000003P00EUT01@00000005II001FF@00EUT0000000L002J300<00000001FF@00EUT0
3P00EUT00`00000002V8000YR004000YR00300000000EUT005II00/005II00<00000000]S@00;Hd0
0P00;Hd01000000005II001FF@0000050?ooo`030000003oool0oooo01T0oooo000<0?ooo`030000
003oool0oooo00@0oooo00<00000000QO0008G`0FP008G`300000400025l00<00000001FF@000000
3`00EUT01000000005II001FF@000007000VP`0300000000EUT005II00h005II00<00000000YR000
:HP01000:HP00`00000005II001FF@0;001FF@0300000000;Hd002f=00<002f=00@00000001FF@00
EUT000001@3oool00`000000oooo0?ooo`0H0?ooo`00303oool00`000000oooo0?ooo`040?ooo`03
000000008G`0025l05L0025l0`000013000QO00300000000EUT0000000l005II00@00000001FF@00
EUT000001`009X<00`00000005II001FF@0?001FF@0300000000:HP002V800<002V800<00000001F
F@00EUT02`00EUT00`00000002f=000]S@03000]S@0400000000EUT005II000000H0oooo00<00000
0?ooo`3oool05`3oool000`0oooo00<000000?ooo`3oool0103oool00`000000025l000QO01D000Q
O0<00000AP008G`00`00000005II0000000@001FF@0300000000EUT0000000L002J300<00000001F
F@00EUT03`00EUT00`00000002V8000YR003000YR00300000000EUT005II00`005II00<00000000]
S@00;Hd00P00;Hd01@00000005II001FF@00EUT0000000D0oooo00<000000?ooo`3oool05`3oool0
00`0oooo00<000000?ooo`3oool0103oool00`000000025l000QO01A000QO0<00000B@008G`00`00
000005II0000000A001FF@8000001`009X<00`00000005II001FF@0?001FF@0300000000:HP002V8
00<002V80P00000=001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT00P00EUT00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo000;0?ooo`030000003oool0oooo00D0
oooo00<00000000QO0008G`0CP008G`3000004`0025l00<00000001FF@0000004P00EUT2000000H0
02J300<00000001FF@00EUT03`00EUT00`00000002V8000YR002000YR08000003P00EUT00`000000
02f=000]S@02000]S@0300000000EUT005II008005II00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0E0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l04`0025l
0`00001?000QO00300000000EUT00000018005II00<00000000VP`009X<01@009X<00`00000005II
001FF@0?001FF@0300000000:HP000000080000000<002V800000000EUT03@00EUT00`00000002f=
000]S@02000]S@0300000000EUT005II00<005II00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l04T0025l0`00
001B000QO00300000000EUT00000018005II00<00000000VP`009X<01P009X<00`00000005II001F
F@0>001FF@8000001000:HP2000000d005II00<00000000]S@00;Hd00P00;Hd00`00000005II001F
F@04001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool000/0oooo00<00000
0?ooo`3oool0103oool00`000000025l000QO017000QO0800000EP008G`2000001<005II00<00000
000VP`009X<01@009X<00`00000005II001FF@0>001FF@0300000000:HP002V800@002V80P00000<
001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT01000EUT00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01<0oooo000;0?ooo`030000003oool0oooo00@0oooo00<00000000Q
O0008G`0A0008G`3000005P0025l0P00000C001FF@03000000009X<002J300D002J300<00000001F
F@00EUT03P00EUT00`00000002V8000YR004000YR00300000000EUT0000000/005II00<00000000]
S@00;Hd00P00;Hd00`00000005II001FF@05001FF@030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool000/0oooo00<000000?ooo`3oool0103oool00`000000025l000QO011000QO0<0
0000F`008G`2000001<005II00<00000000VP`009X<01@009X<00`00000005II001FF@0>001FF@03
00000000:HP002V800@002V800<00000001FF@0000002`00EUT00`00000002f=000]S@02000]S@03
00000000EUT005II00H005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`00
2`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l03h0025l0`00001N000QO0800000
4`00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00h005II00<00000000YR000:HP0
1000:HP01000000005II001FF@00000:001FF@0300000000;Hd002f=008002f=00<00000001FF@00
EUT01P00EUT00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo000;0?ooo`030000
003oool0oooo00@0oooo00<00000000QO0008G`0>`008G`300000640025l0P00000C001FF@030000
00009X<002J300D002J300<00000001FF@00EUT03P00EUT00`00000002V8000YR004000YR0050000
0000EUT005II001FF@0000002@00EUT00`00000002f=000]S@03000]S@0300000000EUT005II00H0
05II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`002P3oool00`000000oooo
0?ooo`050?ooo`03000000008G`0025l03P0025l0`00001T000QO00300000000EUT00000018005II
00<00000000VP`009X<01@009X<00`00000005II001FF@0>001FF@0300000000:HP002V800@002V8
00<00000001FF@00EUT00P00EUT00`00000005II001FF@06001FF@0300000000;Hd002f=00<002f=
00<00000001FF@00EUT01`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
000:0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0=P008G`3000006L0025l00<0
0000001FF@0000004P00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00h005II00<0
0000000YR000:HP01000:HP00`00000005II001FF@03001FF@0300000000EUT005II00D005II00<0
0000000]S@00;Hd00`00;Hd00`00000005II001FF@07001FF@030000003oool0oooo0080oooo0`00
000A0?ooo`002P3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l03@0025l0P00001Z
000QO00300000000EUT00000018005II00<00000000VP`009X<01@009X<00`00000005II001FF@0>
001FF@0300000000:HP002V800@002V800<00000001FF@00EUT00`00EUT00`00000005II001FF@06
001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT02000EUT400000080oooo00<00000
0?ooo`3oool03`3oool000X0oooo00<000000?ooo`3oool0103oool00`000000025l000QO00a000Q
O0<00000K0008G`00`00000005II0000000B001FF@03000000009X<002J300@002J30P00000A001F
F@0300000000:HP002V800<002V800<00000001FF@00EUT01000EUT00`00000005II001FF@05001F
F@0300000000;Hd002f=008002f=00<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo000:0?ooo`030000003oool0oooo00@0oooo00<00000000QO000
8G`0;P008G`3000006l0025l00<00000001FF@0000004P00EUT01000000002J3000VP`009X<30000
0003000VP`00000005II010005II00<00000000YR000:HP00`00:HP00`00000005II001FF@05001F
F@0300000000EUT005II00@005II00<00000000]S@00;Hd00P00;Hd00`00000005II001FF@09001F
F@030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool000X0oooo00<000000?ooo`3o
ool0103oool00`000000025l000QO00[000QO0<00000LP008G`00`00000005II0000000B001FF@@0
000010009X<20000010005II00<00000000YR000:HP00`00:HP00`00000005II001FF@06001FF@03
00000000EUT005II00<005II00<00000000]S@00;Hd00P00;Hd00`00000005II001FF@09001FF@03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool000X0oooo00<000000?ooo`3oool0
103oool00`000000025l000QO00X000QO0<00000M@008G`00`00000005II0000000B001FF@030000
00009X<002J300D002J300<00000001FF@0000003`00EUT00`00000002V8000YR003000YR0030000
0000EUT005II00H005II00<00000001FF@00EUT00`00EUT00`00000002f=000]S@02000]S@030000
0000EUT005II00T005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`002@3o
ool00`000000oooo0?ooo`050?ooo`03000000008G`0025l02D0025l0`00001h000QO00300000000
EUT00000018005II00<00000000VP`009X<01@009X<01000000005II001FF@00000>001FF@030000
0000:HP002V800@002V800<00000001FF@00EUT01P00EUT00`00000005II001FF@02001FF@030000
0000;Hd002f=008002f=00<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00h0oooo00090?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`08`00
8G`3000007/0025l00<00000001FF@0000004P00EUT00`00000002J3000VP`05000VP`0400000000
EUT005II000000h005II00<00000000YR000:HP01000:HP00`00000005II001FF@07001FF@050000
0000EUT005II001FF@0000001000;Hd00`00000005II001FF@0:001FF@030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool000T0oooo00<000000?ooo`3oool0103oool00`000000025l
000QO00P000QO0<00000OP008G`00`00000005II0000000B001FF@03000000009X<002J300D002J3
00D00000001FF@00EUT005II0000000=001FF@0300000000:HP002V800@002V800<00000001FF@00
EUT02000EUT01000000005II001FF@000005000]S@0300000000EUT005II00T005II00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`002@3oool00`000000oooo0?ooo`040?ooo`03
000000008G`0025l01h0025l0P000021000QO00300000000EUT00000018005II00<00000000VP`00
9X<01@009X<00`00000005II001FF@02001FF@0300000000EUT005II00X005II00<00000000YR000
:HP01000:HP00`00000005II001FF@09001FF@0300000000EUT0000000D002f=00<00000001FF@00
EUT02@00EUT00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00090?ooo`030000
003oool0oooo00@0oooo00<00000000QO0008G`06`008G`3000008<0025l00<00000001FF@000000
4P00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00<005II00<00000001FF@00EUT0
2@00EUT00`00000002V8000YR004000YR00300000000EUT005II00T005II00<00000001FF@000000
1@00;Hd00`00000005II001FF@09001FF@030000003oool0oooo0080oooo00<000000?ooo`3oool0
3P3oool000T0oooo00<000000?ooo`3oool0103oool00`000000025l000QO00H000QO0<00000QP00
8G`00`00000005II0000000B001FF@03000000009X<002J300H002J300<00000001FF@00EUT00P00
EUT00`00000005II001FF@09001FF@0300000000:HP002V800@002V800<00000001FF@00EUT02P00
EUT2000000D002f=00<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00090?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`05@008G`3
000008T0025l00<00000001FF@0000004P00EUT00`00000002J3000VP`06000VP`0300000000EUT0
05II00<005II00<00000001FF@00EUT02000EUT00`00000002V8000YR004000YR00300000000EUT0
05II00/005II0P000004000]S@0300000000EUT005II00T005II00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`002@3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l
0180025l0`00002<000QO00300000000EUT00000018005II00<00000000VP`009X<01P009X<00`00
000005II001FF@04001FF@0300000000EUT005II00L005II00<00000000YR000:HP01000:HP00`00
000005II001FF@0<001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT02@00EUT00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00080?ooo`030000003oool0oooo00D0
oooo00<00000000QO0008G`03`008G`3000008l0025l00<00000001FF@0000004`00EUT00`000000
02J3000VP`05000VP`0300000000EUT005II00D005II00<00000001FF@00EUT01P00EUT00`000000
02V8000YR004000YR00300000000EUT005II00`005II00<00000000]S@00;Hd00P00;Hd00`000000
05II001FF@09001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool000P0oooo
00<000000?ooo`3oool0103oool00`000000025l000QO00=000QO0<00000TP008G`00`00000005II
0000000C001FF@03000000009X<002J300D002J300<00000001FF@00EUT01P00EUT00`00000005II
001FF@05001FF@0300000000:HP002V800@002V800<00000001FF@00EUT03000EUT00`00000002f=
000]S@02000]S@0300000000EUT005II00T005II00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`00203oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l00/0025l0P00
002E000QO00300000000EUT0000001<005II00<00000000VP`009X<01@009X<00`00000005II001F
F@06001FF@0300000000EUT005II00H005II00<00000000YR000:HP00`00:HP00`00000005II001F
F@0<001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT02P00EUT00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo00080?ooo`030000003oool0oooo00@0oooo00<00000
000QO0008G`020008G`3000009D0025l1@00000C001FF@03000000009X<002J300D002J300<00000
001FF@00EUT01`00EUT00`00000005II001FF@05001FF@0300000000:HP002V800<002V800<00000
001FF@00EUT03000EUT00`00000002f=000]S@02000]S@0300000000EUT005II00X005II00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00203oool00`000000oooo0?ooo`040?oo
o`03000000008G`0025l00H0025l0P00002E000QO0H0000000<005II00000000EUT04P00EUT00`00
000002J3000VP`05000VP`0300000000EUT005II00P005II00<00000001FF@00EUT01000EUT00`00
000002V8000YR003000YR00300000000EUT005II00`005II00<00000000]S@00;Hd00P00;Hd00`00
000005II001FF@0:001FF@030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool000P0
oooo00<000000?ooo`3oool0103oool00`000000025l000QO003000QO0<00000U0008G`5000000@0
06?b00<00000001FF@0000004P00EUT00`00000002J3000VP`05000VP`0300000000EUT005II00T0
05II00<00000001FF@00EUT00`00EUT00`00000002V8000YR004000YR00300000000EUT005II00/0
05II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@09001FF@030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool000P0oooo00<000000?ooo`3oool0103oool010000000025l
000QO0008G`2000009@0025l1@000008001SlP0300000000EUT00000014005II00<00000000VP`00
9X<01@009X<00`00000005II001FF@09001FF@0300000000EUT005II00<005II00<00000000YR000
:HP01000:HP00`00000005II001FF@0;001FF@0300000000;Hd002f=00<002f=00<00000001FF@00
EUT02@00EUT00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00070?ooo`030000
003oool0oooo00D0oooo1000002C000QO0D000003000Ho800`00000005II0000000@001FF@030000
00009X<002J300D002J300<00000001FF@00EUT02P00EUT00`00000005II001FF@02001FF@030000
0000:HP002V800@002V800<00000001FF@00EUT02`00EUT00`00000002f=000]S@03000]S@030000
0000EUT005II00T005II00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`001`3o
ool00`000000oooo0?ooo`050?ooo`03000000008G`0025l0940025l1@00000@001SlP0300000000
EUT0000000l005II00<00000000VP`009X<01@009X<00`00000005II001FF@0;001FF@0500000000
EUT005II001FF@0000001P00:HP00`00000005II001FF@0;001FF@0300000000;Hd002f=008002f=
0`00000:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool000L0oooo00<0
00000?ooo`3oool0103oool00`000000025l000QO02?000QO0D000005000Ho800`00000005II0000
000>001FF@03000000009X<002J300D002J300<00000001FF@00EUT03000EUT01000000005II001F
F@000006000YR00300000000EUT005II00`005II100000000`00;Hd00000001FF@0:001FF@030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool000L0oooo00<000000?ooo`3oool0103o
ool00`000000025l000QO02<000QO0D000006000Ho800`00000005II0000000=001FF@0300000000
9X<002J300D002J300<00000001FF@00EUT03000EUT01000000005II001FF@000006000YR0030000
0000EUT005II00`005II00<00000000]S@00;Hd00P00;Hd2000000X005II00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool00`000000oooo0?ooo`040?ooo`0300000000
8G`0025l08T0025l1@00000K001SlP0300000000EUT0000000d005II00<00000000VP`009X<01@00
9X<00`00000005II001FF@0=001FF@0300000000EUT0000000H002V800<00000001FF@00EUT03000
EUT00`00000002f=000]S@02000]S@0300000000EUT0000000X005II00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`001`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0
025l08H0025l1@00000O001SlP0300000000EUT0000000`005II00<00000000VP`009X<01@009X<0
0`00000005II001FF@0>001FF@8000001P00:HP00`00000005II001FF@0<001FF@0300000000;Hd0
02f=008002f=00@00000001FF@00EUT000002@00EUT00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00070?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0P`008G`5
000002<006?b00<00000001FF@0000002`00EUT00`00000002J3000VP`05000VP`0300000000EUT0
05II00l005II00<00000000YR000:HP01000:HP00`00000005II001FF@0<001FF@0300000000;Hd0
02f=008002f=00@00000001FF@00EUT000002@00EUT00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00070?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0P0008G`5
000002L006?b00<00000001FF@0000002P00EUT00`00000002J3000VP`05000VP`0300000000EUT0
05II00l005II00<00000000YR000:HP01000:HP00`00000005II001FF@0<001FF@0300000000;Hd0
02f=008002f=00D00000001FF@00EUT005II00000008001FF@030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool000H0oooo00<000000?ooo`3oool01@3oool00`000000025l000QO01m
000QO0D00000:`00Ho800`00000005II00000009001FF@03000000009X<002J300H002J300<00000
001FF@00EUT03P00EUT00`00000002V8000YR004000YR00300000000EUT005II00`005II00<00000
000]S@00;Hd00`00;Hd01@00000005II001FF@00EUT0000000L005II00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`050?ooo`03000000008G`0
025l07X0025l1000000`001SlP0300000000EUT0000000P005II00<00000000VP`009X<01P009X<0
0`00000005II001FF@0?001FF@0300000000:HP002V800<002V800<00000001FF@00EUT03000EUT0
0`00000002f=000]S@03000]S@0500000000EUT005II001FF@0000001`00EUT00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo00@0oooo00<00000
000QO0008G`0M`008G`5000003@006?b0P000008001FF@03000000009X<002J300H002J300<00000
001FF@00EUT03`00EUT00`00000002V8000YR003000YR00300000000EUT005II00`005II00<00000
000]S@00;Hd00`00;Hd00`00000005II001FF@02001FF@0300000000EUT005II00@005II00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000oooo0?ooo`040?oo
o`03000000008G`0025l07@0025l1@00000g001SlP0300000000EUT0000000L005II00<00000000V
P`009X<01P009X<00`00000005II001FF@0?001FF@0300000000:HP002V800@002V800<00000001F
F@00EUT02`00EUT00`00000002f=000]S@03000]S@0300000000EUT005II00<005II00<00000001F
F@00EUT00`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00060?ooo`03
0000003oool0oooo00@0oooo00<00000000QO0008G`0L@008G`5000003/006?b00<00000001FF@00
00001P00EUT00`00000002J3000VP`06000VP`0300000000EUT005II00l005II00<00000000YR000
:HP01000:HP00`00000005II001FF@0;001FF@0300000000;Hd002f=00<002f=00<00000001FF@00
EUT01000EUT00`00000005II001FF@02001FF@030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool000H0oooo00<000000?ooo`3oool0103oool00`000000025l000QO01^000QO0D00000
?`00Ho800`00000005II00000005001FF@03000000009X<002J300H002J300<00000001FF@00EUT0
3`00EUT00`00000002V8000YR004000YR00300000000EUT005II00/005II00<00000000]S@00;Hd0
0`00;Hd00`00000005II001FF@04001FF@0300000000EUT005II00<005II00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000oooo0?ooo`040?ooo`0300000000
8G`0025l06/0025l1@000013001SlP0300000000EUT0000000D005II00<00000000VP`009X<01@00
9X<00`00000005II001FF@0?001FF@0300000000:HP002V800@002V800<00000001FF@00EUT03000
EUT00`00000002f=000]S@02000]S@0300000000EUT005II00D005II00<00000001FF@00EUT00P00
EUT00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00050?ooo`030000003oool0
oooo00D0oooo00<00000000QO0008G`0J0008G`5000004L006?b00<00000001FF@0000001000EUT0
0`00000002J3000VP`05000VP`0300000000EUT005II00l005II00<00000000YR000:HP01000:HP0
0`00000005II001FF@0<001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT01P00EUT0
1@00000005II001FF@00EUT0000000@0oooo00<000000?ooo`3oool02`3oool000D0oooo00<00000
0?ooo`3oool01@3oool00`000000025l000QO01U000QO0D00000B`00Ho800`00000005II00000003
001FF@03000000009X<002J300D002J300<00000001FF@00EUT03`00EUT00`00000002V8000YR002
000YR0<000003P00EUT00`00000002f=000]S@02000]S@0300000000EUT005II00H005II00D00000
001FF@00EUT005II000000040?ooo`030000003oool0oooo00/0oooo00050?ooo`030000003oool0
oooo00D0oooo00<00000000QO0008G`0HP008G`5000004h006?b00<00000001FF@0000000`00EUT0
0`00000002J3000VP`05000VP`0300000000EUT005II00l005II00<00000000YR00000000P000002
000YR00300000000EUT005II00`005II00<00000000]S@00;Hd00P00;Hd00`00000005II001FF@07
001FF@0400000000EUT005II000000D0oooo00<000000?ooo`3oool02P3oool000D0oooo00<00000
0?ooo`3oool0103oool00`000000025l000QO01P000QO0D00000DP00Ho800`00000005II00000002
001FF@03000000009X<002J300D002J300<00000001FF@00EUT03`00EUT2000000D002V80P00000=
001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT02000EUT00`00000005II00000005
0?ooo`030000003oool0oooo00X0oooo00050?ooo`030000003oool0oooo00@0oooo00<00000000Q
O0008G`0G@008G`5000005H006?b00D00000001FF@00000005II00000007000VP`0300000000EUT0
05II00l005II00<00000000YR000:HP01000:HP00`00000005II0000000<001FF@0300000000;Hd0
02f=00<002f=00<00000001FF@00EUT02000EUT2000000D0oooo00<000000?ooo`3oool02P3oool0
00D0oooo00<000000?ooo`3oool0103oool00`000000025l000QO01J000QO0D00000FP00Ho801000
000005II000000000007000VP`0300000000EUT005II00l005II00<00000000YR000:HP01000:HP0
1000000005II001FF@00000;001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT02000
EUT2000000D0oooo00<000000?ooo`3oool02P3oool000D0oooo00<000000?ooo`3oool0103oool0
0`000000025l000QO01G000QO0@00000G`00Ho800`00000005II00000007000VP`0300000000EUT0
05II00l005II00<00000000YR000:HP01000:HP01000000005II001FF@00000;001FF@0300000000
;Hd002f=00<002f=00<00000001FF@00EUT02@00EUT2000000@0oooo00<000000?ooo`3oool02P3o
ool000@0oooo00<000000?ooo`3oool01@3oool00`000000025l000QO01D000QO0@00000H`00Ho83
000000H002J300<00000001FF@00EUT03`00EUT00`00000002V8000YR004000YR00500000000EUT0
05II001FF@0000002P00EUT00`00000002f=000]S@03000]S@0300000000EUT005II00X005II00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00103oool00`000000oooo0?ooo`05
0?ooo`03000000008G`0025l0540025l1000001W001SlP8000001P009X<00`00000005II001FF@0@
001FF@0300000000:HP002V800@002V800D00000001FF@00EUT005II00000009001FF@0300000000
;Hd002f=00<002f=00<00000001FF@00EUT02P00EUT00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00040?ooo`030000003oool0oooo00D0oooo00<00000000QO0008G`0C@008G`5
000006L006?b00<00000000VP`009X<00P009X<00`00000002J3000VP`03000VP`0300000000EUT0
05II010005II00<00000000YR000:HP01000:HP00`00000005II001FF@02001FF@0300000000EUT0
05II00H005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@0:001FF@030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool000@0oooo00<000000?ooo`3oool01@3oool00`00
0000025l000QO01:000QO0D00000I@00Ho83000000P002J300<00000000VP`009X<00P009X<00`00
000005II001FF@0@001FF@0300000000:HP002V800@002V800<00000001FF@00EUT00`00EUT00`00
000005II001FF@06001FF@0300000000;Hd002f=008002f=00<00000001FF@00EUT02P00EUT00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00040?ooo`030000003oool0oooo00@0
oooo00<00000000QO0008G`0B0008G`5000006@006?b1000000<000VP`03000000009X<002J30080
02J300<00000001FF@00EUT03`00EUT00`00000002V8000YR004000YR00300000000EUT005II00<0
05II00<00000001FF@00EUT01P00EUT00`00000002f=000]S@02000]S@0300000000EUT005II00X0
05II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`00103oool00`000000oooo
0?ooo`040?ooo`03000000008G`0025l04D0025l1@00001T001SlP@000000P00[C0>000VP`050000
00009X<002J3000VP`0000004@00EUT00`00000002V8000YR004000YR00300000000EUT005II00@0
05II00<00000001FF@00EUT01@00EUT00`00000002f=000]S@02000]S@0300000000EUT005II00X0
05II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`00103oool00`000000oooo
0?ooo`040?ooo`03000000008G`0025l0480025l1@00001T001SlP@000000P00[C000`0000000:d`
002]<00?000VP`04000000009X<002J30000014005II00<00000000YR000:HP01000:HP00`000000
05II001FF@05001FF@0300000000EUT005II00@005II00<00000000]S@00;Hd00P00;Hd00`000000
05II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000025l000QO00o000QO0D00000I000Ho84000000800:d`
00@00000002]<000[C0000000P00[C0@000VP`03000000009X<00000014005II00<00000000YR000
:HP01000:HP00`00000005II001FF@06001FF@0300000000EUT005II00<005II00<00000000]S@00
;Hd00`00;Hd00`00000005II001FF@09001FF@030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000025l000QO00l000QO0D00000
H`00Ho85000000800<Ei00@00000002]<000[C0000000P00[C000`0000000:d`002]<00@000VP`03
000000009X<00000014005II00<00000000YR000:HP01000:HP00`00000005II001FF@06001FF@03
00000000EUT005II00<005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@09001FF@03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool000<0oooo00<000000?ooo`3oool0
1@3oool00`000000025l000QO00i000QO0D00000H`00Ho85000000H00<Ei00<00000002]<0000000
0P00[C000`0000000:d`002]<00A000VP`8000004@00EUT00`00000002V8000YR004000YR0030000
0000EUT005II00L005II00<00000001FF@00EUT00P00EUT00`00000002f=000]S@03000]S@030000
0000EUT005II00X005II00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`000`3o
ool00`000000oooo0?ooo`050?ooo`03000000008G`0025l03H0025l1000001T001SlPD000002@00
aGT3000000800:d`00<00000002]<000[C004P009X<00`00000005II001FF@0?001FF@0300000000
:HP002V800@002V800<00000001FF@00EUT02000EUT01@00000005II001FF@00EUT0000000D002f=
00<00000001FF@00EUT02P00EUT00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00030?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`0=0008G`4000006<006?b1@00
000:0035N@<000000P00aGT0100000000:d`002]<0000002002]<18002J30P00000@001FF@030000
0000:HP002V800@002V800<00000001FF@00EUT02@00EUT01000000005II001FF@000005000]S@03
00000000EUT005II00X005II00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00
0`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l0340025l1000001S001SlPD00000
2@00aGT4000000H00<Ei00<00000002]<00000000P00[C0@000VP`<0000000<005II00000000EUT0
3P00EUT00`00000002V8000YR004000YR00300000000EUT005II00X005II00<00000001FF@000000
1@00;Hd00`00000005II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool000<0oooo00<000000?ooo`3oool0103oool00`000000025l000QO00^000QO0@00000HP00
Ho86000000P00<Ei1000000;0035N@8000000P00[C0=000VP`<000000P00Ho801000000005II001F
F@00000>001FF@0300000000:HP002V800@002V800<00000001FF@00EUT02P00EUT00`00000005II
00000005000]S@0300000000EUT005II00X005II00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`000`3oool00`000000oooo0?ooo`040?ooo`03000000008G`0025l02/0025l1000
001S001SlP@000002@00aGT3000000h00<Ei0`000002002]<0T002J310000006001SlP0300000000
EUT0000000h005II00<00000000YR000:HP01@00:HP00`00000005II001FF@0:001FF@8000001@00
;Hd00`00000005II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool00080oooo00<000000?ooo`3oool01@3oool00`000000025l000QO00X000QO0@00000HP00Ho85
000000800<Ei00<000000035N@00aGT00`00aGT4000000h00<Ei0`0000030035N@0300000000[C00
02J300@002J3100000000`00:8L006?b001SlP08001SlP0300000000EUT0000000h005II00<00000
000YR000:HP01000:HP00`00000005II001FF@0;001FF@8000001000;Hd00`00000005II001FF@0:
001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00080oooo00<000000?oo
o`3oool01@3oool00`000000025l000QO00T000QO0D00000HP00Ho85000000H00<Ei00<000000035
N@0000000P00000>0035N@@000001`00aGT00`00000002J3000VP`030000008002R73P00Ho800`00
000005II0000000=001FF@0300000000:HP002V800@002V800<00000001FF@00EUT03000EUT00`00
000002f=000]S@02000]S@0300000000EUT005II00X005II00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`000P3oool00`000000oooo0?ooo`050?ooo`03000000008G`0025l0240
025l1@00001R001SlP@000002@00aGT3000000d00<Ei1000000<0035N@8000000P00:8LB001SlP03
00000000EUT0000000`005II00<00000000YR000:HP01000:HP00`00000005II001FF@0<001FF@03
00000000;Hd002f=00<002f=00<00000001FF@00EUT02@00EUT00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00020?ooo`030000003oool0oooo00D0oooo00<00000000QO0008G`0
7P008G`50000064006?b1@0000090035N@<000000`00aGT00`0000000<Ei0035N@070035N@<00000
3P00aGT3000XQaH006?b00<00000001FF@0000002`00EUT00`00000002V8000YR004000YR0030000
0000EUT005II00`005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@0:001FF@030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00080oooo00<000000?ooo`3oool0103o
ool00`000000025l000QO00L000QO0D00000H@00Ho84000000X00<Ei0`0000070035N@0300000000
aGT00<Ei00800<Ei1000000<0035N@8000000`00:8LJ001SlP0300000000EUT0000000X005II00<0
0000000YR000:HP01000:HP00`00000005II001FF@0<001FF@0300000000;Hd002f=00<002f=00<0
0000001FF@00EUT02P00EUT00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0002
0?ooo`030000003oool0oooo00@0oooo00<00000000QO0008G`06@008G`50000060006?b1@000009
0035N@@000002`00aGT4000000/00<Ei10000002000XQal006?b00<00000001FF@0000002@00EUT0
0`00000002V8000YR004000YR00300000000EUT005II00`005II00<00000000]S@00;Hd00`00;Hd0
0`00000005II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0080oooo00<000000?ooo`3oool0103oool00`000000025l000QO00F000QO0D00000H000Ho850000
00T00<Ei0`00000<0035N@D000002P00aGT300000003001SlP00:8L002R7028006?b00<00000001F
F@0000002@00EUT00`00000002V8000YR004000YR00300000000EUT005II00`005II00<00000000]
S@00;Hd00`00;Hd00`00000005II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00080oooo00<000000?ooo`3oool0103oool00`000000025l000QO00C000QO0@0
0000H@00Ho84000000<00<Ei00<000000035N@00aGT01000aGT3000000`00<Ei0`0000050035N@03
00000000aGT00<Ei00<00<Ei100000000`00Ho8002R7000XQ`0V001SlP0300000000EUT0000000P0
05II00<00000000YR000:HP01000:HP00`00000005II001FF@0<001FF@0300000000;Hd002f=00<0
02f=00<00000001FF@00EUT02P00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0
oooo00000`3oool000000?ooo`060?ooo`03000000008G`0025l0100025l1000001Q001SlP@00000
1`00aGT00`0000000<Ei0035N@03000000`00<Ei0`0000090035N@0300000000aGT0000000800000
0P00Ho82000XQbX006?b00<00000001FF@0000001`00EUT00`00000002V8000YR004000YR0030000
0000EUT005II00`005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@0:001FF@030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool000030?ooo`000000oooo00H0oooo00<0
0000000QO0008G`03@008G`40000064006?b1000000:0035N@<000002`00aGT4000000/00<Ei0`00
0002001SlP8002R7;P00Ho800`00000005II00000006001FF@0300000000:HP002V800@002V800<0
0000001FF@00EUT03000EUT00`00000002f=000]S@03000]S@8000002`00EUT00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00000`3oool000000?ooo`060?ooo`03000000008G`0
025l00X0025l1000001P001SlP@000002`00aGT3000000800<Ei00<000000035N@00aGT01P00aGT3
000000/00<Ei10000002001SlP8002R7<P00Ho800`00000005II00000005001FF@0300000000:HP0
02V800@002V800<00000001FF@00EUT03000EUT01000000002f=000]S@00;Hd4000000/005II00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`0000<0oooo0000003oool01P3oool0
0`000000025l000QO007000QO0@00000H000Ho84000000X00<Ei100000060035N@0400000000aGT0
0<Ei0035N@@000002`00aGT3000000<006?b00<002R7001SlP00Ho80=@00Ho800`00000005II0000
0004001FF@0300000000:HP002V800@002V800<00000001FF@00EUT03@00EUT30000008002f=0P00
000<001FF@030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool000030?ooo`000000
oooo00D0oooo00<00000000QO0008G`01@008G`40000060006?b1000000:0035N@<000002`00aGT3
000000/00<Ei10000003001SlP03000XQ`00Ho8006?b03T006?b0P000004001FF@0300000000:HP0
02V800D002V800<00000001FF@00EUT03000EUT00`00000002f=000]S@02000]S@0300000000EUT0
000000/005II00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`0000<0oooo0000
003oool01@3oool00`000000025l000QO002000QO0@00000G`00Ho85000000X00<Ei0`00000;0035
N@<0000000<00<Ei00000000aGT02000aGT3000000<006?b0P00:8Ln001SlP0300000000EUT00000
00<005II00<00000000YR000:HP01@00:HP00`00000005II001FF@0<001FF@0300000000;Hd002f=
00<002f=00<00000001FF@0000002P00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00000`3oool000000?ooo`050?ooo`03000000008G`0000000<00000G`00Ho84000000@0
0<Ei00<000000035N@00aGT00`00aGT4000000X00<Ei100000050035N@0300000000aGT00<Ei00<0
0<Ei0`000003001SlP8002R7@P00Ho800`00000005II00000003001FF@0300000000:HP002V800@0
02V800<00000001FF@00EUT03000EUT00`00000002f=000]S@03000]S@0400000000EUT005II0000
00T005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`0000<000000?ooo`3o
ool01@3oool3000005l006?b100000080035N@0300000000aGT00000008000002`00aGT3000000X0
0<Ei1@000003001SlP8002R7AP00Ho800`00000005II00000002001FF@0300000000:HP002V800@0
02V800<00000001FF@00EUT03000EUT00`00000002f=000]S@03000]S@0500000000EUT005II001F
F@0000002000EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00000`000000
oooo0?ooo`020?ooo`<000000P3oool00`00000006?b001SlP1J001SlP<000002P00aGT4000000/0
0<Ei0`00000;0035N@@000000`00Ho82000XQdX006?b00D00000001FF@00000005II00000006000Y
R00300000000EUT005II00`005II00<00000000]S@00;Hd00`00;Hd01@00000005II001FF@00EUT0
000000P005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`0000<000000?oo
o`0000000P0000060?ooo`0300000000Ho8006?b05D006?b1000000:0035N@<000001000aGT00`00
00000<Ei0035N@040035N@@000002`00aGT3000000@006?b0P00:8LP001SlP<00000:`00Ho801000
000005II000000000006000YR00300000000EUT005II00`005II00<00000000]S@00;Hd00`00;Hd0
0`00000005II001FF@02001FF@0300000000EUT005II00D005II00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`000P00000:0?ooo`0300000000Ho8006?b054006?b1000000:0035
N@<000002000aGT00`0000000<Ei0035N@03000000/00<Ei10000004001SlP03000XQ`00Ho8006?b
01h006?b100000020:80N@0300000000Ho8006?b02X006?b00<00000001FF@0000001P00:HP00`00
000005II001FF@0<001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT00`00EUT00`00
000005II001FF@04001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00080
oooo00<000000?ooo`3oool0203oool2000004h006?b0`00000:0035N@@000002P00aGT4000000/0
0<Ei0`000005001SlP03000XQ`00Ho8006?b01`006?b00<00000001SlP0000000`0000060:80N@03
00000000Ho8006?b02X006?b0P000006000YR00300000000EUT005II00`005II00<00000000]S@00
;Hd00`00;Hd00`00000005II001FF@04001FF@0300000000EUT005II00<005II00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`000`3oool00`000000oooo0?ooo`090?ooo`030000
0000Ho8006?b04L006?b100000020035N@0300000000aGT00<Ei00D00<Ei0`00000;0035N@<00000
0`00aGT00`0000000<Ei0035N@050035N@@000001@00Ho800`00:8L006?b001SlP0M001SlP@00000
2`2R07T00`00000006?b001SlP0Z001SlP8000001@00:HP00`00000005II001FF@0<001FF@030000
0000;Hd002f=00<002f=00<00000001FF@00EUT01@00EUT00`00000005II001FF@03001FF@030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool000@0oooo00<000000?ooo`3oool02@3o
ool00`00000006?b001SlP13001SlP@000001P00aGT0100000000<Ei0035N@00aGT3000000/00<Ei
0`0000070035N@0400000000aGT00<Ei0035N@<000001P00Ho800`00:8L006?b001SlP0L001SlPD0
000000<0XP1i0000002R07T0302R07T00`00000006?b001SlP0V001SlP0300000000:HP002V80080
02V800<00000000YR000:HP00P00:HP00`00000005II001FF@0<001FF@0300000000;Hd002f=00<0
02f=00<00000001FF@00EUT01@00EUT00`00000005II001FF@03001FF@030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool000D0oooo0P00000:0?ooo`0300000000Ho8006?b03l006?b
0`00000:0035N@@000002P00aGT4000000/00<Ei0`000006001SlP03000XQ`00Ho8006?b01/006?b
1P0000050:80N@030000002R07T0XP1i00/0XP1i00<00000001SlP00Ho807`00Ho84000000P002V8
00D00000000YR000:HP002V80000000?001FF@0300000000;Hd002f=008002f=00<00000001FF@00
EUT01P00EUT00`00000005II001FF@02001FF@030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool0203oool00`00000006?b001SlP0j001SlP@00000
2P00aGT3000000800<Ei00<000000035N@00aGT01P00aGT3000000/00<Ei10000006001SlP03000X
Q`00Ho8006?b01X006?b1P00000:0:80N@030000002R07T0XP1i00/0XP1i00<00000001SlP00Ho80
6P00Ho84000000d002V800@00000000YR000:HP000003`00EUT00`00000002f=000]S@03000]S@03
00000000EUT005II00H005II00D00000001FF@00EUT005II000000050?ooo`030000003oool0oooo
00D0oooo00080?ooo`030000003oool0oooo00P0oooo0P00000g001SlP<000002P00aGT4000000H0
0<Ei00<000000035N@00aGT00P00aGT3000000/00<Ei0`000006001SlP8002R77000Ho86000000h0
XP1i00<000000:80N@2R07T02`2R07T00`00000006?b001SlP0F001SlP@000000P00[C0?000YR003
00000000:HP0000000l005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@07001FF@04
00000000EUT005II000000D0oooo00<000000?ooo`3oool01@3oool000T0oooo0P00000:0?ooo`03
00000000Ho8006?b034006?b0`00000:0035N@<000002`00aGT4000000X00<Ei10000006001SlP03
000XQ`00Ho8006?b01X006?b1P0000040:80N@030000002R07T0XP1i00`0XP1i00<000000:80N@2R
07T02`2R07T00`00000006?b0000000;001SlP03000XQ`00Ho8006?b00<006?b100000001000[C00
0000002]<0000002002]<0l002V800@00000000YR000:HP000003P00EUT00`00000002f=000]S@03
000]S@0300000000EUT005II00L005II00@00000001FF@00EUT000001@3oool00`000000oooo0?oo
o`050?ooo`002`3oool00`000000oooo0?ooo`080?ooo`0300000000Ho8006?b02`006?b1@000009
0035N@<000002`00aGT3000000030035N@0000000<Ei00P00<Ei0`000007001SlP03000XQ`00Ho80
06?b01/006?b1@0000080:80N@030000002R07T0XP1i00`0XP1i00<000000:80N@2R07T02@2R07T4
000000P006?b00<002R7001SlP00Ho800`00Ho83000000<00<Ei00D00000002]<00000000:d`0000
0002002]<10002V800<00000000YR00000003P00EUT00`00000002f=000]S@03000]S@0300000000
EUT005II00P005II00<00000001FF@0000001@3oool00`000000oooo0?ooo`050?ooo`00303oool0
0`000000oooo0?ooo`080?ooo`0300000000Ho8006?b02P006?b0`0000050035N@0300000000aGT0
0<Ei00800<Ei1000000:0035N@@000001@00aGT00`0000000<Ei0035N@030035N@<000001`00Ho80
0`00:8L006?b001SlP0N001SlP800000302R07T00`000000XP1i0:80N@0<0:80N@030000002R07T0
XP1i00D0XP1i0`0000030:80N@0300000000Ho8006?b008006?b00<002R7001SlP00Ho800`00Ho84
000000L00<Ei0P0000001000[C000000002]<000[C0A000YR08000003P00EUT00`00000002f=000]
S@03000]S@0300000000EUT005II00T005II0P0000050?ooo`030000003oool0oooo00D0oooo000=
0?ooo`030000003oool0oooo00P0oooo0P00000U001SlP<000002@00aGT4000000/00<Ei0`00000:
0035N@D000001`00Ho800`00:8L006?b001SlP0R001SlP030?P0=`2R07T0XP1i00/0XP1i00<00000
0:80N@2R07T0302R07T010000000XP1i0:80N@2R07T3000000L0XP1i00<00000000XQ`00Ho801000
Ho83000000X00<Ei0`000002002]<00300000000[C000:d`014002V800<00000001FF@00EUT03000
EUT00`00000002f=000]S@03000]S@0300000000EUT005II00X005II00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`003P3oool2000000X0oooo00<00000001SlP00Ho807P00Ho84
000000X00<Ei1000000:0035N@<000002`00aGT4000000L006?b00<002R7001SlP00Ho809P00Ho80
0`3h03L000000:80N@0;0:80N@030000002R07T0XP1i00/0XP1i1000000;0:80N@0300000000Ho80
000000<000002P00aGT3000000<00<Ei00<00000002]<00000000P00[C0A000YR08000003@00EUT0
0`00000002f=000]S@03000]S@0300000000EUT005II00/005II00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`00403oool00`000000oooo0?ooo`080?ooo`0300000000Ho8006?b
01X006?b0`00000:0035N@@000001000aGT00`0000000<Ei0035N@030035N@@000002`00aGT30000
00P006?b00<002R7001SlP00Ho80:P00Ho800`3h03L000000:80N@0;0:80N@030000002R07T0XP1i
00L0XP1i0`0000020:80N@030000002R07T0XP1i00X0XP1i0P00000:0035N@@000001`00aGT20000
00800:d`3`00:HP300000003001FF@00000005II00/005II00<00000000]S@00;Hd00`00;Hd00`00
000005II001FF@0;001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00140
oooo00<000000?ooo`3oool0203oool00`00000006?b001SlP0F001SlP<000002P00aGT3000000T0
0<Ei00<000000035N@0000000P00000;0035N@@000002000Ho800`00:8L006?b001SlP0^001SlP03
0?P0=`000000XP1i00/0XP1i00<000000:80N@2R07T00`2R07T3000000H0XP1i00<000000:80N@2R
07T02P2R07T2000000H00<Ei0`00000:0035N@<000000P00[C0;000YR0@000000P00Ho8010000000
05II001FF@00000;001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT02`00EUT00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo000B0?ooo`8000002@3oool00`000000
06?b001SlP0B001SlP<000002@00aGT4000000/00<Ei0`00000;0035N@<00000?P00Ho800`3h03L0
00000:80N@0;0:80N@030000002R07T00000008000002P2R07T00`000000XP1i0:80N@0:0:80N@80
00000P00aGT3000000X00<Ei0`0000030035N@0300000000[C0002V800D002V81@000007001SlP03
00000000EUT0000000/005II00<00000000]S@00;Hd00`00;Hd00`00000005II001FF@0;001FF@03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3oool0
1`3oool2000000l006?b0`000003000VP`0300000000aGT00<Ei00<00<Ei0`00000;0035N@@00000
0`00aGT00`0000000<Ei0035N@040035N@@00000@P00Ho800`3h03L000000:80N@080:80N@@00000
3P2R07T00`000000XP1i0:80N@0:0:80N@<000002@00aGT4000000L00<Ei00<00000000YR000:HP0
1000000=001SlP0300000000EUT0000000X005II00<00000000]S@00;Hd00`00;Hd00`00000005II
001FF@0;001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool001D0oooo00<0
00000?ooo`3oool0203oool00`00000006?b001SlP08001SlP@0000000<0oooo000000009X<01000
9X<00`0000000<Ei00000002000000/00<Ei0`0000080035N@0300000000aGT00<Ei00<000002@00
Ho800`00:8L006?b001SlP0k001SlP030?P0=`000000XP1i00@0XP1i0`0000040:80N@030000002R
07T0XP1i00`0XP1i00<000000:80N@2R07T02P2R07T3000000D00<Ei0`00000:0035N@@000004P00
Ho800`00000005II0000000:001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT02P00
EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo00P0oooo00<00000001SlP00Ho801000Ho83000000D0oooo00<00000000VP`009X<00`009X<2
000000X00<Ei1000000;0035N@<000002@00Ho800`00:8L006?b001SlP0o001SlP030?P0=`000000
XP1i00<00000202R07T00`000000XP1i0:80N@0<0:80N@030000002R07T0XP1i00T0XP1i0`000002
0035N@<000002P00aGT3000001L006?b00<00000001FF@0000002@00EUT00`00000002f=000]S@03
000]S@0300000000EUT005II00X005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`005`3oool2000000T0oooo00<00000001SlP00Ho800`0000080?ooo`03000000009X<002J3
00D002J30P0000050035N@<000002`00aGT4000000T006?b00<002R7001SlP00Ho80@`00Ho820000
00`0XP1i0P00000=0:80N@030000002R07T0XP1i00@0XP1i100000020:80N@<000002@00aGT40000
01/006?b00<00000001FF@0000002000EUT00`00000002f=000]S@03000]S@0300000000EUT005II
00X005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`006@3oool00`000000
oooo0?ooo`070?ooo`8000002`3oool00`00000002J3000VP`07000VP`0300000000aGT000000080
00002`00aGT3000000X006?b00<002R7001SlP00Ho80A`00Ho800`3h03L000000:80N@0;0:80N@80
00003@2R07T00`000000XP1i0:80N@03000000L0XP1i0P0000050035N@04000YR000000000000000
020006?b00<00000001FF@0000001`00EUT00`00000002f=000]S@03000]S@0300000000EUT005II
00X005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`006P3oool00`000000
oooo0?ooo`0C0?ooo`03000000009X<002J300L002J30P00000:0035N@@00000F000Ho800`3h03L0
00000:80N@0<0:80N@030000002R07T0XP1i00T0XP1i1000000;0:80N@80000000<002V80035N@00
00000P00000S001SlP0300000000EUT0000000L005II00<00000000]S@00;Hd00`00;Hd00`000000
05II001FF@0;001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo
0P00000C0?ooo`03000000009X<002J300T002J300<000000035N@00aGT01000aGT3000005T006?b
0P00DD<01000Ho8000000?P0=`00000=0:80N@030000002R07T0XP1i00@0XP1i100000030:80N@03
0000002R07T0XP1i00X0XP1i0`00000W001SlP0300000000EUT0000000H005II00<00000000]S@00
;Hd00`00;Hd00`00000005II001FF@0;001FF@030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool001d0oooo00<000000?ooo`3oool0403oool=000VP`0300000000aGT00<Ei00<00000
F@00Ho800`00DD<006?b001SlP03000000800<Ei0P00000=0:80N@030000002R07T0000000<00000
202R07T00`000000XP1i0:80N@0:0:80N@0300000000Ho8006?b02L006?b00<00000001FF@000000
1@00EUT00`00000002f=000]S@03000]S@0300000000EUT005II00/005II00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`0300000000
9X<002J300/002J30`00001I001SlP03001A@`00Ho80000000<000001`00aGT00`000000XP1i0:80
N@080:80N@@000003@2R07T00`000000XP1i0:80N@090:80N@800000:@00Ho800`00000005II0000
0004001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT02`00EUT00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo000O0?ooo`030000003oool0oooo00d0oooo00<00000
000VP`009X<020009X<3000005T006?b00<00553001SlP0000000P00000:0035N@<000001P2R07T3
000000@0XP1i00<000000:80N@2R07T02`2R07T00`000000XP1i0:80N@090:80N@800000:@00Ho80
0`00000005II00000003001FF@0300000000;Hd002f=00<002f=00<00000001FF@00EUT02`00EUT0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000P0?ooo`8000003@3oool00`00
000002J3000VP`05000VP`<00000F000Ho800`00DD<006?b00000003000000X00<Ei0`0000030035
N@030000002R07T0000000<00000202R07T00`000000XP1i0:80N@0:0:80N@030000002R07T0XP1i
00T0XP1i1000000X001SlP0300000000EUT00000008005II00<00000000]S@00;Hd00`00;Hd00`00
000005II001FF@0;001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00280
oooo00<000000?ooo`3oool02P3oool00`00000002J3000VP`02000VP`<00000F000Ho800`00DD<0
06?b00000004000000P00<Ei100000060035N@8000003@2R07T00`000000XP1i0:80N@0:0:80N@03
0000002R07T0XP1i00D0XP1i0`0000020:80N@800000:000Ho801P00000005II001FF@00000005II
000000H002f=00<00000001FF@00EUT02P00EUT00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo000S0?ooo`030000003oool0oooo00T0oooo0P009X<3000005P006?b00<005530000
000000000P0000050035N@0300000000aGT00<Ei00800<Ei0`00000:0035N@<000003@2R07T00`00
0000XP1i0:80N@0:0:80N@030000002R07T0XP1i00@000001P2R07T2000002P006?b00<00000001F
F@0000000P00EUT00`00000002f=000]S@03000]S@0300000000EUT005II00X005II00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`00903oool2000000T0oooo0P00001I001SlP<0
00002P00aGT4000000X00<Ei0`0000030035N@030000002R07T0XP1i00X0XP1i00<000000:80N@2R
07T02P2R07T3000000/0XP1i0P00000X001SlP0500000000EUT00000001FF@0000001@00;Hd00`00
000005II001FF@0:001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool002H0
oooo00<000000?ooo`3oool0203oool00`00000006?b001SlP1A001SlP03001A@`00000000000080
00002@00aGT4000000030035N@0000000<Ei00H00<Ei00<002V80000000000000P0000070035N@03
0000002R07T0XP1i00X0XP1i00<000000:80N@2R07T01@2R07T400000080XP1i00<000000:80N@2R
07T02P2R07T2000002P006?b00@00000001FF@00000000001@00;Hd00`00000005II001FF@0;001F
F@030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool002L0oooo00<000000?ooo`3o
ool0203oool00`00000006?b001SlP1=001SlP@000002P00aGT3000000H00<Ei00<00000000YR000
:HP00P00aGT3000000/00<Ei0P00000<0:80N@030000002R07T0XP1i00@000001`2R07T00`000000
XP1i0:80N@0:0:80N@800000:000Ho800`00000005II00000005000]S@0300000000EUT005II00/0
05II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`00:03oool00`000000oooo
0?ooo`080?ooo`0300000000Ho8006?b04T006?b0`00000:0035N@@000001@00aGT2000YR0<00<Ei
1000000:0035N@<000000`00Ho800`000000XP1i0:80N@090:80N@<00000302R07T00`000000XP1i
0:80N@0:0:80N@800000:000Ho83000000@002f=00<00000001FF@00EUT02`00EUT00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo000Y0?ooo`8000002@3oool2000004D006?b1P00
00080035N@<000001000aGT00`00:HP00<Ei0035N@030035N@@0000000<00<Ei00000000aGT02000
aGT2000000P006?b00<000000:80N@2R07T0102R07T400000080XP1i00<000000:80N@2R07T02`2R
07T00`000000XP1i0:80N@0:0:80N@8000009P00Ho8300000003000]S@00000002f=008002f=00<0
0000001FF@00EUT02`00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000[
0?ooo`030000003oool0oooo00P0oooo00<00000001SlP00Ho80?`00Ho83000000H00<Ei00@00000
0035N@00aGT00<Ei100000020035N@03000YR000aGT00<Ei00D00<Ei0`0000060035N@0300000000
aGT00<Ei00800<Ei0`00000<001SlP030000002R07T0XP1i00<000001`2R07T00`000000XP1i0:80
N@0;0:80N@030000002R07T0XP1i00X0XP1i0P00000Q001SlP@000001000;Hd01@00000002f=000]
S@00;Hd0000000d005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`00;03o
ool00`000000oooo0?ooo`080?ooo`0300000000Ho8006?b03X006?b1000000:0035N@<0000000<0
0<Ei000YR000aGT01`00aGT4000000X00<Ei0`00000A001SlP8000002`2R07T00`000000XP1i0:80
N@0;0:80N@030000002R07T0XP1i00P0XP1i0`00000N001SlP<000002@00;Hd01000000002f=000]
S@00000=001FF@030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool002d0oooo0P00
00090?ooo`0300000000Ho8006?b03H006?b0`00000:0035N@@0000000<00<Ei00000000aGT01`00
aGT3000000/00<Ei0`00000E001SlP030000002R07T0XP1i00X0XP1i00<000000:80N@2R07T02`2R
07T00`000000XP1i0:80N@030:80N@@000007@00Ho84000000d002f=00<00000000]S@0000003@00
EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000_0?ooo`030000003oool0
oooo00L0oooo0P00000b001SlP@000002P00aGT3000000H00<Ei00@000000035N@00aGT00<Ei1000
000:0035N@<000000`00Ho800`00000006?b001SlP0D001SlP030000002R07T0XP1i00X0XP1i00<0
00000:80N@2R07T02`2R07T5000001d006?b100000000`00[C000000002]<00?000]S@8000003@00
EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000`0?ooo`030000003oool0
oooo00P0oooo00<00000001SlP00Ho80;000Ho83000000X00<Ei1000000:0035N@<000002`00aGT2
000001l006?b00<000000:80N@2R07T02P2R07T00`000000XP1i0:80N@070:80N@@000007@00Ho86
00000005002]<00000000:d`00000000[C004000;Hd2000000`005II00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`080?ooo`0300000000Ho80
06?b02L006?b1P0000080035N@<000002P00aGT4000000030035N@0000000<Ei00L00<Ei0P00000T
001SlP030000002R07T0XP1i00X0XP1i00<000000:80N@2R07T00P2R07T4000001h006?b1P000002
0035N@0600000000[C000000002]<00000000:d`4@00;Hd00`00000005II001FF@0;001FF@030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool00380oooo0P0000090?ooo`8000008`00
Ho84000000H00<Ei00@000000035N@00aGT00<Ei1000000:0035N@<000001P00aGT00`0000000<Ei
0035N@020035N@800000:000Ho800`000000XP1i0:80N@0:0:80N@@000007P00Ho86000000L00<Ei
0P0000000`00[C000000002]<00A000]S@8000003000EUT00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo000d0?ooo`030000003oool0oooo00P0oooo00<00000001SlP00Ho807@00
Ho83000000X00<Ei1000000:0035N@@000002P00aGT2000002d006?b00<000000:80N@2R07T01@2R
07T4000001h006?b1P00000:0035N@<000000P00[C000`0000000:d`000]S@0?000]S@8000003000
EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo000e0?ooo`030000003oool0
oooo00P0oooo00<00000001SlP00Ho806000Ho84000000X00<Ei0`0000020035N@0300000000aGT0
0<Ei00H00<Ei0`00000;0035N@0500000000Ho8006?b001SlP000000;P00Ho800`000000XP1i0:80
N@04000001h006?b1P00000:0035N@@000000`00aGT0100000000:d`00000000[C0>000]S@<00000
00<005II00000000EUT02P00EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
000f0?ooo`8000002@3oool00`00000006?b001SlP0D001SlP<000002P00aGT4000000H00<Ei0P00
00020035N@@000002P00aGT2000000H006?b00<00000001SlP00Ho80;@00Ho82000001l006?b1P00
00090035N@@000001`00aGT300000003002]<000;Hd002f=00P002f=10000002001SlP0400000000
EUT005II000000X005II00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00>03o
ool00`000000oooo0?ooo`070?ooo`8000004000Ho84000000X00<Ei0`00000:0035N@@000002`00
aGT00`00000006?b001SlP1E001SlPH000002@00aGT4000000L00<Ei100000020035N@0300000000
[C0002f=00D002f=10000007001SlP0400000000EUT005II000000T005II00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`0300000000
Ho8006?b00T006?b10000004000YR00300000000aGT00<Ei00<00<Ei1000000:0035N@<000000`00
aGT00`0000000<Ei0035N@050035N@0300000000Ho8006?b05D006?b1P0000040035N@0300000000
aGT00<Ei00800<Ei100000070035N@@000001`00aGT00`00000002f=000]S@04000000`006?b00@0
0000001FF@00EUT000002000EUT00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
000j0?ooo`030000003oool0oooo00P0oooo00<00000001SlP00Ho801@00Ho8300000080oooo00<0
0000000YR000:HP01000:HP00`0000000<Ei00000002000000X00<Ei100000070035N@8000000P00
aGT00`00000006?b001SlP1D001SlPH000002@00aGT4000000P00<Ei0`00000:0035N@@000004@00
Ho801000000005II001FF@000007001FF@030000003oool0oooo00@0oooo0@0000010?ooo`40oooo
000k0?ooo`8000002@3oool00`00000006?b001SlP04000000D0oooo00<00000000YR000:HP01000
:HP2000000X00<Ei0`00000;0035N@800000EP00Ho85000000T00<Ei100000000`00aGT000000035
N@050035N@@000002P00aGT3000001H006?b00<00000001FF@0000001`00EUT00`000000oooo0?oo
o`040?ooo`4000000@3oool10?ooo`00?@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool0
0`00000002V8000YR006000YR08000001000aGT4000000/00<EiE`00Ho85000000T00<Ei10000006
0035N@0300000000aGT0000000<000002P00aGT4000001X006?b00<00000001FF@0000001`00EUT0
0`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`00?P3oool00`000000oooo0?ooo`0@0?oo
o`0300000000:HP002V800T002V81000000;0035N@0300000000Ho8006?b05@006?b1@0000090035
N@@000002000aGT4000000X00<Ei1000000O001SlP0300000000EUT0000000H005II00<000000?oo
o`3oool00`3oool100000040oooo0@3oool003l0oooo0P00000@0?ooo`0300000000:HP002V800P0
02V80`00000:0035NEH006?b1@0000020035N@0300000000aGT00<Ei00@00<Ei100000080035N@@0
00000`00aGT00`0000000<Ei0035N@040035N@@000009000Ho800`00000005II00000005001FF@03
0000003oool0oooo00<0oooo0@0000010?ooo`40oooo00110?ooo`030000003oool0oooo00d0oooo
00<00000000YR000:HP02`00:HP00`0000000<Ei0035N@030035NEL006?b1@0000060035N@030000
0000aGT0000000<000002000aGT4000000P00<Ei00<000000035N@0000000`00000Y001SlP030000
0000EUT0000000@005II00<000000?ooo`3oool00`3oool100000040oooo0@3oool00480oooo00<0
00000?ooo`3oool0303oool00`00000002V8000YR00:000YR0<0000000<00<Ei001SlP00Ho80E000
Ho85000000P00<Ei100000080035N@@000002P00aGT4000002d006?b00@00000001FF@00EUT00000
0`00EUT00`000000oooo0?ooo`030?ooo`4000000@3oool10?ooo`00@`3oool00`000000oooo0?oo
o`0;0?ooo`0300000000:HP002V800H002V81000001F001SlPD000002000aGT4000000@00<Ei00<0
00000035N@00aGT00P00aGT3000000X00<Ei1000000b001SlP0400000000EUT005II0000008005II
00<000000?ooo`3oool00`3oool100000040oooo0@3oool004@0oooo0P00000;0?ooo`0300000000
:HP002V800<002V80`00001F001SlPD000002000aGT4000000T00<Ei100000090035N@@00000=`00
Ho800`00000005II00000002001FF@030000003oool0oooo00<0oooo0@0000010?ooo`40oooo0016
0?ooo`030000003oool0oooo00P0oooo0P00:HP4000005D006?b1@0000000`00aGT000000035N@06
0035N@<000002@00aGT4000000030035N@0000000<Ei00H00<Ei1000000l001SlP0500000000EUT0
0000001FF@0000001P3oool100000040oooo00170?ooo`030000003oool0oooo00L0oooo0P00001F
001SlP@000001P00aGT00`0000000<Ei0035N@04000000P00<Ei100000060035N@0300000000aGT0
0<Ei00@00000@@00Ho801000000005II0000000000060?ooo`4000000@3oool004P0oooo0P000009
0?ooo`0300000000Ho8006?b04l006?b100000090035N@@000002000aGT4000000X00<Ei0`000016
001SlP0400000000EUT00000000000D0oooo0@0000010?ooo`00BP3oool00`000000oooo0?ooo`07
0?ooo`0300000000Ho8006?b04X006?b100000090035N@@000000`00aGT00`0000000<Ei0035N@02
0035N@@000002P00aGT4000004X006?b00<00000001FF@0000001@3oool100000040oooo001;0?oo
o`030000003oool0oooo00L0oooo00<00000001SlP00Ho80A@00Ho85000000T00<Ei0`0000080035
N@@000002P00aGT4000004l006?b0`0000040?ooo`4000000@3oool004`0oooo00<000000?ooo`3o
ool01`3oool20000048006?b1@0000080035N@@000002000aGT5000000P00<Ei1000001D001SlP80
0000103oool100000040oooo001=0?ooo`8000002@3oool00`00000006?b001SlP0k001SlP@00000
1@00aGT0100000000<Ei0035N@00aGT4000000P00<Ei100000050035N@0400000000aGT00<Ei0035
N@@00000E000Ho82000000@0oooo00D000000?ooo`3oool0oooo000000010?ooo`00C`3oool00`00
0000oooo0?ooo`070?ooo`0300000000Ho8006?b03H006?b100000090035N@@000002000aGT40000
00T00<Ei1000001B001SlP@000002@3oool010000000oooo0?ooo`0000010?ooo`00D03oool00`00
0000oooo0?ooo`070?ooo`0300000000Ho8006?b034006?b1000000:0035N@<000000P00aGT00`00
00000<Ei0035N@030035N@@000002@00aGT40000058006?b1000000>0?ooo`030000003oool0oooo
00400000001A0?ooo`800000203oool00`00000006?b001SlP0]001SlP<000002P00aGT4000000H0
0<Ei1@0000090035N@@00000DP00Ho84000001<0oooo0@0000010?ooo`400000001C0?ooo`030000
003oool0oooo00H0oooo0P00000Y001SlP@000002@00aGT4000000P00<Ei100000080035N@@00000
DP00Ho84000001P0oooo0P00000005@0oooo00<000000?ooo`3oool01`3oool00`00000006?b001S
lP0R001SlP@000001000aGT00`0000000<Ei0035N@020035N@@000002000aGT4000000@00<Ei00<0
00000035N@00aGT00P00aGT30000058006?b1000000K0?ooo`<00000001E0?ooo`030000003oool0
oooo00L0oooo00<00000001SlP00Ho807@00Ho84000000T00<Ei100000080035N@@000002@00aGT4
0000054006?b1000000K0?ooo`@000000`3oool005H0oooo0P0000080?ooo`0300000000Ho8006?b
01T006?b0`00000:0035N@D000001P00aGT4000000T00<Ei1000001A001SlP@000006P3oool50000
00L0oooo001H0?ooo`030000003oool0oooo00H0oooo0P00000E001SlP@000002@00aGT4000000D0
0<Ei00<000000035N@0000000`0000090035N@@00000D@00Ho84000001X0oooo1000000<0?ooo`00
F@3oool00`000000oooo0?ooo`070?ooo`0300000000Ho8006?b00h006?b100000090035N@@00000
1`00aGT4000000T00<Ei1000001A001SlP@000006P3oool400000100oooo001J0?ooo`800000203o
ool00`00000006?b001SlP09001SlP@000000`00;Hd00`0000000<Ei0035N@040035N@<000001`00
aGT4000000@00<Ei00<000000035N@00aGT00P00aGT40000054006?b1000000J0?ooo`@00000503o
ool005`0oooo00<000000?ooo`3oool01P3oool00`00000006?b001SlP05001SlP@000001`00;Hd6
000000L00<Ei0`0000090035N@@00000D@00Ho84000001X0oooo1000000H0?ooo`00G@3oool00`00
0000oooo0?ooo`060?ooo`0300000000Ho8006?b00@000000`3oool00`00000002f=000]S@05000]
S@<000001P00aGT4000000P00<Ei1000001A001SlP@000006@3oool5000001`0oooo001N0?ooo`03
0000003oool0oooo00H0oooo0P0000070?ooo`0300000000;Hd002f=00P002f=00<000000035N@00
00000`0000080035N@@00000D@00Ho84000001T0oooo1000000Q0?ooo`00G`3oool2000000l0oooo
00<00000000]S@00;Hd02000;Hd2000000P00<Ei1000001A001SlP@000006@3oool4000002D0oooo
001Q0?ooo`030000003oool0oooo00`0oooo00<00000000]S@00;Hd02P00;Hd00`0000000<Ei0035
N@020035N@<00000D@00Ho84000001T0oooo1000000Y0?ooo`00HP3oool00`000000oooo0?ooo`0;
0?ooo`0300000000;Hd002f=00T002f=1P00001@001SlP@000006@3oool4000002d0oooo001S0?oo
o`8000002`3oool00`00000002f=000]S@06000]S@D00000D000Ho84000001P0oooo1@00000a0?oo
o`00I@3oool00`000000oooo0?ooo`080?ooo`D002f=1@00001@001SlP@00000603oool4000003H0
oooo001V0?ooo`030000003oool0oooo00L0oooo0P00;Hd40000050006?b1000000H0?ooo`@00000
>P3oool006L0oooo00<000000?ooo`3oool01P3oool20000050006?b1000000H0?ooo`@00000?P3o
ool006P0oooo0P0000080?ooo`0300000000Ho8006?b04T006?b1000000G0?ooo`D00000@P3oool0
06X0oooo00<000000?ooo`3oool01P3oool00`00000006?b001SlP14001SlP@000005`3oool40000
04L0oooo001[0?ooo`030000003oool0oooo00H0oooo00<00000001SlP00Ho80?`00Ho84000001L0
oooo1000001;0?ooo`00K03oool2000000L0oooo0P00000k001SlP@000005`3oool4000004l0oooo
001^0?ooo`030000003oool0oooo00H0oooo00<00000001SlP00Ho80=000Ho84000001L0oooo1000
001C0?ooo`00K`3oool00`000000oooo0?ooo`060?ooo`0300000000Ho8006?b02l006?b1000000F
0?ooo`D00000E`3oool00700oooo00<000000?ooo`3oool01P3oool00`00000006?b001SlP0Z001S
lP@000005P3oool4000005`0oooo001a0?ooo`8000001`3oool2000002H006?b1000000F0?ooo`@0
0000H03oool007<0oooo00<000000?ooo`3oool01P3oool00`00000006?b001SlP0O001SlP@00000
5P3oool4000006@0oooo001d0?ooo`030000003oool0oooo00H0oooo00<00000001SlP00Ho806P00
Ho84000001D0oooo1@00001X0?ooo`00M@3oool2000000L0oooo00<00000001SlP00Ho805@00Ho84
000001D0oooo1000001]0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`8000004@00Ho840000
01D0oooo1000001a0?ooo`00N03oool00`000000oooo0?ooo`060?ooo`0300000000Ho8006?b00X0
06?b1000000E0?ooo`@00000M@3oool007T0oooo00<000000?ooo`3oool01P3oool00`00000006?b
001SlP05001SlP@000005@3oool4000007T0oooo001j0?ooo`8000001`3oool00`00000006?b001S
lP04000001@0oooo1@00001m0?ooo`00O03oool00`000000oooo0?ooo`040?ooo`<00000503oool4
00000880oooo001m0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool40000
08H0oooo001n0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`@00000RP3oool00800oooo
00@000000?ooo`3oool000002P3oool4000008h0oooo00210?ooo`030000003oool0000000D0oooo
1@00002B0?ooo`00PP3oool2000000030?ooo`000000000000800000U`3oool008<0oooo0P00002K
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {316.125, 0}} -> {0.0525512, -9.73739*^-5, \
0.00292675, 0.00292675}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot the field signature of the shim", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  ___  ___\ Magnets\ \ \ ___  ___  ___  ___*) \
\[IndentingNewLine]\[IndentingNewLine]\(x = 
        8;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  (*\ Horiz . \ 
          position\ where\ the\ field\ signature\ is\ computed\ *) \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), \
"\[IndentingNewLine]", 
    \(\(z = 
        10;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*\ Vertic . \ 
          position\ where\ the\ field\ signature\ is\ computed\ *) \ \ \ \ \
\), "\[IndentingNewLine]", 
    \(\(xmin = \(-30\);\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Min\ Horiz . \ 
          position\ for\ the\ field\ integral\ signature\ *) \ \ \ \ \), "\
\[IndentingNewLine]", 
    \(\(xmax = 30;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Max\ Horiz . \ 
          position\ for\ the\ field\ integral\ signature\ *) \ \ \ \ \), "\
\[IndentingNewLine]", 
    \(\(dx = 
        2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*\ Step\ of\ Horiz . \ 
          position\ for\ the\ field\ integral\ signature\ *) \ \ \ \ \), "\
\[IndentingNewLine]", 
    \(\(npts = 100;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Number\ of\ points\ in\ the\ field\ signature\ *) \), "\
\[IndentingNewLine]", 
    \(\(b = "\<bz\>";\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  (*\ Field\ Component\ can\ \(be\  : \ "\<bx\>"\), \ "\<bz or \>" 
        by \*"\"\<  \>"*) \), "\[IndentingNewLine]", 
    \(\(ib = \ "\<ibz\>";\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*\ Field\ Integral\ Component\ can\ \(be\  : \ "\<ibx\>"\ or\ "\<ibz\>"\)\ *) \
\[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___\ \
Computation\ \ \ \ ___  ___  ___  ___*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(r1 = RadSolve[magnetpole, 0.0001, 200];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Result of RadSolve without Shim = \>", \ 
        r1];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(t1 = 
        radFldLst[magnetpole, b, {x, \(-per\), z}, {x, per, z}, 
          npts];\)\), "\[IndentingNewLine]", 
    \(\(ti1 = 
        Table[radFldInt[magnetpole, "\<inf\>", 
            ib, {xx, \(-1\), z}, {xx, 1, z}], \ {xx, xmin, xmax, 
            dx}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(r2 = RadSolve[all, 0.0001, 200];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Result of RadSolve with    Shim = \>", \ 
        r2];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(t2 = \(-t1\) + 
          radFldLst[all, b, {x, \(-per\), z}, {x, per, z}, 
            npts];\)\), "\[IndentingNewLine]", 
    \(\(ti2 = \(-ti1\) + 
          Table[radFldInt[all, "\<inf\>", 
              ib, {xx, \(-1\), z}, {xx, 1, z}], \ {xx, xmin, xmax, 
              dx}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(t3 = 
        radFldLst[shim, b, {x, \(-per\), z}, {x, per, z}, 
          npts];\)\), "\[IndentingNewLine]", 
    \(\(xx = 
        Table[y, {y, \(-per\), per, 2*per/\((npts - 1)\)}]\  // 
          N;\)\), "\[IndentingNewLine]", 
    \(\(xxi = 
        Table[xx, {xx, xmin, xmax, dx}] // 
          N;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ListPlot[Transpose[{xx, t2}], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All, 
        PlotLabel \[Rule] "\<Signature of Vert. Field[T] vs longit. \
position[mm] @ x=8 and z=10 mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Transpose[{xxi, ti2}], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All, 
        PlotLabel \[Rule] "\<Signature of Vertical Field Integral[Tmm] vs \
horiz.position[mm]\>"];\)\[IndentingNewLine]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Result of RadSolve without Shim = \
"\[InvisibleSpace]{0.00009633926299901712`, 2.1584921013809613`, 
          0.9743655781259423`, 113}\),
      SequenceForm[ 
      "Result of RadSolve without Shim = ", {9.6339262999017123*^-05, 
        2.1584921013809613, 0.97436557812594227, 113}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Result of RadSolve with    Shim = \
"\[InvisibleSpace]{0.00009688406312363614`, 2.162205808562896`, 
          1.2108482302329895`, 112}\),
      SequenceForm[ 
      "Result of RadSolve with    Shim = ", {9.6884063123636136*^-05, 
        2.1622058085628959, 1.2108482302329895, 112}],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0136054 0.590732 382.011 [
[.09184 .57823 -9 -9 ]
[.09184 .57823 9 0 ]
[.22789 .57823 -9 -9 ]
[.22789 .57823 9 0 ]
[.36395 .57823 -9 -9 ]
[.36395 .57823 9 0 ]
[.63605 .57823 -6 -9 ]
[.63605 .57823 6 0 ]
[.77211 .57823 -6 -9 ]
[.77211 .57823 6 0 ]
[.90816 .57823 -6 -9 ]
[.90816 .57823 6 0 ]
[.4875 .01771 -42 -4.5 ]
[.4875 .01771 0 4.5 ]
[.4875 .11322 -48 -4.5 ]
[.4875 .11322 0 4.5 ]
[.4875 .20872 -36 -4.5 ]
[.4875 .20872 0 4.5 ]
[.4875 .30422 -48 -4.5 ]
[.4875 .30422 0 4.5 ]
[.4875 .39973 -42 -4.5 ]
[.4875 .39973 0 4.5 ]
[.4875 .49523 -48 -4.5 ]
[.4875 .49523 0 4.5 ]
[.5 .63053 -209.125 0 ]
[.5 .63053 209.125 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 .59073 m
.09184 .59698 L
s
[(-30)] .09184 .57823 0 1 Mshowa
.22789 .59073 m
.22789 .59698 L
s
[(-20)] .22789 .57823 0 1 Mshowa
.36395 .59073 m
.36395 .59698 L
s
[(-10)] .36395 .57823 0 1 Mshowa
.63605 .59073 m
.63605 .59698 L
s
[(10)] .63605 .57823 0 1 Mshowa
.77211 .59073 m
.77211 .59698 L
s
[(20)] .77211 .57823 0 1 Mshowa
.90816 .59073 m
.90816 .59698 L
s
[(30)] .90816 .57823 0 1 Mshowa
.125 Mabswid
.11905 .59073 m
.11905 .59448 L
s
.14626 .59073 m
.14626 .59448 L
s
.17347 .59073 m
.17347 .59448 L
s
.20068 .59073 m
.20068 .59448 L
s
.2551 .59073 m
.2551 .59448 L
s
.28231 .59073 m
.28231 .59448 L
s
.30952 .59073 m
.30952 .59448 L
s
.33673 .59073 m
.33673 .59448 L
s
.39116 .59073 m
.39116 .59448 L
s
.41837 .59073 m
.41837 .59448 L
s
.44558 .59073 m
.44558 .59448 L
s
.47279 .59073 m
.47279 .59448 L
s
.52721 .59073 m
.52721 .59448 L
s
.55442 .59073 m
.55442 .59448 L
s
.58163 .59073 m
.58163 .59448 L
s
.60884 .59073 m
.60884 .59448 L
s
.66327 .59073 m
.66327 .59448 L
s
.69048 .59073 m
.69048 .59448 L
s
.71769 .59073 m
.71769 .59448 L
s
.7449 .59073 m
.7449 .59448 L
s
.79932 .59073 m
.79932 .59448 L
s
.82653 .59073 m
.82653 .59448 L
s
.85374 .59073 m
.85374 .59448 L
s
.88095 .59073 m
.88095 .59448 L
s
.06463 .59073 m
.06463 .59448 L
s
.03741 .59073 m
.03741 .59448 L
s
.0102 .59073 m
.0102 .59448 L
s
.93537 .59073 m
.93537 .59448 L
s
.96259 .59073 m
.96259 .59448 L
s
.9898 .59073 m
.9898 .59448 L
s
.25 Mabswid
0 .59073 m
1 .59073 L
s
.5 .01771 m
.50625 .01771 L
s
[(-0.0015)] .4875 .01771 1 0 Mshowa
.5 .11322 m
.50625 .11322 L
s
[(-0.00125)] .4875 .11322 1 0 Mshowa
.5 .20872 m
.50625 .20872 L
s
[(-0.001)] .4875 .20872 1 0 Mshowa
.5 .30422 m
.50625 .30422 L
s
[(-0.00075)] .4875 .30422 1 0 Mshowa
.5 .39973 m
.50625 .39973 L
s
[(-0.0005)] .4875 .39973 1 0 Mshowa
.5 .49523 m
.50625 .49523 L
s
[(-0.00025)] .4875 .49523 1 0 Mshowa
.125 Mabswid
.5 .03682 m
.50375 .03682 L
s
.5 .05592 m
.50375 .05592 L
s
.5 .07502 m
.50375 .07502 L
s
.5 .09412 m
.50375 .09412 L
s
.5 .13232 m
.50375 .13232 L
s
.5 .15142 m
.50375 .15142 L
s
.5 .17052 m
.50375 .17052 L
s
.5 .18962 m
.50375 .18962 L
s
.5 .22782 m
.50375 .22782 L
s
.5 .24692 m
.50375 .24692 L
s
.5 .26602 m
.50375 .26602 L
s
.5 .28512 m
.50375 .28512 L
s
.5 .32332 m
.50375 .32332 L
s
.5 .34242 m
.50375 .34242 L
s
.5 .36153 m
.50375 .36153 L
s
.5 .38063 m
.50375 .38063 L
s
.5 .41883 m
.50375 .41883 L
s
.5 .43793 m
.50375 .43793 L
s
.5 .45703 m
.50375 .45703 L
s
.5 .47613 m
.50375 .47613 L
s
.5 .51433 m
.50375 .51433 L
s
.5 .53343 m
.50375 .53343 L
s
.5 .55253 m
.50375 .55253 L
s
.5 .57163 m
.50375 .57163 L
s
.5 .60983 m
.50375 .60983 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -270.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Signature) show
123.000 13.000 moveto
(of) show
141.000 13.000 moveto
(Vert) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Field) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
207.000 13.000 moveto
(@) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
219.000 13.000 moveto
(D) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
249.000 13.000 moveto
(longit) show
285.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
297.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
345.000 13.000 moveto
(@) show
351.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
363.125 13.000 moveto
(D) show
375.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\236) show
387.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
393.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
399.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
411.125 13.000 moveto
(and) show
435.125 13.000 moveto
(z) show
441.125 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
447.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
465.125 13.000 moveto
(mm) show
477.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .59925 m
.03343 .5996 L
.04305 .59997 L
.05267 .60034 L
.06229 .60074 L
.07191 .60114 L
.08153 .60154 L
.09115 .60195 L
.10077 .60234 L
.11039 .6027 L
.12001 .60301 L
.12963 .60323 L
.13925 .60332 L
.14887 .60321 L
.15849 .60281 L
.16811 .60199 L
.17773 .6006 L
.18735 .59842 L
.19697 .59518 L
.20659 .59055 L
.21621 .58412 L
.22583 .57544 L
.23545 .56404 L
.24507 .54943 L
.25469 .5312 L
.26431 .50904 L
.27393 .48282 L
.28355 .45268 L
.29317 .41903 L
.30279 .38257 L
.31241 .34432 L
.32203 .30551 L
.33165 .26751 L
.34127 .23163 L
.35089 .19902 L
.36051 .17047 L
.37013 .14631 L
.37975 .12638 L
.38937 .11009 L
.39899 .0966 L
.40861 .08496 L
.41823 .07435 L
.42785 .06421 L
.43747 .05431 L
.44709 .04473 L
.45671 .03578 L
.46633 .02788 L
.47595 .02151 L
.48557 .01703 L
.49519 .01472 L
Mistroke
.50481 .01472 L
.51443 .01702 L
.52405 .0215 L
.53367 .02788 L
.54329 .03577 L
.55291 .04473 L
.56253 .05431 L
.57215 .06421 L
.58177 .07434 L
.59139 .08495 L
.60101 .09659 L
.61063 .11009 L
.62025 .12637 L
.62987 .1463 L
.63949 .17046 L
.64911 .19901 L
.65873 .23162 L
.66835 .2675 L
.67797 .30551 L
.68759 .34431 L
.69721 .38256 L
.70683 .41902 L
.71645 .45268 L
.72607 .48282 L
.73569 .50903 L
.74531 .5312 L
.75493 .54943 L
.76455 .56403 L
.77417 .57544 L
.78379 .58411 L
.79341 .59055 L
.80303 .59518 L
.81265 .59842 L
.82227 .6006 L
.83189 .60199 L
.84151 .60281 L
.85113 .60321 L
.86075 .60332 L
.87037 .60323 L
.87999 .60301 L
.88961 .6027 L
.89923 .60234 L
.90885 .60195 L
.91847 .60155 L
.92809 .60114 L
.93771 .60074 L
.94733 .60035 L
.95695 .59997 L
.96657 .5996 L
.97619 .59925 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{437.375, 270.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006e00013R000`400?l00000o`00003ofP3oool0
0`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000
oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?oo
o`3H0?ooo`00/`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000003
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0f03oool00;80oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00T00000eP3oool00:/0oooo
1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo0`0000040?ooo`<000000P3oool3
00000=<0oooo002b0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0`0000060?ooo`030000
003oool0oooo00D0oooo0P00003A0?ooo`00/P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool4
000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3>0?ooo`00/P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool200000080oooo0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
c@3oool00;<0oooo0P00000:0?ooo`800000103oool2000000@0oooo00@000000?ooo`000000oooo
1@0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0c03oool00</0oooo0P00
000=0?ooo`030000003oool0oooo00X0oooo0P00003<0?ooo`00bP3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0b@3oool00<T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<P0oooo00370?ooo`80
00004@3oool2000000l0oooo0P0000380?ooo`00aP3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0a@3oool00<D0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<@0oooo00340?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`330?ooo`00``3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0`P3oool00<80
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<40
oooo00310?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`300?ooo`00`03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0_`3oool00;l0oooo00<000000?ooo`3oool0603oool2000001P0oooo00<00000
0?ooo`3oool0_P3oool00;h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0;d0oooo002m0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`2l0?ooo`00_03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0^`3oool00;`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;/0oooo002k0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2j0?ooo`00^P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0^@3oool00;T0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;P0
oooo002h0?ooo`030000003oool0oooo01l0oooo0P00000O0?ooo`030000003oool0oooo0;L0oooo
002g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`2f0?ooo`00]P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0]@3oool00;D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0;@0oooo002d0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`2c0?ooo`00]03oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0/`3oool00;<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0;80oooo002b0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2a0?ooo`00/@3oool00`00
0000oooo0?ooo`0V0?ooo`8000009P3oool00`000000oooo0?ooo`2`0?ooo`00/03oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0[`3oool00;00oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:l0oooo
002_0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`2^0?ooo`00[P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0[@3oool00:d0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`8000000`3oool300000080oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0:`0oooo002/0?ooo`80000000<0oooo0000003oool01`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0:/0oooo002U0?ooo`D000000P3oool2000000030?ooo`00
0000oooo00L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`<0
0000:P3oool00`000000oooo0?ooo`2[0?ooo`00[03oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0:X0oooo002/0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo00000003000000L0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`2Z0?ooo`00Z`3oool200000080oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`070000003oool0oooo
0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0Z@3o
ool00:X0oooo00<000000?ooo`3oool00P00000:0?ooo`800000103oool2000000@0oooo00<00000
0?ooo`3oool00P3oool300000080oooo1@0000060?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0Z03oool00:X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0:P0oooo002Y0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2W0?ooo`00Z@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0Y`3oool00:P0oooo00<000000?ooo`3oool0;`3o
ool200000300oooo00<000000?ooo`3oool0YP3oool00:P0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:H0oooo002W0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2U0?ooo`00Y`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0Y@3oool00:H0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0:@0oooo
002V0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2T0?ooo`00Y@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0X`3oool00:D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0:<0oooo002T0?ooo`030000003oool0oooo03<0oooo0P00000d0?ooo`03
0000003oool0oooo0:80oooo002T0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`2R0?ooo`00Y03oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0XP3oool00:<0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0:40oooo002S0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2Q0?ooo`00XP3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X03oool00:80oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:00oooo
002R0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`2P0?ooo`00X@3oool00`000000oooo0?ooo`0f0?ooo`800000=`3oool00`000000oooo0?ooo`2O
0?ooo`00X@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0W`3oool00:00oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo09h0oooo002P0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2N0?ooo`00X03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0WP3oool009l0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09d0oooo002O0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2M0?ooo`00W`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0W@3oool009h0oooo
00<000000?ooo`3oool0>@3oool2000003X0oooo00<000000?ooo`3oool0W03oool009h0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo09`0oooo002N
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2L
0?ooo`00W@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0V`3oool009d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo09/0oooo002M0?ooo`030000003oool0oooo01T0oooo0P0000040?ooo`030000
003oool0oooo00<0oooo0P0000040?ooo`8000000`3oool3000000L0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`2K0?ooo`00W03oool00`000000oooo0?ooo`0I0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2J0?oo
o`00W03oool00`000000oooo0?ooo`0B0?ooo`D000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`060?ooo`<00000>`3oool00`000000oooo0?ooo`2J0?ooo`00W03oool00`000000oooo0?ooo`0I
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`2J0?ooo`00V`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2J0?ooo`00V`3oool00`00
0000oooo0?ooo`0J0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`800000203oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo09X0oooo002K0?ooo`030000003oool0oooo01/0oooo0P00000:0?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo09T0oooo002K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`2I0?ooo`00VP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0V@3oool009X0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo09T0oooo002J0?ooo`030000003oool0oooo03d0oooo
0P00000m0?ooo`030000003oool0oooo09T0oooo002I0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`2H0?ooo`00V@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0V03oool009T0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo09P0oooo002I0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2H0?ooo`00
V03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
U`3oool009P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo09L0oooo002H0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`2G0?ooo`00U`3oool00`000000oooo0?ooo`100?ooo`800000@03oool00`00
0000oooo0?ooo`2F0?ooo`00U`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0UP3oool009L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo09H0oooo002G0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`2F0?ooo`00UP3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0U@3oool009H0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo09D0oooo002F0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2E0?ooo`00
U@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
U03oool009D0oooo00<000000?ooo`3oool0@P3oool200000480oooo00<000000?ooo`3oool0U03o
ool009D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo09@0oooo002E0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`2D0?ooo`00U03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0T`3oool009@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo09<0oooo002D0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`2C0?ooo`00U03oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0T`3oool009<0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0980oooo002C0?ooo`03
0000003oool0oooo04@0oooo0P0000140?ooo`030000003oool0oooo0980oooo002C0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2B0?ooo`00T`3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0TP3o
ool00980oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0940oooo002B0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`2A0?ooo`00TP3oool00`000000oooo0?ooo`0H0?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080
oooo0`0000070?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0T@3oool00980oooo
00<000000?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0T@3oool00940oooo00<000000?ooo`3oool04@3oool500000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo0`0000150?ooo`030000003oool0oooo0900oooo002A0?ooo`030000003oool0oooo
01P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`2@0?ooo`00
T@3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`0000000`0000070?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0T03o
ool00940oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0900oooo002@0?ooo`030000003oool0oooo01X0oooo0P00000:0?ooo`800000103oool20000
00@0oooo0P0000020?ooo`D0000000<0oooo0000000000000`0000060?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0S`3oool00900oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo08l0oooo002@0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2?0?ooo`00T03oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0S`3oool008l0oooo00<00000
0?ooo`3oool0B03oool2000004P0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo08h0oooo002?0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2>0?ooo`00
S`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
SP3oool008h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo08d0oooo002>0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`2=0?ooo`00SP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0S@3oool008h0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo08d0oooo002=0?ooo`030000003oool0oooo04X0oooo
0P00001:0?ooo`030000003oool0oooo08`0oooo002=0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`2<0?ooo`00S@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0S03oool008d0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo08`0oooo002<0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2;0?ooo`00
S03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
R`3oool008`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo08/0oooo002<0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`2;0?ooo`00R`3oool00`000000oooo0?ooo`1<0?ooo`800000C03oool00`00
0000oooo0?ooo`2:0?ooo`00R`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0RP3oool008/0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo08X0oooo002:0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`290?ooo`00RP3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0R@3oool008X0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo08T0oooo002:0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`290?ooo`00
R@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
R03oool008T0oooo00<000000?ooo`3oool0CP3oool2000004h0oooo00<000000?ooo`3oool0R03o
ool008T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo08P0oooo00290?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`280?ooo`00R03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0Q`3oool008P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo08L0oooo00280?ooo`030000003oool0oooo02P0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103oool2000000<0oooo0`00
00070?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0Q`3oool008P0oooo00<00000
0?ooo`3oool09`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo08L0oooo00270?oo
o`030000003oool0oooo0240oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0103oool3000004l0oooo00<000000?ooo`3oool0QP3oool008L0oooo
00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`260?ooo`00Q`3oool0
0`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003oool0100000070?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0QP3oool008H0oooo00<000000?ooo`3o
ool0:@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`250?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`800000
2P3oool2000000@0oooo0P0000040?ooo`8000000P3oool5000000H0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`250?ooo`00QP3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool0Q@3oool008H0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo08D0oooo00250?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`240?ooo`00Q@3oool00`000000
oooo0?ooo`1B0?ooo`800000DP3oool00`000000oooo0?ooo`240?ooo`00Q@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0Q03oool008D0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo08@0oooo0024
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`23
0?ooo`00Q03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0P`3oool008@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo08<0oooo00230?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`220?ooo`00P`3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0PP3oool008<0oooo00<000000?ooo`3oool0E03oool2
000005@0oooo00<000000?ooo`3oool0PP3oool008<0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0880oooo00220?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`210?ooo`00PP3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0P@3oool00880oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0840oooo0021
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`20
0?ooo`00P@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0P03oool00840oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0800oooo00200?ooo`030000003oool0oooo05L0oooo0P00001G0?ooo`030000
003oool0oooo07l0oooo00200?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`1o0?ooo`00P03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0O`3oool007l0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo07h0oooo001o0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1n0?ooo`00O`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0OP3oool007h0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07d0oooo001n
0?ooo`030000003oool0oooo05T0oooo0P00001I0?ooo`030000003oool0oooo07d0oooo001n0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1m0?oo
o`00O@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0O03oool007d0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo07`0oooo001m0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1l0?ooo`00O@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0N`3oool007`0oooo00<000000?ooo`3oool0;P3oool20000
00@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`8000000P3oool50000
0080oooo0`0000070?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0N`3oool007`0
oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0N`3oool007`0oooo00<000000?ooo`3oool09P3oool500000080
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo0`00001K0?ooo`030000003oool0oooo07X0oooo001k0?ooo`030000003o
ool0oooo02h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1j
0?ooo`00N`3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo00000003000000L0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`1j0?ooo`00N`3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0N@3oool007/0oooo00<000000?ooo`3oool0;`3oool2000000X0oooo
0P0000040?ooo`800000103oool2000000<0oooo0`0000020?ooo`D000001P3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo07T0oooo001j0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`1i0?ooo`00NP3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0N03oool007X0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo07P0oooo001i0?ooo`03
0000003oool0oooo05h0oooo0P00001O0?ooo`030000003oool0oooo07L0oooo001i0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1g0?ooo`00N03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0MP3o
ool007P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo07H0oooo001h0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`1f0?ooo`00M`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0M@3oool007L0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo07D0oooo001f0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`1d0?ooo`00MP3oool00`000000oooo0?ooo`1Q
0?ooo`800000HP3oool00`000000oooo0?ooo`1d0?ooo`00M@3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0L`3oool007D0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo07<0oooo001d0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1b0?ooo`00L`3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0L@3o
ool007<0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0740oooo001b0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`1`0?ooo`00LP3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0L03oool00740oooo00<000000?ooo`3oool0IP3oool2000006L0oooo
00<000000?ooo`3oool0K`3oool00700oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo06h0oooo000a0?ooo`<00000103oool2000002h0oooo1@000003
0?ooo`800000;P3oool3000000@0oooo0P00000a0?ooo`030000003oool0oooo02l0oooo0`000004
0?ooo`800000;P3oool5000000<0oooo0P00000^0?ooo`<00000103oool200000340oooo000`0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000^0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000002h0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<0
00000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000<03oool002X0oooo1@0000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool09@3oool5000000<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo
02@0oooo1@0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<03oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;`3o
ool2000000<0oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02h0oooo000b0?ooo`8000000`3oool010000000oooo0?ooo`00000`0?ooo`03
0000003oool0oooo008000000P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000<03oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0;03oool2000000<0oooo00@000000?ooo`3oool00000<03oool003@0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0[0?ooo`040000003oool0oooo0?ooo`80
000000D0oooo0000003oool0oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000<03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0oooo000`0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000]0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000]0?ooo`800000103oool010000000oooo
0?ooo`00000`0?ooo`800000<03oool2000000@0oooo00@000000?ooo`3oool00000;@3oool01000
0000oooo0?ooo`3oool2000000050?ooo`000000oooo0?ooo`000000;03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000<03oool00340oooo0`0000040?ooo`800000
;`3oool3000000@0oooo0P00000_0?ooo`030000003oool0oooo00<0oooo0P00000a0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool00`3oool2000002l0oooo0`0000020?ooo`040000
003oool00000000002h0oooo0`0000040?ooo`800000<@3oool006X0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06P0oooo001Y0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1X0?ooo`00J03oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0I`3oool0
06L0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
06H0oooo001U0?ooo`800000L`3oool00`000000oooo0?ooo`1`0?ooo`800000IP3oool006<0oooo
0P00001e0?ooo`030000003oool0oooo0780oooo0P00001T0?ooo`003P3ooooo000009X000003P3o
ool00180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0100oooo000B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0`0000000`3oool000000?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`@000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`00<`3oool00`000000oooo0?ooo`0R0?ooo`@0
00003`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00`0oooo1000000T0?ooo`03
0000003oool0oooo0380oooo000G0?oooa<00000:P3oool400000880oooo00<000000?ooo`3oool0
O`3oool4000002X0oooo4`00000H0?ooo`00:P3ooolZ000008H0oooo00<000000?ooo`3oool0P`3o
oolZ000002/0oooo003J0?ooo`030000003oool0oooo0=P0oooo003J0?ooo`030000003oool0oooo
0=P0oooo003J0?ooo`800000f@3oool00=X0oooo00<000000?ooo`3oool0f03oool00=X0oooo00<0
00000?ooo`3oool0f03oool00=X0oooo00<000000?ooo`3oool0f03oool00?l0oooo]P3oool00?l0
oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3oool001P0
oooo0`0000230?ooo`800000203oool2000002h0oooo0`00000J0?ooo`<00000<03oool2000000h0
oooo0P00001k0?ooo`006`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1i0?ooo`00303oool300000080oooo1@00
00020?ooo`@0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000800000
0`3oool2000000@0oooo0P0000000`3oool0000000000002000000@0oooo0`0000090?ooo`<00000
0P3oool5000000T0oooo00<000000?ooo`3oool00P3oool300000080oooo0`0000050?ooo`800000
103oool00`000000oooo0?ooo`070?ooo`<000000`3oool500000080oooo0`0000020?ooo`D00000
0P3oool4000000@0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool0oooo100000080?ooo`D000000P3oool300000080oooo0`000000103o
ool000000000003oool4000000030?ooo`000000000000<000000`3oool2000000@0oooo00<00000
0?ooo`3oool0203oool3000000<0oooo0`0000020?ooo`@000000P3oool5000000<0oooo0P000002
0?ooo`D000000P3oool300000080oooo0`0000000`3oool00000000000030?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003o
ool0oooo00P0oooo0`0000080?ooo`80000000<0oooo0000000000000P3oool400000080oooo0`00
00090?ooo`@0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000800000
1`3oool500000080oooo100000020?ooo`<00000103oool2000000P0oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000000=0?ooo`00303oool010000000oooo0?ooo`00
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000h0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo
000000h0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
203oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000000`3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000000d0oooo000?0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo1@0000070?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool5000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000000`3oool3000000X0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool03`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
0`0000080?ooo`030000003oool0oooo0080oooo100000000`3oool000000?ooo`020?ooo`030000
003oool0oooo00H0oooo0`0000030?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo100000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000001`3oool02`000000oooo0000003oool000000?ooo`000000
oooo0000003oool0000000d0oooo000=0?ooo`800000103oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo
0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P000004
0?ooo`030000003oool0oooo00l0oooo0`0000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000
oooo000000020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool03`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<000001`3o
ool00`000000oooo000000090?ooo`<00000203oool010000000oooo0?ooo`0000030?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`0;0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000003@3oool000`0oooo00<000000?oo
o`3oool00P3oool3000000@0oooo2@0000030?ooo`8000000`3oool400000080oooo0P000000103o
ool000000000003oool2000000030?ooo`00000000000080oooo0`0000090?ooo`<000000`3oool4
000000P0oooo00<000000?ooo`0000000`3oool300000080oooo0P000000103oool000000000003o
ool4000000l0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000040?ooo`030000003o
ool0oooo0080oooo0`0000050?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo00L0oooo0P0000000`3oool00000000000020?ooo`@000002@3oool00`00
0000oooo0?ooo`020?ooo`<000000P3oool4000000<0oooo200000030?ooo`@000003P3oool40000
00<0oooo0`0000030?ooo`@0000000@0oooo00000000000000000`3oool400000080oooo0`000004
0?ooo`<000000P3oool4000000D0oooo00<000000?ooo`3oool00P000000103oool000000?ooo`3o
ool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo0P0000000`3oool00000000000070?ooo`050000003o
ool0oooo0?ooo`000000203oool2000000<0oooo100000030?ooo`<00000203oool5000000T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`80000000@0oooo0000003o
ool0oooo0P0000000`3oool000000?ooo`0=0?ooo`00303oool010000000oooo0?ooo`00000J0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool00`000000oooo0000000?0?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo
0P00000M0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0G0?ooo`8000003P3oool2000000X0oooo1000000C0?ooo`050000003oool0oooo0?ooo`00
00005P3oool00`000000oooo0?ooo`0C0?ooo`800000103oool010000000oooo0?ooo`00000O0?oo
o`003@3oool3000000<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?ooo`80
00001`3oool5000000h0oooo00<000000?ooo`3oool03P3oool5000000<0oooo00<000000?ooo`3o
ool01`3oool3000000D0oooo0P0000080?ooo`D000007`3oool3000001L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`140?ooo`<000005P3oool2000001H0oooo00<000000?ooo`3o
ool00`3oool200000200oooo003o0?oookH0oooo003o0?oookH0oooo0000\
\>"],
  ImageRangeCache->{{{0, 436.375}, {269.312, 0}} -> {-39.2978, -0.00154638, \
0.18011, 6.41466*^-6}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.015873 0.503534 12.7224 [
[.02381 .49103 -9 -9 ]
[.02381 .49103 9 0 ]
[.18254 .49103 -9 -9 ]
[.18254 .49103 9 0 ]
[.34127 .49103 -9 -9 ]
[.34127 .49103 9 0 ]
[.65873 .49103 -6 -9 ]
[.65873 .49103 6 0 ]
[.81746 .49103 -6 -9 ]
[.81746 .49103 6 0 ]
[.97619 .49103 -6 -9 ]
[.97619 .49103 6 0 ]
[.4875 .12186 -30 -4.5 ]
[.4875 .12186 0 4.5 ]
[.4875 .24909 -30 -4.5 ]
[.4875 .24909 0 4.5 ]
[.4875 .37631 -30 -4.5 ]
[.4875 .37631 0 4.5 ]
[.5 .63053 -191.125 0 ]
[.5 .63053 191.125 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .50353 m
.02381 .50978 L
s
[(-30)] .02381 .49103 0 1 Mshowa
.18254 .50353 m
.18254 .50978 L
s
[(-20)] .18254 .49103 0 1 Mshowa
.34127 .50353 m
.34127 .50978 L
s
[(-10)] .34127 .49103 0 1 Mshowa
.65873 .50353 m
.65873 .50978 L
s
[(10)] .65873 .49103 0 1 Mshowa
.81746 .50353 m
.81746 .50978 L
s
[(20)] .81746 .49103 0 1 Mshowa
.97619 .50353 m
.97619 .50978 L
s
[(30)] .97619 .49103 0 1 Mshowa
.125 Mabswid
.05556 .50353 m
.05556 .50728 L
s
.0873 .50353 m
.0873 .50728 L
s
.11905 .50353 m
.11905 .50728 L
s
.15079 .50353 m
.15079 .50728 L
s
.21429 .50353 m
.21429 .50728 L
s
.24603 .50353 m
.24603 .50728 L
s
.27778 .50353 m
.27778 .50728 L
s
.30952 .50353 m
.30952 .50728 L
s
.37302 .50353 m
.37302 .50728 L
s
.40476 .50353 m
.40476 .50728 L
s
.43651 .50353 m
.43651 .50728 L
s
.46825 .50353 m
.46825 .50728 L
s
.53175 .50353 m
.53175 .50728 L
s
.56349 .50353 m
.56349 .50728 L
s
.59524 .50353 m
.59524 .50728 L
s
.62698 .50353 m
.62698 .50728 L
s
.69048 .50353 m
.69048 .50728 L
s
.72222 .50353 m
.72222 .50728 L
s
.75397 .50353 m
.75397 .50728 L
s
.78571 .50353 m
.78571 .50728 L
s
.84921 .50353 m
.84921 .50728 L
s
.88095 .50353 m
.88095 .50728 L
s
.9127 .50353 m
.9127 .50728 L
s
.94444 .50353 m
.94444 .50728 L
s
.25 Mabswid
0 .50353 m
1 .50353 L
s
.5 .12186 m
.50625 .12186 L
s
[(-0.03)] .4875 .12186 1 0 Mshowa
.5 .24909 m
.50625 .24909 L
s
[(-0.02)] .4875 .24909 1 0 Mshowa
.5 .37631 m
.50625 .37631 L
s
[(-0.01)] .4875 .37631 1 0 Mshowa
.125 Mabswid
.5 .02008 m
.50375 .02008 L
s
.5 .04553 m
.50375 .04553 L
s
.5 .07097 m
.50375 .07097 L
s
.5 .09642 m
.50375 .09642 L
s
.5 .14731 m
.50375 .14731 L
s
.5 .17275 m
.50375 .17275 L
s
.5 .1982 m
.50375 .1982 L
s
.5 .22364 m
.50375 .22364 L
s
.5 .27453 m
.50375 .27453 L
s
.5 .29998 m
.50375 .29998 L
s
.5 .32542 m
.50375 .32542 L
s
.5 .35087 m
.50375 .35087 L
s
.5 .40176 m
.50375 .40176 L
s
.5 .4272 m
.50375 .4272 L
s
.5 .45264 m
.50375 .45264 L
s
.5 .47809 m
.50375 .47809 L
s
.5 .52898 m
.50375 .52898 L
s
.5 .55442 m
.50375 .55442 L
s
.5 .57987 m
.50375 .57987 L
s
.5 .60531 m
.50375 .60531 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -252.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Signature) show
123.000 13.000 moveto
(of) show
141.000 13.000 moveto
(Vertical) show
195.000 13.000 moveto
(Field) show
231.000 13.000 moveto
(Integral) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
279.000 13.000 moveto
(@) show
285.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tmm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
303.125 13.000 moveto
(D) show
315.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
333.125 13.000 moveto
(horiz) show
363.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
369.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
417.125 13.000 moveto
(@) show
423.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
435.250 13.000 moveto
(D) show
441.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .55248 m
.05556 .55741 L
.0873 .56312 L
.11905 .56962 L
.15079 .57671 L
.18254 .584 L
.21429 .59091 L
.24603 .59682 L
.27778 .60117 L
.30952 .60332 L
.34127 .60221 L
.37302 .5959 L
.40476 .58129 L
.43651 .554 L
.46825 .50887 L
.5 .44112 L
.53175 .34908 L
.56349 .23902 L
.59524 .12922 L
.62698 .04657 L
.65873 .01472 L
.69048 .04237 L
.72222 .11918 L
.75397 .22053 L
.78571 .31966 L
.81746 .39958 L
.84921 .45597 L
.88095 .4923 L
.9127 .51428 L
.94444 .5269 L
.97619 .53371 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{437.375, 270.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006e00013R000`400?l00000o`00003ofP3oool0
0`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000
oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?oo
o`3H0?ooo`00fP3oool00`000000oooo0?ooo`3H0?ooo`00fP3oool00`000000oooo0?ooo`0m0?oo
o`800000V@3oool00=X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0000002H0?ooo`00
fP3oool2000003d0oooo00D000000?ooo`3oool0oooo0000002G0?ooo`00fP3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0U03oool00=X0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09<0oooo003J
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool2000009<0oooo003J0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2@0?oo
o`00fP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0S`3oool00=X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo08h0oooo003J0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`2=0?ooo`00fP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0S03oool00=X0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo08/0oooo003J0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2;0?ooo`00fP3oool200000380oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2:0?ooo`00fP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0RP3oool00=X0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08X0oooo003J0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`290?oo
o`00fP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0R@3oool00=X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo08P0oooo003J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`280?ooo`00fP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0R03oool00=X0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo08L0oooo003J0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`270?ooo`00fP3oool2000002h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`260?ooo`00fP3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0QP3oool00=X0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08H0oooo003J0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`250?oo
o`00fP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0Q@3oool00=X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo08@0oooo003J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`240?ooo`00fP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0P`3oool00=X0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo08<0oooo003J0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`230?ooo`00fP3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0PP3oool00=X0oooo0P00
000Z0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0PP3oool00=X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0840oooo003J0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`210?oo
o`00fP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0P@3oool00=X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0800oooo003J0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`200?ooo`00fP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0O`3oool00;l0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`<000001`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0O`3oool00;h0oooo00@000000?ooo`3oool00000203oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0O`3oool00;L0oooo1@000002
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1n0?ooo`00_P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo0P0000070?ooo`<000009@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07h0
oooo002n0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`1n0?ooo`00_P3oool010000000oooo0?ooo`0000080?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`1m0?ooo`00_`3oool2000000X0oooo0P000003
0?ooo`<000001`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0O@3oool00=X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo07d0oooo003J0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`1l0?ooo`00fP3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0O03oool00=X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07`0oooo003J0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1k0?ooo`00fP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0N`3oool00=X0
oooo0P00000S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0N`3oool00=X0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo07X0oooo
003J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`1j0?ooo`00fP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0NP3oool00=X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo07T0oooo003J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1i0?ooo`00fP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0N@3oool00=X0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07P0oooo003J0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1h0?ooo`00fP3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0N03oool00=X0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo07L0
oooo003J0?ooo`800000803oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo07L0oooo
003J0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`1g0?ooo`00fP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0M`3oool00=X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo07H0oooo003J0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`1f0?ooo`00fP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0MP3oool00=X0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo07D0oooo003J0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1e0?ooo`00fP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0M@3oool00=X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo07@0
oooo003J0?ooo`8000007@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo07@0oooo
003J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`1d0?ooo`00fP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0L`3oool00=X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo07<0oooo003J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`1c0?ooo`00fP3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0LP3oool00=X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0780oooo003J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1b0?ooo`00fP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0L@3oool00=X0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0740
oooo003J0?ooo`8000006P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0740oooo
003J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`1a0?ooo`00fP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0L03oool00=X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0700oooo003J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1`0?ooo`00fP3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0K`3oool00=X0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo06l0oooo003J0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1_0?ooo`00_`3oool20000
00@0oooo00<000000?ooo`3oool00`3oool200000080oooo1@0000060?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1^0?ooo`00_P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0KP3o
ool00;L0oooo1@0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`1^0?ooo`00_P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool3000001H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1]0?ooo`00_P3oool010000000oooo0?ooo`0000080?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1]0?ooo`00_P3oool01000
0000oooo0?ooo`0000080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`1]0?ooo`00_`3oool2000000X0oooo0P0000030?ooo`<000001`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0K03oool00=X0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo06`0oooo003J0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1/0?oo
o`00fP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0J`3oool00=X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo06/0oooo003J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`1[0?ooo`00fP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0JP3oool00=X0oooo0P00000D0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0JP3oool00=X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo06X0oooo003J0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1Z0?ooo`00fP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0J@3oool00=X0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo06T0oooo003J0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1Y0?oo
o`00fP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0J03oool00=X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo06P0oooo003J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`1X0?ooo`00fP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0I`3oool00=X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo06L0oooo003J0?ooo`8000004@3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo06L0oooo003J0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1V0?ooo`00fP3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0IP3oool00=X0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo06H0oooo003J0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1U0?oo
o`00fP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0I@3oool00=X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo06D0oooo003J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1T0?ooo`00fP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0I03oool00=X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo06@0oooo003J0?ooo`8000003P3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo06<0oooo003J0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`00fP3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00=X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0680oooo003J0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1R0?oo
o`00fP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0H@3oool00=X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0640oooo003J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`1Q0?ooo`00fP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0H03oool00=X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo0600oooo003J0?ooo`8000002`3oool00`000000
oooo0?ooo`1Y0?ooo`030000003oool0oooo05l0oooo003J0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1O0?ooo`00fP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0G`3oool00=X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo05h0oooo003J0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1N0?oo
o`00fP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0G@3oool00=X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo05d0oooo003J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`1L0?ooo`00_`3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
000000<0oooo0`0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1L0?ooo`00_P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0G03oool00;L0oooo1@0000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1K0?ooo`00_P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool01P3oool3000000H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1K0?ooo`00
_P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool0FP3oool00;h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0FP3oool00;l0oooo0P00000:0?ooo`800000103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1J0?oo
o`00fP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool0F@3oool00=X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo05T0oooo003J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`1H0?ooo`00fP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0F03oool00=X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo05P0oooo003J0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`00fP3oool2000000@0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1G0?ooo`00fP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0EP3oool00=X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo05H0oooo003J0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1E0?oo
o`00fP3oool01@000000oooo0?ooo`3oool0000007l0oooo00<000000?ooo`3oool0E03oool00=X0
oooo00D000000?ooo`3oool0oooo0000001o0?ooo`030000003oool0oooo05@0oooo003J0?ooo`05
0000003oool0oooo0?ooo`000000P03oool00`000000oooo0?ooo`1C0?ooo`00fP3oool010000000
oooo0?ooo`0000210?ooo`030000003oool0oooo05<0oooo003J0?ooo`040000003oool0oooo0000
0880oooo00<000000?ooo`3oool0DP3oool00=X0oooo00@000000?ooo`3oool00000PP3oool00`00
0000oooo0?ooo`1B0?ooo`00fP3oool00`000000oooo000000240?ooo`030000003oool0oooo0540
oooo003J0?ooo`<00000Q@3oool00`000000oooo0?ooo`1@0?ooo`00fP3oool00`000000oooo0000
00250?ooo`030000003oool0oooo0500oooo003J0?ooo`800000Q`3oool00`000000oooo0?ooo`1?
0?ooo`00fP3oool2000008L0oooo00<000000?ooo`3oool0C`3oool00=X0oooo0P0000280?ooo`03
0000003oool0oooo04h0oooo003J0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
CP3oool00=X0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1=0?ooo`00f@3oool2
000008X0oooo00<000000?ooo`3oool0C@3oool00=T0oooo0P00002;0?ooo`030000003oool0oooo
04`0oooo003H0?ooo`030000003oool0000008`0oooo00<000000?ooo`3oool0B`3oool00=P0oooo
00@000000?ooo`0000000000R`3oool00`000000oooo0?ooo`1;0?ooo`00e`3oool010000000oooo
0?ooo`00002=0?ooo`030000003oool0oooo04X0oooo003G0?ooo`040000003oool0oooo000008d0
oooo00<000000?ooo`3oool0BP3oool00=L0oooo00@000000?ooo`3oool00000SP3oool00`000000
oooo0?ooo`190?ooo`00eP3oool01@000000oooo0?ooo`3oool0000008l0oooo00<000000?ooo`3o
ool0B03oool00=H0oooo00D000000?ooo`3oool0oooo0000002@0?ooo`030000003oool0oooo04L0
oooo003E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`160?ooo`00e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0A@3oool001D0oooo0`0000040?ooo`800000=`3oool5000000<0oooo0P00000h
0?ooo`<00000103oool2000003@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h
0?ooo`<00000103oool2000003L0oooo1@0000030?ooo`8000003`3oool00`000000oooo0?ooo`0V
0?ooo`<00000103oool2000001D0oooo000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`00000g0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000>03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000=`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000l0oooo
00<000000?ooo`3oool0903oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000503oool000h0oooo1@0000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0;P3oool5000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000`
0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000380oooo00<0
00000?ooo`3oool0103oool2000003X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000003`3oool00`000000
oooo0?ooo`0X0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool001H0
oooo0P0000030?ooo`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000003T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool09@3oool2000000<0oooo00@000000?ooo`3o
ool00000503oool001P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000h0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo02H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`00503oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000=P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000=`3oool2000000@0oooo00@000000?oo
o`3oool00000<@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03P0oooo0P000004
0?ooo`040000003oool0oooo000003H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000503oool001D0oooo0`0000040?ooo`800000>03oool30000
00@0oooo0P00000i0?ooo`030000003oool0oooo00<0oooo0P00000a0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`800000>03oool30000
00@0oooo0P00000D0?ooo`030000003oool0oooo0240oooo0`0000040?ooo`8000005@3oool00=40
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03h0
oooo003@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0V03oool2000003h0oooo
003@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0k0?ooo`00d03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09/0oooo0P00000k
0?ooo`00c`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool0>03oool00<l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2N0?ooo`80
0000>03oool000h0ooooo`00002J000000h0oooo000G0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool2000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`005`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0Q0?ooo`8000006`3oool00`000000oooo0?ooo`0F0?ooo`00c@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0<@3oool0
0<`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2U0?ooo`800000<@3oool00</0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2W0?ooo`<00000;P3oool00<X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2Z0?ooo`<00000:`3oool00<X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2]0?ooo`800000:@3oool00<T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`2_0?ooo`<000009P3oool00<P0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`2b0?ooo`<000008`3oool00<P0oooo00<000000?ooo`3o
ool03`3oool200000;H0oooo1@00000N0?ooo`00a`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0;X0oooo1000000J0?ooo`00aP3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0;h0oooo0P00000H0?ooo`00a@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0=P0oooo00350?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0f03oool00<@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3H0?ooo`00``3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0=P0oooo00330?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0f03oool00<80oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3H
0?ooo`00`@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0=P0oooo000G0?ooo`@0
0000Y03oool2000001T0oooo0P00003I0?ooo`006`3oool7000009`0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`3H0?ooo`008P3oool6000009D0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3H0?ooo`00:03oool7000008d0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`3H0?ooo`00;`3oool5000008L0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3H0?ooo`00=03oool500000800oooo0P00000O0?ooo`030000003oool0oooo0=P0
oooo000i0?ooo`@00000N`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0=P0oooo
000m0?ooo`@00000MP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0=P0oooo0011
0?ooo`D00000L03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0=P0oooo00160?oo
o`@00000J`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0=P0oooo001:0?ooo`@0
0000IP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0=P0oooo001>0?ooo`D00000
G`3oool2000002H0oooo0P00003I0?ooo`00D`3oool4000005T0oooo0P00000X0?ooo`030000003o
ool0oooo0=P0oooo001G0?ooo`D00000DP3oool2000002X0oooo00<000000?ooo`3oool0f03oool0
05`0oooo1`0000180?ooo`<00000;03oool00`000000oooo0?ooo`3H0?ooo`00H`3oool500000440
oooo0P00000_0?ooo`030000003oool0oooo0=P0oooo001X0?ooo`D00000>P3oool200000340oooo
00<000000?ooo`3oool0f03oool006d0oooo1000000c0?ooo`<00000<`3oool00`000000oooo0?oo
o`3H0?ooo`00L@3oool5000002T0oooo1@00000f0?ooo`030000003oool0oooo0=P0oooo001f0?oo
o`L000007P3oool4000003/0oooo00<000000?ooo`3oool0f03oool007d0oooo7P00000o0?ooo`03
0000003oool0oooo0=P0oooo003J0?ooo`800000f@3oool00=X0oooo00<000000?ooo`3oool0f03o
ool00=X0oooo00<000000?ooo`3oool0f03oool00=X0oooo00<000000?ooo`3oool0f03oool00=X0
oooo00<000000?ooo`3oool0f03oool00=X0oooo00<000000?ooo`3oool0f03oool00?l0oooo]P3o
ool00?l0oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3oool00?l0oooo]P3o
ool002X0oooo0`00002a0?ooo`<000005`3oool2000001@0oooo0P00000o0?ooo`<00000<03oool2
000000h0oooo0P00000Q0?ooo`00;@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`007P3oool300000080
oooo1@0000020?ooo`@0000000D0oooo00000000000000000?ooo`02000000030?ooo`0000000000
008000000`3oool2000000@0oooo0P0000000`3oool0000000000002000000@0oooo0`0000090?oo
o`<000000P3oool5000000T0oooo00<000000?ooo`3oool00P3oool300000080oooo0`0000050?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000070?oo
o`<000000`3oool500000080oooo0`0000020?ooo`D000000P3oool4000000L0oooo1@0000001@3o
ool00000000000000000oooo008000000P3oool2000000<0oooo0`0000030?ooo`@0000000@0oooo
0000000000000000103oool4000000030?ooo`000000000000<00000103oool010000000oooo0?oo
o`3oool300000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo100000080?ooo`H00000
00@0oooo00000000000000000P3oool3000000<0oooo1@0000000`3oool0000000000003000000<0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`0000020?ooo`@000000P3oool5000000<0
oooo0P0000020?ooo`D000000P3oool300000080oooo0`0000000`3oool00000000000030?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo01l0oooo000N0?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000001@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool03`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`060000003o
ool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo01l0oooo000Q0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool3000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo1@0000070?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`<0
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0oooo1@0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`D0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000050?ooo`<00000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00l000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0000000<0oooo0`0000090?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool00`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00030?ooo`030000003oool0oooo01l0oooo000O0?ooo`800000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`8000000`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
0P0000040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<0
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo00<000000?ooo`3oool00P0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`0?0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo008000001@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000`3oool00`000000oooo0?ooo`0O0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`<0
0000103oool9000000<0oooo0P0000030?ooo`@000000P3oool2000000040?ooo`00000000000?oo
o`80000000<0oooo0000000000000P3oool3000000T0oooo0`0000030?ooo`@00000203oool00`00
0000oooo000000030?ooo`<000000P3oool2000000040?ooo`00000000000?ooo`@000000P3oool3
000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo0`0000040?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<000002P3oool0
10000000oooo0?ooo`3oool400000080oooo100000030?ooo`<000000`3oool7000000030?ooo`00
000000000080oooo0P0000050?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool00000
0?ooo`000000oooo0000003oool00P000000103oool000000?ooo`3oool2000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`00000000000080oooo10000008
0?ooo`<000000`3oool300000080oooo0P000000103oool000000000003oool3000000<0oooo1@00
00070?ooo`@000000`3oool3000000<0oooo10000000103oool000000000000000030?ooo`@00000
0P3oool3000000@0oooo0`0000020?ooo`@000001@3oool00`000000oooo0?ooo`02000000040?oo
o`000000oooo0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0O0?ooo`00
7P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0203oool00`000000oooo0000000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0103oool2000000060?ooo`000000oooo0000003oool000003P3oool2000001`0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0G0?ooo`8000003P3oool200000240oooo000O
0?ooo`<000000`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo0P000007
0?ooo`D000003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`000009
0?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`<000001@3oool2000000P0oooo1@000008
0?ooo`030000003oool0oooo01X0oooo0`0000090?ooo`D00000:`3oool200000180oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0@`3oool00?l0oooo]P3oool00?l0oooo]P3oool00001\
\>"],
  ImageRangeCache->{{{0, 436.375}, {269.312, 0}} -> {-33.6837, -0.0395788, \
0.15438, 0.000192611}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 1004}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{831, 624},
WindowMargins->{{74, Automatic}, {Automatic, 92}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`_mooh/=<`Tk0fL5N`?P0080004/0B`000000]P2:001
0000I00000400`<30?l00BL?00400@P3lM0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 75, 0, 62, "Title"],
Cell[1795, 51, 340, 9, 82, "Text"],

Cell[CellGroupData[{
Cell[2160, 64, 43, 0, 59, "Section"],
Cell[2206, 66, 2273, 32, 274, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4516, 103, 43, 0, 39, "Section"],
Cell[4562, 105, 902, 16, 170, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5501, 126, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5559, 130, 114, 2, 63, "Input"],
Cell[5676, 134, 220, 4, 22, "Print"],
Cell[5899, 140, 121, 2, 37, "Print"]
}, Open  ]],
Cell[6035, 145, 2620, 45, 687, "Input"],
Cell[8658, 192, 2221, 39, 543, "Input"],
Cell[10882, 233, 366, 7, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11285, 245, 38, 0, 39, "Section"],
Cell[11326, 247, 280, 5, 42, "Text"],
Cell[11609, 254, 4704, 83, 591, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16350, 342, 40, 0, 39, "Section"],
Cell[16393, 344, 136, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[16554, 351, 263, 5, 95, "Input"],
Cell[16820, 358, 77244, 1047, 296, 16983, 301, "BoxData", "Graphics3D", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94101, 1410, 70, 1, 47, "Input"],
Cell[94174, 1413, 107025, 2976, 326, 29900, 2019, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[201248, 4395, 55, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[201328, 4399, 3757, 73, 575, "Input"],
Cell[205088, 4474, 361, 7, 22, "Print"],
Cell[205452, 4483, 359, 7, 22, "Print"],
Cell[205814, 4492, 49146, 1055, 279, 9873, 566, "GraphicsData", "PostScript", \
"Graphics"],
Cell[254963, 5549, 40122, 805, 279, 6524, 386, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

